@@ -29,6 +29,8 @@ The checks here are supposed to take a negligible amount of time (< 0.2 seconds)
 and not impact startup. Module imports have no impact (they get imported later
 by the app anyway). For more complex checks, you can measure (with time.time()),
 when called from application.py instead of bin/pitivi, if it has an impact.
+
+Package maintainers should look at the bottom section of this file.
 """
 
 import sys
@@ -38,6 +40,14 @@ from gettext import gettext as _
 missing_soft_deps = {}
 
 
+def _version_to_string(version):
+    return ".".join([str(x) for x in version])
+
+
+def _string_to_list(version):
+    return [int(x) for x in version.split(".")]
+
+
 class Dependency(object):
     """
     This abstract class represents a module or component requirement.
@@ -88,7 +98,7 @@ class Dependency(object):
         """
         raise NotImplementedError
 
-    def __nonzero__(self):
+    def __bool__(self):
         return self.satisfied
 
     def __repr__(self):
@@ -141,7 +151,10 @@ class GstPluginDependency(Dependency):
     Gst is importable.
     """
     def _try_importing_component(self):
-        from gi.repository import Gst
+        try:
+            from gi.repository import Gst
+        except ImportError:
+            return None
         Gst.init(None)
 
         registry = Gst.Registry.get()
@@ -170,34 +183,8 @@ class CairoDependency(ClassicDependency):
         return _string_to_list(module.cairo_version_string())
 
 
-HARD_DEPENDENCIES = (CairoDependency("1.10.0"),
-                     GtkOrClutterDependency("Clutter", "1.12.0"),
-                     GtkOrClutterDependency("ClutterGst", "2.0.0"),
-                     GstDependency("Gst", "1.2.0"),
-                     GstDependency("GES", "1.2.0.0"),
-                     GtkOrClutterDependency("Gtk", "3.8.0"),
-                     ClassicDependency("numpy", None),
-                     GIDependency("Gio", None),
-                     GstPluginDependency("gnonlin", "1.2.0"))
-
-PYCANBERRA_SOFT_DEPENDENCY = ClassicDependency("pycanberra", None,
-                                               _("enables sound notifications when rendering is complete"))
-GNOMEDESKTOP_SOFT_DEPENDENCY = GIDependency("GnomeDesktop", None,
-                                            _("file thumbnails provided by GNOME's thumbnailers"))
-NOTIFY_SOFT_DEPENDENCY = GIDependency("Notify", None,
-                                      _("enables visual notifications when rendering is complete"))
-LIBAV_SOFT_DEPENDENCY = GstPluginDependency("libav", None,
-                                            _("additional multimedia codecs through the Libav library"))
-
-SOFT_DEPENDENCIES = (PYCANBERRA_SOFT_DEPENDENCY,
-                     GNOMEDESKTOP_SOFT_DEPENDENCY,
-                     NOTIFY_SOFT_DEPENDENCY,
-                     LIBAV_SOFT_DEPENDENCY)
-
-
 def _check_audiosinks():
     from gi.repository import Gst
-
     # Yes, this can still fail, if PulseAudio is non-responsive for example.
     sink = Gst.ElementFactory.make("autoaudiosink", None)
     if not sink:
@@ -205,12 +192,13 @@ def _check_audiosinks():
     return True
 
 
-def _version_to_string(version):
-    return ".".join([str(x) for x in version])
-
-
-def _string_to_list(version):
-    return [int(x) for x in version.split(".")]
+def _check_gst_python():
+    from gi.repository import Gst
+    try:
+        Gst.Fraction(9001, 1)  # It's over NINE THOUSANDS!
+    except TypeError:
+        return False  # What, nine thousands?! There's no way that can be right
+    return True
 
 
 def check_requirements():
@@ -219,24 +207,29 @@ def check_requirements():
         dependency.check()
         if not dependency.satisfied:
             if hard_dependencies_satisfied:
-                print _("ERROR - The following hard dependencies are unmet:")
-                print "=================================================="
-            print dependency
+                print((_("ERROR - The following hard dependencies are unmet:")))
+                print("==================================================")
+            print(dependency)
             hard_dependencies_satisfied = False
 
     for dependency in SOFT_DEPENDENCIES:
         dependency.check()
         if not dependency.satisfied:
             missing_soft_deps[dependency.modulename] = dependency
-            print _("Missing soft dependency:")
-            print dependency
+            print((_("Missing soft dependency:")))
+            print(dependency)
 
     if not hard_dependencies_satisfied:
         return False
 
+    if not _check_gst_python():
+        print((_("ERROR — Could not create a Gst.Fraction — "
+              "this means gst-python is not installed correctly.")))
+        return False
+
     if not _check_audiosinks():
-        print _("Could not create audio output sink. "
-                "Make sure you have a valid one (pulsesink, alsasink or osssink).")
+        print((_("Could not create audio output sink. "
+                "Make sure you have a valid one (pulsesink, alsasink or osssink).")))
         return False
 
     return True
@@ -253,8 +246,6 @@ def initialize_modules():
     Gdk.init([])
     from gi.repository import GtkClutter
     GtkClutter.init([])
-    from gi.repository import ClutterGst
-    ClutterGst.init([])
 
     import gi
     if not gi.version_info >= (3, 11):
@@ -266,7 +257,41 @@ def initialize_modules():
     from gi.repository import GES
     GES.init()
 
-    # This is required because of:
-    # https://bugzilla.gnome.org/show_bug.cgi?id=656314
-    from gi.repository import GdkX11
-    GdkX11  # noop
+
+"""
+--------------------------------------------------------------------------------
+Package maintainers, this is where you can see the list of requirements.
+
+Those are either:
+- Classic Python modules
+- Dynamic Python bindings through GObject introspection ("GIDependency")
+- Something else. For example, there are various GStreamer plugins/elements
+  for which there is no clear detection method other than trying to instantiate;
+  there are special snowflakes like gst-python that are GI bindings "overrides"
+  for which there is no way to detect the version either.
+
+Some of our dependencies have version numbers requirements; for those without
+a specific version requirement, they have the "None" value.
+"""
+HARD_DEPENDENCIES = [CairoDependency("1.10.0"),
+                     GtkOrClutterDependency("Clutter", "1.12.0"),
+                     GstDependency("Gst", "1.4.0"),
+                     GstDependency("GES", "1.4.0.0"),
+                     GtkOrClutterDependency("Gtk", "3.10.0"),
+                     ClassicDependency("numpy", None),
+                     GIDependency("Gio", None),
+                     ]
+
+# This one is a special case: eventually gnonlin will be dropped
+ges_1_5 = GstDependency("GES", "1.5.0.0")
+ges_1_5.check()
+if not ges_1_5.satisfied:
+    HARD_DEPENDENCIES.append(GstPluginDependency("gnonlin", "1.4.0"))
+
+SOFT_DEPENDENCIES = \
+    (
+        ClassicDependency("pycanberra", None, _("enables sound notifications when rendering is complete")),
+        GIDependency("GnomeDesktop", None, _("file thumbnails provided by GNOME's thumbnailers")),
+        GIDependency("Notify", None, _("enables visual notifications when rendering is complete")),
+        GstPluginDependency("libav", None, _("additional multimedia codecs through the GStreamer Libav library")),
+    )
