@@ -19,9 +19,6 @@
 # Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 # Boston, MA 02110-1301, USA.
 
-"""
-Class handling the midle pane
-"""
 import os
 
 from gi.repository import Gtk
@@ -45,9 +42,10 @@ from pitivi.effects import AUDIO_EFFECT, VIDEO_EFFECT, HIDDEN_EFFECTS, \
 
 (COL_ACTIVATED,
  COL_TYPE,
+ COL_BIN_DESCRIPTION_TEXT,
  COL_NAME_TEXT,
  COL_DESC_TEXT,
- COL_TRACK_EFFECT) = range(5)
+ COL_TRACK_EFFECT) = list(range(6))
 
 
 class ClipPropertiesError(Exception):
@@ -69,37 +67,41 @@ def compare_type(track, effect_type):
 class ClipProperties(Gtk.ScrolledWindow, Loggable):
     """
     Widget for configuring the selected clip.
+
+    @type app: L{Pitivi}
     """
 
-    def __init__(self, instance, uiman):
+    def __init__(self, app):
         Gtk.ScrolledWindow.__init__(self)
         Loggable.__init__(self)
-        self.app = instance
-        self.settings = instance.settings
+        self.app = app
+        self.settings = app.settings
         self._project = None
 
-        self.infobar_box = Gtk.VBox()
-        effects_properties_manager = EffectsPropertiesManager(instance)
-        self.effect_expander = EffectProperties(instance, effects_properties_manager, self)
-        self.effect_expander.set_vexpand(False)
-        # Transformation boxed DISABLED
-        #self.transformation_expander = TransformationProperties(instance, instance.action_log)
-        #self.transformation_expander.set_vexpand(False)
+        self.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
+
+        viewport = Gtk.Viewport()
+        viewport.show()
+        self.add(viewport)
 
         vbox = Gtk.VBox()
         vbox.set_spacing(SPACING)
-        vbox.pack_start(self.infobar_box, False, True, 0)
-        # Transformation boxed DISABLED
-        #vbox.pack_start(self.transformation_expander, False, True, 0)
-        vbox.pack_start(self.effect_expander, True, True, 0)
-
-        viewport = Gtk.Viewport()
-        viewport.add(vbox)
-        self.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
-        self.add(viewport)
-        viewport.show()
         vbox.show()
+        viewport.add(vbox)
+
+        self.infobar_box = Gtk.VBox()
         self.infobar_box.show()
+        vbox.pack_start(self.infobar_box, False, True, 0)
+
+        # Transformation boxed DISABLED
+        # self.transformation_expander = TransformationProperties(instance, instance.action_log)
+        # self.transformation_expander.set_vexpand(False)
+        # vbox.pack_start(self.transformation_expander, False, True, 0)
+
+        effects_properties_manager = EffectsPropertiesManager(app)
+        self.effect_expander = EffectProperties(app, effects_properties_manager, self)
+        self.effect_expander.set_vexpand(False)
+        vbox.pack_start(self.effect_expander, True, True, 0)
 
     def _setProject(self, project):
         self._project = project
@@ -107,7 +109,7 @@ class ClipProperties(Gtk.ScrolledWindow, Loggable):
             self.effect_expander._connectTimelineSelection(self.app.gui.timeline_ui.timeline)
             # Transformation boxed DISABLED
             # if self.transformation_expander:
-                # self.transformation_expander.timeline = self.app.gui.timeline_ui.timeline
+            #     self.transformation_expander.timeline = self.app.gui.timeline_ui.timeline
 
     def _getProject(self):
         return self._project
@@ -118,6 +120,7 @@ class ClipProperties(Gtk.ScrolledWindow, Loggable):
         label = Gtk.Label(label=text)
         label.set_line_wrap(True)
         infobar = Gtk.InfoBar()
+        infobar.props.message_type = Gtk.MessageType.OTHER
         infobar.get_content_area().add(label)
         self.infobar_box.pack_start(infobar, False, False, 0)
         return infobar
@@ -138,22 +141,19 @@ class EffectProperties(Gtk.Expander, Loggable):
     """
     Widget for viewing and configuring effects
 
-    @type instance: C{Pitivi}
+    @type app: C{Pitivi}
     @type effects_properties_manager: C{EffectsPropertiesManager}
     """
-    # Note: This should be inherited from Gtk.Expander when we get other things
-    # to put in ClipProperties, that is why this is done this way
 
-    def __init__(self, instance, effects_properties_manager, clip_properties):
-        # Set up the expander widget that will contain everything:
+    def __init__(self, app, effects_properties_manager, clip_properties):
         Gtk.Expander.__init__(self)
         self.set_expanded(True)
         self.set_label(_("Effects"))
         Loggable.__init__(self)
 
         # Global variables related to effects
-        self.app = instance
-        self.settings = instance.settings
+        self.app = app
+        self.settings = app.settings
 
         self.selected_effects = []
         self.clips = []
@@ -179,10 +179,22 @@ class EffectProperties(Gtk.Expander, Loggable):
                                            Gtk.PolicyType.AUTOMATIC)
         self.treeview_scrollwin.set_shadow_type(Gtk.ShadowType.ETCHED_IN)
 
-        self.storemodel = Gtk.ListStore(bool, str, str, str, object)
+        # We need to specify Gtk.TreeDragSource because otherwise we are hitting
+        # bug https://bugzilla.gnome.org/show_bug.cgi?id=730740.
+        class EffectsListStore(Gtk.ListStore, Gtk.TreeDragSource):
+            def __init__(self, *args):
+                Gtk.ListStore.__init__(self, *args)
+                # Simply set the source index on the storemodrel directly
+                # to avoid issues with the selection_data API
+                # FIXME: Work around https://bugzilla.gnome.org/show_bug.cgi?id=737587
+                self.source_index = None
+
+            def do_drag_data_get(self, path, selection_data):
+                self.source_index = path.get_indices()[0]
+
+        self.storemodel = EffectsListStore(bool, str, str, str, str, object)
         self.treeview = Gtk.TreeView(model=self.storemodel)
         self.treeview_scrollwin.add(self.treeview)
-        self.treeview.set_property("rules_hint", True)
         self.treeview.set_property("has_tooltip", True)
         self.treeview.set_headers_clickable(False)
         self.treeview.get_selection().set_mode(Gtk.SelectionMode.SINGLE)
@@ -194,7 +206,6 @@ class EffectProperties(Gtk.Expander, Loggable):
                             _("Active"), activatedcell, active=COL_ACTIVATED)
 
         typecol = Gtk.TreeViewColumn(_("Type"))
-        typecol.set_sort_column_id(COL_TYPE)
         typecol.set_spacing(SPACING)
         typecol.set_sizing(Gtk.TreeViewColumnSizing.AUTOSIZE)
         typecell = Gtk.CellRendererText()
@@ -205,7 +216,6 @@ class EffectProperties(Gtk.Expander, Loggable):
         self.treeview.append_column(typecol)
 
         namecol = Gtk.TreeViewColumn(_("Effect name"))
-        namecol.set_sort_column_id(COL_NAME_TEXT)
         namecol.set_spacing(SPACING)
         namecell = Gtk.CellRendererText()
         namecell.props.xpad = PADDING
@@ -214,10 +224,15 @@ class EffectProperties(Gtk.Expander, Loggable):
         namecol.add_attribute(namecell, "text", COL_NAME_TEXT)
         self.treeview.append_column(namecol)
 
-        self.treeview.drag_dest_set(Gtk.DestDefaults.ALL,
-            [EFFECT_TARGET_ENTRY], Gdk.DragAction.COPY)
+        # Allow the treeview to accept EFFECT_TARGET_ENTRY when drag&dropping.
+        self.treeview.enable_model_drag_dest([EFFECT_TARGET_ENTRY],
+                                             Gdk.DragAction.COPY)
+
+        # Enable reordering by drag&drop.
+        self.treeview.enable_model_drag_source(Gdk.ModifierType.BUTTON1_MASK,
+                                               [EFFECT_TARGET_ENTRY],
+                                               Gdk.DragAction.MOVE)
 
-        self.treeview.drag_dest_add_text_targets()
         self.selection = self.treeview.get_selection()
 
         self._infobar = clip_properties.createInfoBar(
@@ -238,17 +253,17 @@ class EffectProperties(Gtk.Expander, Loggable):
 
         # Connect all the widget signals
         self.selection.connect("changed", self._treeviewSelectionChangedCb)
-        self.treeview.connect("drag-leave", self._dragLeaveCb)
-        self.treeview.connect("drag-drop", self._dragDropCb)
         self.treeview.connect("drag-motion", self._dragMotionCb)
+        self.treeview.connect("drag-leave", self._dragLeaveCb)
+        self.treeview.connect("drag-data-received", self._dragDataReceivedCb)
         self.treeview.connect("query-tooltip", self._treeViewQueryTooltipCb)
         self._vcontent.connect("notify", self._vcontentNotifyCb)
         removeEffectButton.connect("clicked", self._removeEffectCb)
-        self.app.connect("new-project-loaded", self._newProjectLoadedCb)
+        self.app.project_manager.connect("new-project-loaded", self._newProjectLoadedCb)
         self.connect('notify::expanded', self._expandedCb)
         self.connected = False
 
-    def _newProjectLoadedCb(self, app, project):
+    def _newProjectLoadedCb(self, app, project, unused_fully_loaded):
         self.clip_properties.project = project
         self.selected_effects = self.timeline.selection.getSelectedEffects()
         self.updateAll()
@@ -262,22 +277,18 @@ class EffectProperties(Gtk.Expander, Loggable):
         return self._timeline
 
     def _setTimeline(self, timeline):
+        if self.connected:
+            self._timeline.selection.disconnect_by_func(self._selectionChangedCb)
+        self._timeline = timeline
         if timeline:
-            self._timeline = timeline
             self._timeline.selection.connect("selection-changed", self._selectionChangedCb)
-            self.connected = True
-        else:
-            if self.connected:
-                self._timeline.selection.disconnect_by_func(self._selectionChangedCb)
-
-            self.connected = False
-            self._timeline = None
+        self.connected = bool(timeline)
 
     timeline = property(_getTimeline, _setTimeline)
 
     def _selectionChangedCb(self, selection,):
         for clip in self.clips:
-            clip.disconnect_by_func(self._TrackElementAddedCb)
+            clip.disconnect_by_func(self._trackElementAddedCb)
             clip.disconnect_by_func(self._trackElementRemovedCb)
 
         self.selected_effects = selection.getSelectedEffects()
@@ -285,7 +296,7 @@ class EffectProperties(Gtk.Expander, Loggable):
         if selection.selected:
             self.clips = list(selection.selected)
             for clip in self.clips:
-                clip.connect("child-added", self._TrackElementAddedCb)
+                clip.connect("child-added", self._trackElementAddedCb)
                 clip.connect("child-removed", self._trackElementRemovedCb)
             self.show()
         else:
@@ -293,7 +304,7 @@ class EffectProperties(Gtk.Expander, Loggable):
             self.hide()
         self.updateAll()
 
-    def _TrackElementAddedCb(self, unused_clip, track_element):
+    def _trackElementAddedCb(self, unused_clip, track_element):
         if isinstance(track_element, GES.BaseEffect):
             selec = self.timeline.selection.getSelectedEffects()
             self.selected_effects = selec
@@ -318,51 +329,117 @@ class EffectProperties(Gtk.Expander, Loggable):
 
     def _removeEffect(self, effect):
         self.app.action_log.begin("remove effect")
-        if self._effect_config_ui:
-            self._effect_config_ui.get_children()[0].get_children()[0].resetKeyframeToggleButtons()
+        self._removeEffectConfigurationWidget()
         self.effects_properties_manager.cleanCache(effect)
         effect.get_parent().remove(effect)
-        self._updateTreeview()
         self.app.action_log.commit()
+        self._updateTreeview()
 
-    def addEffectToClip(self, clip, bin_desc):
-        media_type = self.app.effects.getFactoryFromName(bin_desc).media_type
-
+    def addEffectToClip(self, clip, factory_name, priority=None):
+        """Adds the specified effect if it can be applied to the clip."""
+        model = self.treeview.get_model()
+        media_type = self.app.effects.getFactoryFromName(factory_name).media_type
         for track_element in clip.get_children(False):
             track_type = track_element.get_track_type()
             if track_type == GES.TrackType.AUDIO and media_type == AUDIO_EFFECT or \
                     track_type == GES.TrackType.VIDEO and media_type == VIDEO_EFFECT:
-                    #Actually add the effect
-                    self.app.action_log.begin("add effect")
-                    effect = GES.Effect.new(bin_description=bin_desc)
-                    clip.add(effect)
-                    self.updateAll()
-                    self.app.current_project.timeline.commit()
-                    self.app.action_log.commit()
-                    self.app.current_project.pipeline.flushSeek()
+                # Actually add the effect
+                self.app.action_log.begin("add effect")
+                effect = GES.Effect.new(bin_description=factory_name)
+                clip.add(effect)
+                if priority is not None and priority < len(model):
+                    clip.set_top_effect_priority(effect, priority)
+                self.app.project_manager.current_project.timeline.commit()
+                self.app.action_log.commit()
+                self.app.project_manager.current_project.pipeline.flushSeek()
+                self.updateAll()
+                break
 
-                    break
+    def addEffectToCurrentSelection(self, factory_name):
+        if not self.clips or len(self.clips) > 1:
+            return
+        clip = self.clips[0]
+        # Checking that this effect can be applied on this track object
+        # Which means, it has the corresponding media_type
+        self.addEffectToClip(clip, factory_name)
 
-    def addEffectToCurrentSelection(self, bin_desc):
-        if self.clips:
-            # Trying to apply effect only on the first object of the selection
-            clip = self.clips[0]
+    def _dragMotionCb(self, unused_tree_view, unused_drag_context, unused_x, unused_y, unused_timestamp):
+        self.debug("Something is being dragged in the clip properties' effects list")
+        self.drag_highlight()
 
-            # Checking that this effect can be applied on this track object
-            # Which means, it has the corresponding media_type
-            self.addEffectToClip(clip, bin_desc)
-
-    def _dragDropCb(self, *unused_arguments):
-        self.info("An item has been dropped onto the clip properties' effects list")
-        self.addEffectToCurrentSelection(self.app.gui.effectlist.getSelectedItems())
-
-    def _dragLeaveCb(self, unused_layout, unused_context, unused_tstamp):
+    def _dragLeaveCb(self, unused_tree_view, unused_drag_context, unused_timestamp):
         self.info("The item being dragged has left the clip properties' effects list")
         self.drag_unhighlight()
 
-    def _dragMotionCb(self, unused, context, x, y, timestamp):
-        self.debug("Something is being dragged in the clip properties' effects list")
-        self.drag_highlight()
+    def _dragDataReceivedCb(self, treeview, drag_context, x, y, selection_data, unused_info, timestamp):
+        if not self.clips or len(self.clips) > 1:
+            # Indicate that a drop will not be accepted.
+            Gdk.drag_status(drag_context, 0, timestamp)
+            return
+        clip = self.clips[0]
+        model = treeview.get_model()
+        if drag_context.get_suggested_action() == Gdk.DragAction.COPY:
+            # An effect dragged probably from the effects list.
+            factory_name = str(selection_data.get_data(), "UTF-8")
+            # Target
+            dest_row = treeview.get_dest_row_at_pos(x, y)
+            if dest_row:
+                drop_path, drop_pos = dest_row
+                drop_index = drop_path.get_indices()[0]
+                if drop_pos != Gtk.TreeViewDropPosition.BEFORE:
+                    drop_index += 1
+            else:
+                # This should happen when dragging after the last row.
+                drop_index = None
+            self.addEffectToClip(clip, factory_name, drop_index)
+        elif drag_context.get_suggested_action() == Gdk.DragAction.MOVE:
+            # An effect dragged from the same treeview to change its position.
+            # Source
+            source_index = self.storemodel.source_index
+            self.storemodel.source_index = None
+            # Target
+            dest_row = treeview.get_dest_row_at_pos(x, y)
+            if dest_row:
+                drop_path, drop_pos = dest_row
+                drop_index = drop_path.get_indices()[0]
+                drop_index = self.calculateEffectPriority(source_index, drop_index, drop_pos)
+            else:
+                # This should happen when dragging after the last row.
+                drop_index = len(model) - 1
+                drop_pos = Gtk.TreeViewDropPosition.INTO_OR_BEFORE
+            self.moveEffect(clip, source_index, drop_index)
+        drag_context.finish(True, False, timestamp)
+
+    def moveEffect(self, clip, source_index, drop_index):
+        if source_index == drop_index:
+            # Noop.
+            return
+        # The paths are different.
+        effects = clip.get_top_effects()
+        effect = effects[source_index]
+        self.app.action_log.begin("move effect")
+        clip.set_top_effect_priority(effect, drop_index)
+        self.app.project_manager.current_project.timeline.commit()
+        self.app.action_log.commit()
+        self.app.project_manager.current_project.pipeline.flushSeek()
+        new_path = Gtk.TreePath.new()
+        new_path.append_index(drop_index)
+        self.updateAll(path=new_path)
+
+    @staticmethod
+    def calculateEffectPriority(source_index, drop_index, drop_pos):
+        """
+        Return where the effect from source_index will end up
+        """
+        if drop_pos in (Gtk.TreeViewDropPosition.INTO_OR_BEFORE, Gtk.TreeViewDropPosition.INTO_OR_AFTER):
+            return drop_index
+        if drop_pos == Gtk.TreeViewDropPosition.BEFORE:
+            if source_index < drop_index:
+                return drop_index - 1
+        elif drop_pos == Gtk.TreeViewDropPosition.AFTER:
+            if source_index > drop_index:
+                return drop_index + 1
+        return drop_index
 
     def _effectActiveToggleCb(self, cellrenderertoggle, path):
         iter = self.storemodel.get_iter(path)
@@ -371,31 +448,32 @@ class EffectProperties(Gtk.Expander, Loggable):
         tck_effect.set_active(not tck_effect.is_active())
         cellrenderertoggle.set_active(tck_effect.is_active())
         self._updateTreeview()
-        self.app.current_project.timeline.commit()
+        self.app.project_manager.current_project.timeline.commit()
         self.app.action_log.commit()
 
     def _expandedCb(self, expander, params):
         self.updateAll()
 
     def _treeViewQueryTooltipCb(self, view, x, y, keyboard_mode, tooltip):
-        is_row, x, y, model, path, iter_ = view.get_tooltip_context(x, y, keyboard_mode)
-
+        is_row, x, y, model, path, tree_iter = view.get_tooltip_context(x, y, keyboard_mode)
         if not is_row:
             return False
 
-        # FIXME GObject Introspection, make sure forth is the path
-        #view.set_tooltip_row(tooltip, path)
-
+        view.set_tooltip_row(tooltip, path)
+        description = self.storemodel.get_value(tree_iter, COL_DESC_TEXT)
+        bin_description = self.storemodel.get_value(tree_iter, COL_BIN_DESCRIPTION_TEXT)
+        tooltip.set_text("%s\n%s" % (bin_description, description))
         return True
 
-    def updateAll(self):
+    def updateAll(self, path=None):
         if self.get_expanded():
             if len(self.clips) == 1:
                 self._setEffectDragable()
                 self._updateTreeview()
-                self._updateEffectConfigUi()
+                if path:
+                    self.selection.select_path(path)
             else:
-                self._hideEffectConfig()
+                self._removeEffectConfigurationWidget()
                 self.storemodel.clear()
                 self._infobar.show()
             self._vcontent.show()
@@ -404,24 +482,24 @@ class EffectProperties(Gtk.Expander, Loggable):
 
     def _updateTreeview(self):
         self.storemodel.clear()
-
-        obj = self.clips[0]
-        for effect in obj.get_top_effects():
-            if not effect.props.bin_description in HIDDEN_EFFECTS:
-                asset = self.app.effects.getFactoryFromName(
-                    effect.props.bin_description)
-                to_append = [effect.props.active]
-                track_type = effect.get_track_type()
-                if track_type == GES.TrackType.AUDIO:
-                    to_append.append("Audio")
-                elif track_type == GES.TrackType.VIDEO:
-                    to_append.append("Video")
-
-                to_append.append(effect.props.bin_description)
-                to_append.append(asset.description)
-                to_append.append(effect)
-
-                self.storemodel.append(to_append)
+        clip = self.clips[0]
+        for effect in clip.get_top_effects():
+            if effect.props.bin_description in HIDDEN_EFFECTS:
+                continue
+            asset = self.app.effects.getFactoryFromName(
+                effect.props.bin_description)
+            to_append = [effect.props.active]
+            track_type = effect.get_track_type()
+            if track_type == GES.TrackType.AUDIO:
+                to_append.append("Audio")
+            elif track_type == GES.TrackType.VIDEO:
+                to_append.append("Video")
+            to_append.append(effect.props.bin_description)
+            effect_factory = self.app.effects.getFactoryFromName(effect.props.bin_description)
+            to_append.append(effect_factory.human_name)
+            to_append.append(asset.description)
+            to_append.append(effect)
+            self.storemodel.append(to_append)
 
     def _setEffectDragable(self):
         self.show()
@@ -441,33 +519,33 @@ class EffectProperties(Gtk.Expander, Loggable):
             if self._config_ui_h_pos is None:
                 self._config_ui_h_pos = self.app.gui.settings.mainWindowHeight // 3
 
-        if self.selection.get_selected()[1]:
-            effect = self.storemodel.get_value(self.selection.get_selected()[1],
-                                               COL_TRACK_EFFECT)
-
-            for widget in self._vcontent.get_children():
-                if type(widget) in [Gtk.ScrolledWindow, GstElementSettingsWidget]:
-                    self._vcontent.remove(widget)
-
-            element = effect
-            ui = self.effects_properties_manager.getEffectConfigurationUI(element)
-
-            if self._effect_config_ui:
-                self._effect_config_ui.get_children()[0].get_children()[0].resetKeyframeToggleButtons()
-
-            self._effect_config_ui = ui
-            if self._effect_config_ui:
-                self._vcontent.pack2(self._effect_config_ui, resize=False, shrink=False)
-                self._vcontent.set_position(int(self._config_ui_h_pos))
-                self._effect_config_ui.show_all()
-            self.selected_on_treeview = effect
+        model, tree_iter = self.selection.get_selected()
+        if tree_iter:
+            effect = model.get_value(tree_iter, COL_TRACK_EFFECT)
+            self._showEffectConfigurationWidget(effect)
         else:
-            self._hideEffectConfig()
+            self._removeEffectConfigurationWidget()
 
-    def _hideEffectConfig(self):
-        if self._effect_config_ui:
-            self._effect_config_ui.hide()
-            self._effect_config_ui = None
+    def _removeEffectConfigurationWidget(self):
+        if not self._effect_config_ui:
+            # Nothing to remove.
+            return
+
+        viewport = self._effect_config_ui.get_children()[0]
+        element_settings_widget = viewport.get_children()[0]
+        element_settings_widget.resetKeyframeToggleButtons()
+
+        self._vcontent.remove(self._effect_config_ui)
+        self._effect_config_ui = None
+
+    def _showEffectConfigurationWidget(self, effect):
+        self._removeEffectConfigurationWidget()
+        self._effect_config_ui = self.effects_properties_manager.getEffectConfigurationUI(effect)
+        if not self._effect_config_ui:
+            return
+        self._vcontent.pack2(self._effect_config_ui, resize=False, shrink=False)
+        self._vcontent.set_position(int(self._config_ui_h_pos))
+        self._effect_config_ui.show_all()
 
 
 class TransformationProperties(Gtk.Expander):
@@ -532,22 +610,22 @@ class TransformationProperties(Gtk.Expander):
 
     def _defaultValuesCb(self, widget):
         self.disconnectSpinButtonsFromFlush()
-        for name, spinbtn in self.spin_buttons.items():
+        for name, spinbtn in list(self.spin_buttons.items()):
             spinbtn.set_value(self.default_values[name])
         self.connectSpinButtonsToFlush()
         # FIXME Why are we looking at the gnl object directly?
         self.effect.gnl_object.props.active = False
 
     def disconnectSpinButtonsFromFlush(self):
-        for spinbtn in self.spin_buttons.values():
+        for spinbtn in list(self.spin_buttons.values()):
             spinbtn.disconnect_by_func(self._flushPipeLineCb)
 
     def connectSpinButtonsToFlush(self):
-        for spinbtn in self.spin_buttons.values():
+        for spinbtn in list(self.spin_buttons.values()):
             spinbtn.connect("output", self._flushPipeLineCb)
 
     def _updateSpinButtons(self):
-        for name, spinbtn in self.spin_buttons.items():
+        for name, spinbtn in list(self.spin_buttons.items()):
             spinbtn.set_value(self.effect.get_property(name))
 
     def _getAndConnectToEffect(self, widget_name, property_name):
@@ -579,7 +657,7 @@ class TransformationProperties(Gtk.Expander):
             box.update_from_effect(self.effect)
 
     def _flushPipeLineCb(self, widget):
-        self.app.current_project.pipeline.flushSeek()
+        self.app.project_manager.current_project.pipeline.flushSeek()
 
     def _findEffect(self, name):
         for effect in self._selected_clip.get_children(False):
@@ -593,7 +671,7 @@ class TransformationProperties(Gtk.Expander):
         if not effect:
             effect = GES.Effect.new(bin_description=name)
             self._selected_clip.add(effect)
-            tracks = self.app.projectManager.current_project.timeline.get_tracks()
+            tracks = self.app.project_manager.current_project.timeline.get_tracks()
             effect = self._findEffect(name)
             # disable the effect on default
             a = self.effect.get_gnlobject()
@@ -620,7 +698,7 @@ class TransformationProperties(Gtk.Expander):
             if self._selected_clip:
                 self._selected_clip = None
                 self.zoom_scale.set_value(1.0)
-                self.app.current_project.pipeline.flushSeek()
+                self.app.project_manager.current_project.pipeline.flushSeek()
             self.effect = None
             self.hide()
         self._updateBoxVisibility()
