@@ -38,10 +38,15 @@ def in_devel():
     rd = _get_root_dir()
     return os.path.exists(os.path.join(rd, '.git'))
 
+if "APPDIR" in os.environ:
+    basedir = os.environ["APPDIR"]
+    LIBDIR = os.path.join(basedir, 'usr', 'lib')
+    PKGDATADIR = os.path.join(basedir, 'usr', 'share', 'pitivi')
+else:
+    LIBDIR = '/usr/local/lib'
+    PKGDATADIR = '/usr/local/share/pitivi'
 
-LIBDIR = '/usr/local/lib'
-PKGDATADIR = '/usr/local/share/pitivi'
-VERSION = '0.93'
+VERSION = '0.94'
 APPNAME = 'Pitivi'
 APPURL = 'http://www.pitivi.org/'
 RELEASES_URL = 'http://pitivi.org/releases.txt'
