@@ -34,16 +34,15 @@ Effects global handling
      that are too cumbersome to use as such
   _ Complex Audio/Video Effects
 """
-import re
+
 import os
-import time
+import re
 
 from gi.repository import GLib
 from gi.repository import Gst
 from gi.repository import Gtk
 from gi.repository import Gdk
 from gi.repository import Pango
-from gi.repository import GObject
 from gi.repository import GdkPixbuf
 
 from gettext import gettext as _
@@ -51,15 +50,83 @@ from gettext import gettext as _
 from pitivi.configure import get_ui_dir, get_pixmap_dir
 from pitivi.settings import GlobalSettings
 
-import pitivi.utils.ui as dnd
 from pitivi.utils.loggable import Loggable
-from pitivi.utils.ui import SPACING, TYPE_PITIVI_EFFECT
+from pitivi.utils.ui import EFFECT_TARGET_ENTRY, SPACING
 
 from pitivi.utils.widgets import GstElementSettingsWidget, FractionWidget
 
 
-#------------- Helper to handle effect in the backend ---------------------------#
-(VIDEO_EFFECT, AUDIO_EFFECT) = range(1, 3)
+(VIDEO_EFFECT, AUDIO_EFFECT) = list(range(1, 3))
+
+AUDIO_EFFECTS_CATEGORIES = ()
+
+VIDEO_EFFECTS_CATEGORIES = (
+    (_("Colors"), (
+        # Mostly "serious" stuff that relates to correction/adjustments
+        # Fancier stuff goes into the "fancy" category
+        "cogcolorspace", "videobalance", "chromahold", "gamma",
+        "coloreffects", "exclusion", "burn", "dodge", "videomedian",
+        "frei0r-filter-color-distance", "frei0r-filter-threshold0r",
+        "frei0r-filter-contrast0r", "frei0r-filter-saturat0r",
+        "frei0r-filter-white-balance", "frei0r-filter-brightness",
+        "frei0r-filter-gamma", "frei0r-filter-invert0r",
+        "frei0r-filter-hueshift0r", "frei0r-filter-equaliz0r",
+        "frei0r-filter-bw0r", "frei0r-filter-glow",
+        "frei0r-filter-twolay0r", "frei0r-filter-3-point-color-balance",
+        "frei0r-filter-coloradj-rgb", "frei0r-filter-curves",
+        "frei0r-filter-levels", "frei0r-filter-primaries",
+        "frei0r-filter-sop-sat", "frei0r-filter-threelay0r",
+        "frei0r-filter-tint0r",
+    )),
+    (_("Compositing"), (
+        "alpha", "alphacolor", "gdkpixbufoverlay",
+        "frei0r-filter-transparency", "frei0r-filter-mask0mate",
+        "frei0r-filter-alpha0ps", "frei0r-filter-alphagrad",
+        "frei0r-filter-alphaspot", "frei0r-filter-bluescreen0r",
+        "frei0r-filter-select0r",
+    )),
+    (_("Noise & blur"), (
+        "gaussianblur", "diffuse", "dilate", "marble", "smooth",
+        "frei0r-filter-hqdn3d", "frei0r-filter-squareblur",
+        "frei0r-filter-sharpness", "frei0r-filter-edgeglow",
+        "frei0r-filter-facebl0r",
+    )),
+    (_("Analysis"), (
+        "videoanalyse", "videodetect", "videomark", "revtv",
+        "navigationtest", "frei0r-filter-rgb-parade",
+        "frei0r-filter-r", "frei0r-filter-g", "frei0r-filter-b",
+        "frei0r-filter-vectorscope", "frei0r-filter-luminance",
+        "frei0r-filter-opencvfacedetect", "frei0r-filter-pr0be",
+        "frei0r-filter-pr0file",
+    )),
+    (_("Geometry"), (
+        "cogscale", "aspectratiocrop", "cogdownsample", "videoscale",
+        "videocrop", "videoflip", "videobox", "gdkpixbufscale",
+        "kaleidoscope", "mirror", "pinch", "sphere", "square", "fisheye",
+        "stretch", "twirl", "waterriple", "rotate", "bulge", "circle",
+        "frei0r-filter-letterb0xed", "frei0r-filter-k-means-clustering",
+        "frei0r-filter-lens-correction", "frei0r-filter-defish0r",
+        "frei0r-filter-perspective", "frei0r-filter-c0rners",
+        "frei0r-filter-scale0tilt", "frei0r-filter-pixeliz0r",
+        "frei0r-filter-flippo", "frei0r-filter-3dflippo",
+    )),
+    (_("Fancy"), (
+        "rippletv", "streaktv", "radioactv", "optv", "solarize",
+        "quarktv", "vertigotv", "shagadelictv", "warptv", "dicetv",
+        "agingtv", "edgetv", "bulge", "circle", "fisheye", "tunnel",
+        "kaleidoscope", "mirror", "pinch", "sphere", "square",
+        "stretch", "twirl", "waterripple", "glfiltersobel", "chromium",
+        "frei0r-filter-sobel", "frei0r-filter-cartoon",
+        "frei0r-filter-water", "frei0r-filter-nosync0r",
+        "frei0r-filter-k-means-clustering", "frei0r-filter-delay0r",
+        "frei0r-filter-distort0r", "frei0r-filter-light-graffiti",
+        "frei0r-filter-tehroxx0r", "frei0r-filter-vertigo",
+    )),
+    (_("Time"), (
+        "videorate", "frei0r-filter-delay0r", "frei0r-filter-baltan",
+        "frei0r-filter-nervous",
+    )),
+)
 
 BLACKLISTED_EFFECTS = ["colorconvert", "coglogoinsert", "festival",
                        "alphacolor", "cogcolorspace", "videodetect",
@@ -68,111 +135,32 @@ BLACKLISTED_EFFECTS = ["colorconvert", "coglogoinsert", "festival",
 #FIXME Check if this is still true with GES
 #We should unblacklist it when #650985 is solved
 BLACKLISTED_PLUGINS = ["ldaspa"]
+
 ICON_WIDTH = 48 + 2 * 6  # 48 pixels, plus a margin on each side
 
 
-class Effect():
+class EffectFactory(object):
     """
     Factories that applies an effect on a stream
     """
-    def __init__(self, effect, media_type, categories=[_("Uncategorized")],
-                human_name="", description="", icon=None):
-        self.effectname = effect
+    def __init__(self, effect_name, media_type, categories,
+                human_name, description):
+        object.__init__(self)
+        self.effect_name = effect_name
         self.media_type = media_type
         self.categories = categories
         self.description = description
         self.human_name = human_name
-        self._icon = icon
-
-    def getHumanName(self):
-        return self.human_name
-
-    def getDescription(self):
-        return self.description
-
-    def getCategories(self):
-        return self.categories
 
 
-class EffectsHandler(object):
+class EffectsManager(object):
     """
-    Handles all the effects
+    Groups effects.
     """
+
     def __init__(self):
         object.__init__(self)
         self._pixdir = os.path.join(get_pixmap_dir(), "effects")
-        self._audio_categories_effects = ((_("All effects"), ("")),)
-        self._video_categories_effects = (
-            (_("All effects"), ("")),
-            (_("Colors"), (
-                # Mostly "serious" stuff that relates to correction/adjustments
-                # Fancier stuff goes into the "fancy" category
-                "cogcolorspace", "videobalance", "chromahold", "gamma",
-                "coloreffects", "exclusion", "burn", "dodge", "videomedian",
-                "frei0r-filter-color-distance", "frei0r-filter-threshold0r",
-                "frei0r-filter-contrast0r", "frei0r-filter-saturat0r",
-                "frei0r-filter-white-balance", "frei0r-filter-brightness",
-                "frei0r-filter-gamma", "frei0r-filter-invert0r",
-                "frei0r-filter-hueshift0r", "frei0r-filter-equaliz0r",
-                "frei0r-filter-bw0r", "frei0r-filter-glow",
-                "frei0r-filter-twolay0r", "frei0r-filter-3-point-color-balance",
-                "frei0r-filter-coloradj-rgb", "frei0r-filter-curves",
-                "frei0r-filter-levels", "frei0r-filter-primaries",
-                "frei0r-filter-sop-sat", "frei0r-filter-threelay0r",
-                "frei0r-filter-tint0r",
-            )),
-            (_("Compositing"), (
-                "alpha", "alphacolor", "gdkpixbufoverlay",
-                "frei0r-filter-transparency", "frei0r-filter-mask0mate",
-                "frei0r-filter-alpha0ps", "frei0r-filter-alphagrad",
-                "frei0r-filter-alphaspot", "frei0r-filter-bluescreen0r",
-                "frei0r-filter-select0r",
-            )),
-            (_("Noise & blur"), (
-                "gaussianblur", "diffuse", "dilate", "marble", "smooth",
-                "frei0r-filter-hqdn3d", "frei0r-filter-squareblur",
-                "frei0r-filter-sharpness", "frei0r-filter-edgeglow",
-                "frei0r-filter-facebl0r",
-            )),
-            (_("Analysis"), (
-                "videoanalyse", "videodetect", "videomark", "revtv",
-                "navigationtest", "frei0r-filter-rgb-parade",
-                "frei0r-filter-r", "frei0r-filter-g", "frei0r-filter-b",
-                "frei0r-filter-vectorscope", "frei0r-filter-luminance",
-                "frei0r-filter-opencvfacedetect", "frei0r-filter-pr0be",
-                "frei0r-filter-pr0file",
-            )),
-            (_("Geometry"), (
-                "cogscale", "aspectratiocrop", "cogdownsample", "videoscale",
-                "videocrop", "videoflip", "videobox", "gdkpixbufscale",
-                "kaleidoscope", "mirror", "pinch", "sphere", "square", "fisheye",
-                "stretch", "twirl", "waterriple", "rotate", "bulge", "circle",
-                "frei0r-filter-letterb0xed", "frei0r-filter-k-means-clustering",
-                "frei0r-filter-lens-correction", "frei0r-filter-defish0r",
-                "frei0r-filter-perspective", "frei0r-filter-c0rners",
-                "frei0r-filter-scale0tilt", "frei0r-filter-pixeliz0r",
-                "frei0r-filter-flippo", "frei0r-filter-3dflippo",
-            )),
-            (_("Fancy"), (
-                "rippletv", "streaktv", "radioactv", "optv", "solarize",
-                "quarktv", "vertigotv", "shagadelictv", "warptv", "dicetv",
-                "agingtv", "edgetv", "bulge", "circle", "fisheye", "tunnel",
-                "kaleidoscope", "mirror", "pinch", "sphere", "square",
-                "stretch", "twirl", "waterripple", "glfiltersobel", "chromium",
-                "frei0r-filter-sobel", "frei0r-filter-cartoon",
-                "frei0r-filter-water", "frei0r-filter-nosync0r",
-                "frei0r-filter-k-means-clustering", "frei0r-filter-delay0r",
-                "frei0r-filter-distort0r", "frei0r-filter-light-graffiti",
-                "frei0r-filter-tehroxx0r", "frei0r-filter-vertigo",
-            )),
-            (_("Time"), (
-                "videorate", "frei0r-filter-delay0r", "frei0r-filter-baltan",
-                "frei0r-filter-nervous",
-            )),
-            (_("Uncategorized"), ("",))
-        )
-        self._audio_categories = set([])
-        self._video_categories = set([])
         self.video_effects = []
         self.audio_effects = []
         self._effect_factories_dict = {}
@@ -183,8 +171,8 @@ class EffectsHandler(object):
         go trough the list of element factories and
         add them to the correct list filtering if necessary
         """
-        factlist = Gst.Registry.get().get_feature_list(Gst.ElementFactory)
-        for element_factory in factlist:
+        factories = Gst.Registry.get().get_feature_list(Gst.ElementFactory)
+        for element_factory in factories:
             klass = element_factory.get_klass()
             name = element_factory.get_name()
 
@@ -203,10 +191,11 @@ class EffectsHandler(object):
                     HIDDEN_EFFECTS.append(name)
                     continue
 
-                effect = Effect(name, media_type,
-                               self._getEffectCategories(name),
-                               self._getEffectName(element_factory),
-                               self._getEffectDescripton(element_factory))
+                effect = EffectFactory(name,
+                                       media_type,
+                                       categories=self._getEffectCategories(name),
+                                       human_name=self._getEffectName(element_factory),
+                                       description=self._getEffectDescripton(element_factory))
                 self._addEffectToDic(name, effect)
 
     def getAllAudioEffects(self):
@@ -226,9 +215,9 @@ class EffectsHandler(object):
 
     def getFactoryFromName(self, name):
         """
-        @param name: Factory name.
+        @param name: The bin_description of the effect.
         @type name: C{str}
-        @return: The l{Effect} corresponding to the name or None
+        @return: The l{EffectFactory} corresponding to the name or None
         """
         return self._effect_factories_dict.get(name)
 
@@ -247,28 +236,16 @@ class EffectsHandler(object):
         @return: A C{list} of name C{str} of categories corresponding the effect
         """
         categories = []
-
-        for categorie in self._audio_categories_effects:
-            for name in categorie[1]:
-                if name == effect_name:
-                    categories.append(categorie[0])
-                    self._audio_categories.append(categorie[0])
-
-        for categorie in self._video_categories_effects:
-            for name in categorie[1]:
-                if name == effect_name:
-                    categories.append(categorie[0])
-                    self._video_categories.add(categorie[0])
-
+        for category_name, effects in AUDIO_EFFECTS_CATEGORIES:
+            if effect_name in effects:
+                categories.append(category_name)
+        for category_name, effects in VIDEO_EFFECTS_CATEGORIES:
+            if effect_name in effects:
+                categories.append(category_name)
         if not categories:
             uncategorized = _("Uncategorized")
             categories.append(uncategorized)
-            self._video_categories.add(uncategorized)
-            self._audio_categories.add(uncategorized)
-
-        categories.insert(0, self._video_categories_effects[0][0])
-        categories.insert(0, self._audio_categories_effects[0][0])
-
+        categories.insert(0, _("All effects"))
         return categories
 
     def _getEffectName(self, element_factory):
@@ -277,79 +254,49 @@ class EffectsHandler(object):
         @type element_factory: L{Gst.ElementFactory}
         @return: A human readable name C{str} for the effect
         """
-        #TODO check if it is the good way to make it translatable
-        #And to filter actually!
         video = _("Video")
-        audio = _("Audio |audio")
+        audio = _("Audio")
         effect = _("effect")
-        pipe = " |"
-        uselessWords = re.compile(video + pipe + audio + pipe + effect)
+        uselessWords = re.compile(" |".join([video, audio, audio.lower(), effect]))
         return uselessWords.sub("", element_factory.get_longname()).title()
 
-    def getVideoCategories(self, aware=True):
+    def getVideoCategories(self):
         """
-        @param aware: C{True} if you want it to return only categories on which
-            there are effects on the system, else C{False}
-        @type aware: C{bool}
-        @return: All video effect categories names C{str} that are available
-            on the system if it has been filled earlier, if it hasen't it will
-            just return all categories
+        Get all video effect categories names.
         """
-        if not self._video_categories or not aware:
-            for categorie in self._video_categories_effects[1:]:
-                self._video_categories.add(categorie[0])
-
-        ret = list(self._video_categories)
-        ret.sort()
-        ret.insert(0, self._video_categories_effects[0][0])
-
-        return ret
+        return EffectsManager._getCategoriesNames(VIDEO_EFFECTS_CATEGORIES)
 
     video_categories = property(getVideoCategories)
 
-    def getAudioCategories(self, aware=True):
+    def getAudioCategories(self):
         """
-        @param aware: C{True} if you want it to return only categories on
-            which there are effects on the system, else C{False}
-        @type aware: C{bool}
-        @return: All audio effect categories names C{str}
+        Get all audio effect categories names.
         """
-        if not self._audio_categories or not aware:
-            for categorie in self._audio_categories_effects[1:]:
-                self._audio_categories.add(categorie[0])
-
-        ret = list(self._audio_categories)
-        ret.sort()
-        ret.insert(0, self._audio_categories_effects[0][0])
-
-        return ret
+        return EffectsManager._getCategoriesNames(AUDIO_EFFECTS_CATEGORIES)
 
     audio_categories = property(getAudioCategories)
 
-    def getAllCategories(self):
-        """
-        @return: All effect categories names C{str}
-        """
-        effects_categories = []
-        return effects_categories.extended(self.video_categories).extended(
-            self.audio_categories)
+    @staticmethod
+    def _getCategoriesNames(categories):
+        ret = [category_name for category_name, unused_effects in categories]
+        ret.sort()
+        ret.insert(0, _("All effects"))
+        if categories:
+            # Add Uncategorized only if there are other categories defined.
+            ret.append(_("Uncategorized"))
+        return ret
 
     def getEffectIcon(self, effect_name):
-        effect_name = effect_name + ".png"
         icon = None
         try:
             # We can afford to scale the images here, the impact is negligible
             icon = GdkPixbuf.Pixbuf.new_from_file_at_size(
-                os.path.join(self._pixdir, effect_name),
+                os.path.join(self._pixdir, effect_name + ".png"),
                 ICON_WIDTH, ICON_WIDTH)
         # An empty except clause is bad, but "gi._glib.GError" is not helpful.
         except:
-            try:
-                icon = GdkPixbuf.Pixbuf.new_from_file(
-                    os.path.join(self._pixdir, "defaultthumbnail.svg"))
-            except:
-                return None
-
+            icon = GdkPixbuf.Pixbuf.new_from_file(
+                os.path.join(self._pixdir, "defaultthumbnail.svg"))
         return icon
 
 
@@ -364,7 +311,7 @@ GlobalSettings.addConfigSection('effect-library')
  COL_EFFECT_CATEGORIES,
  COL_FACTORY,
  COL_ELEMENT_NAME,
- COL_ICON) = range(7)
+ COL_ICON) = list(range(7))
 
 
 class EffectListWidget(Gtk.VBox, Loggable):
@@ -424,17 +371,11 @@ class EffectListWidget(Gtk.VBox, Loggable):
         self.view.append_column(icon_col)
         self.view.append_column(text_col)
 
-        self.view.drag_source_set(0, [], Gdk.DragAction.COPY)
-        self.view.enable_model_drag_source(Gdk.ModifierType.BUTTON1_MASK, [("pitivi/effect", 0, TYPE_PITIVI_EFFECT)], Gdk.DragAction.COPY)
-        #self.view.drag_source_set_target_list([("pitivi/effect", 0, TYPE_PITIVI_EFFECT)])
-        self.view.drag_source_set_target_list([])
-        self.view.drag_source_add_uri_targets()
-        self.view.drag_source_add_text_targets()
+        # Make the treeview a drag source which provides effects.
+        self.view.enable_model_drag_source(Gdk.ModifierType.BUTTON1_MASK, [EFFECT_TARGET_ENTRY], Gdk.DragAction.COPY)
 
         self.view.connect("button-press-event", self._buttonPressEventCb)
         self.view.connect("select-cursor-row", self._enterPressEventCb)
-        self.view.connect("drag-begin", self._dndDragBeginCb)
-        self.view.connect("drag-end", self._dndDragEndCb)
         self.view.connect("drag-data-get", self._dndDragDataGetCb)
 
         scrollwin = Gtk.ScrolledWindow()
@@ -471,13 +412,15 @@ class EffectListWidget(Gtk.VBox, Loggable):
         for element in elements:
             name = element.get_name()
             if name not in HIDDEN_EFFECTS:
-                effect = self.app.effects.getFactoryFromName(name)
-                self.storemodel.append([effect.getHumanName(),
-                                        effect.getDescription(), effectType,
-                                        effect.getCategories(),
-                                        effect, name,
+                effect_factory = self.app.effects.getFactoryFromName(name)
+                self.storemodel.append([effect_factory.human_name,
+                                        effect_factory.description,
+                                        effectType,
+                                        effect_factory.categories,
+                                        effect_factory,
+                                        name,
                                         self.app.effects.getEffectIcon(name)])
-                self.storemodel.set_sort_column_id(COL_NAME_TEXT, Gtk.SortType.ASCENDING)
+        self.storemodel.set_sort_column_id(COL_NAME_TEXT, Gtk.SortType.ASCENDING)
 
     def populate_categories_widget(self):
         self.categoriesWidget.get_model().clear()
@@ -494,24 +437,10 @@ class EffectListWidget(Gtk.VBox, Loggable):
 
         self.categoriesWidget.set_active(0)
 
-    def _dndDragBeginCb(self, unused_view, context):
-        self.info("Drag operation begun")
-        model, paths = self.view.get_selection().get_selected_rows()
-
-        if not paths:
-            context.drag_abort(int(time.time()))
-            return
-
-        path = paths[0]
-        pixbuf = model.get_value(model.get_iter(path), COL_ICON)
-        if pixbuf:
-            Gtk.drag_set_icon_pixbuf(context, pixbuf, 0, 0)
-
-    def _dndDragEndCb(self, unused_view, unused_context):
-        self.info("Drag operation ended")
-
-    def _dndDragDataGetCb(self, unused_view, unused_context, data, unused_info, unused_timestamp):
-        data.set_uris([self.getSelectedItems()])
+    def _dndDragDataGetCb(self, unused_view, drag_context, selection_data, unused_info, unused_timestamp):
+        factory_name = bytes(self.getSelectedEffectFactoryName(), "UTF-8")
+        selection_data.set(drag_context.list_targets()[0], 0, factory_name)
+        return True
 
     def _rowUnderMouseSelected(self, view, event):
         result = view.get_path_at_pos(int(event.x), int(event.y))
@@ -523,7 +452,7 @@ class EffectListWidget(Gtk.VBox, Loggable):
         return False
 
     def _enterPressEventCb(self, unused_view, unused_event=None):
-        factory_name = self.getSelectedItems()
+        factory_name = self.getSelectedEffectFactoryName()
         if factory_name is not None:
             self.app.gui.clipconfig.effect_expander.addEffectToCurrentSelection(factory_name)
 
@@ -533,7 +462,7 @@ class EffectListWidget(Gtk.VBox, Loggable):
         if event.button == 3:
             chain_up = False
         elif event.type == getattr(Gdk.EventType, '2BUTTON_PRESS'):
-            factory_name = self.getSelectedItems()
+            factory_name = self.getSelectedEffectFactoryName()
             if factory_name is not None:
                 self.app.gui.clipconfig.effect_expander.addEffectToCurrentSelection(factory_name)
         else:
@@ -542,17 +471,16 @@ class EffectListWidget(Gtk.VBox, Loggable):
         if chain_up:
             self._draggedItems = None
         else:
-            self._draggedItems = self.getSelectedItems()
+            self._draggedItems = self.getSelectedEffectFactoryName()
 
         Gtk.TreeView.do_button_press_event(view, event)
         return True
 
-    def getSelectedItems(self):
+    def getSelectedEffectFactoryName(self):
         if self._draggedItems:
             return self._draggedItems
         model, rows = self.view.get_selection().get_selected_rows()
         path = self.modelFilter.convert_path_to_child_path(rows[0])
-
         return self.storemodel[path][COL_ELEMENT_NAME]
 
     def _toggleViewTypeCb(self, widget):
@@ -596,25 +524,20 @@ class EffectListWidget(Gtk.VBox, Loggable):
         else:
             return False
 
-    def _nothingUnderMouse(self, view, event):
-        return not bool(view.get_path_at_pos(int(event.x), int(event.y)))
-
-    def _getTargetEntries(self):
-        if self._effectType == VIDEO_EFFECT:
-            return [dnd.VIDEO_EFFECT_TARGET_ENTRY, dnd.EFFECT_TARGET_ENTRY]
-        else:
-            return [dnd.AUDIO_EFFECT_TARGET_ENTRY, dnd.EFFECT_TARGET_ENTRY]
 
 PROPS_TO_IGNORE = ['name', 'qos', 'silent', 'message']
 
 
 class EffectsPropertiesManager:
-    def __init__(self, instance):
+    """
+    @type app: L{Pitivi}
+    """
+    def __init__(self, app):
         self.cache_dict = {}
         self._current_effect_setting_ui = None
         self._current_element_values = {}
-        self.action_log = instance.action_log
-        self.app = instance
+        self.action_log = app.action_log
+        self.app = app
 
     def getEffectConfigurationUI(self, effect):
         """Permit to get a configuration GUI for the effect
@@ -663,7 +586,7 @@ class EffectsPropertiesManager:
         return effect_set_ui
 
     def _connectAllWidgetCallbacks(self, effect_settings_widget, unused_effect):
-        for prop, widget in effect_settings_widget.properties.iteritems():
+        for prop, widget in effect_settings_widget.properties.items():
             widget.connectValueChanged(self._onValueChangedCb, widget, prop)
 
     def _onSetDefaultCb(self, unused_widget, dynamic):
@@ -681,5 +604,5 @@ class EffectsPropertiesManager:
             self._current_effect_setting_ui.element.set_child_property(prop.name, value)
             self.action_log.commit()
 
-            self.app.current_project.pipeline.flushSeek()
+            self.app.project_manager.current_project.pipeline.flushSeek()
             self._current_element_values[prop.name] = value
