@@ -89,13 +89,13 @@ class PreviewWidget(Gtk.Grid, Loggable):
 
         self.discoverer = GstPbutils.Discoverer.new(Gst.SECOND)
 
-        #playbin for play pics
+        # playbin for play pics
         self.player = AssetPipeline(clip=None, name="preview-player")
         self.player.connect('eos', self._pipelineEosCb)
         self.player.connect('error', self._pipelineErrorCb)
         self.player._bus.connect('message::tag', self._tag_found_cb)
 
-        #some global variables for preview handling
+        # some global variables for preview handling
         self.is_playing = False
         self.original_dims = (PREVIEW_WIDTH, PREVIEW_HEIGHT)
         self.countinuous_seek = False
@@ -107,7 +107,9 @@ class PreviewWidget(Gtk.Grid, Loggable):
 
         # Gui elements:
         # Drawing area for video output
-        self.preview_video = ViewerWidget(realizedCb=self._on_preview_video_realize_cb)
+        self.preview_video = ViewerWidget(
+            realizedCb=self._on_preview_video_realize_cb)
+        self.preview_video.sink = self.player.video_sink
         self.preview_video.props.hexpand = minimal
         self.preview_video.props.vexpand = minimal
         self.attach(self.preview_video, 0, 0, 1, 1)
@@ -125,7 +127,7 @@ class PreviewWidget(Gtk.Grid, Loggable):
         self.play_button.connect("clicked", self._on_start_stop_clicked_cb)
         self.bbox.pack_start(self.play_button, False, False, 0)
 
-        #Scale for position handling
+        # Scale for position handling
         self.pos_adj = Gtk.Adjustment()
         self.seeker = Gtk.Scale.new(Gtk.Orientation.HORIZONTAL, self.pos_adj)
         self.seeker.connect('button-press-event', self._on_seeker_press_cb)
@@ -192,7 +194,7 @@ class PreviewWidget(Gtk.Grid, Loggable):
             self.fixme("Use a GESAsset here, and discover async with it")
             try:
                 info = self.discoverer.discover_uri(uri)
-            except Exception, e:
+            except Exception as e:
                 self.preview_cache_errors[uri] = e
                 if self.current_selected_uri == uri:
                     self.show_error(uri)
@@ -246,7 +248,6 @@ class PreviewWidget(Gtk.Grid, Loggable):
                 self.preview_video.set_size_request(w, h)
                 self.preview_video.setDisplayAspectRatio(float(video_width) / video_height)
                 self.preview_video.show()
-                self.player.connectWithViewer(self.preview_video)
                 self.bbox.show()
                 self.play_button.show()
                 self.seeker.show()
@@ -328,7 +329,7 @@ class PreviewWidget(Gtk.Grid, Loggable):
                 self.player.setState(Gst.State.PAUSED)
         elif event.type == Gdk.EventType.BUTTON_RELEASE:
             self.countinuous_seek = False
-            value = long(widget.get_value())
+            value = int(widget.get_value())
             self.player.simple_seek(value)
             if self.is_playing:
                 self.player.setState(Gst.State.PLAYING)
@@ -337,7 +338,7 @@ class PreviewWidget(Gtk.Grid, Loggable):
 
     def _on_motion_notify_cb(self, widget, event):
         if self.countinuous_seek:
-            value = long(widget.get_value())
+            value = int(widget.get_value())
             self.player.simple_seek(value)
 
     def _pipelineEosCb(self, unused_pipeline):
@@ -353,7 +354,7 @@ class PreviewWidget(Gtk.Grid, Loggable):
     def _update_position(self, *unused_args):
         if self.is_playing and not self.slider_being_used:
             curr_pos = self.player.getPosition()
-            self.pos_adj.set_value(long(curr_pos))
+            self.pos_adj.set_value(int(curr_pos))
         return self.is_playing
 
     def _on_preview_video_realize_cb(self, unused_drawing_area, unused_widget):
@@ -423,7 +424,7 @@ class PreviewWidget(Gtk.Grid, Loggable):
     def _tag_found_cb(self, abus, mess):
         tag_list = mess.parse_tag()
         tag_list.foreach(self._appendTag, None)
-        keys = self.tags.keys()
+        keys = list(self.tags.keys())
         keys.sort()
         text = self.description + "\n\n"
         for key in keys:
