@@ -36,13 +36,13 @@ import os
 import time
 import threading
 
-from urllib import unquote
+from urllib.parse import unquote
 from gettext import ngettext, gettext as _
-from urlparse import urlparse
+from urllib.parse import urlparse
 from hashlib import md5
 from gi.repository.GstPbutils import DiscovererVideoInfo
 
-from pitivi.check import GNOMEDESKTOP_SOFT_DEPENDENCY
+from pitivi.check import missing_soft_deps
 from pitivi.configure import get_ui_dir, get_pixmap_dir
 from pitivi.settings import GlobalSettings
 from pitivi.mediafilespreviewer import PreviewWidget
@@ -50,12 +50,9 @@ from pitivi.dialogs.filelisterrordialog import FileListErrorDialog
 from pitivi.dialogs.clipmediaprops import ClipMediaPropsDialog
 from pitivi.utils.ui import beautify_length
 from pitivi.utils.misc import PathWalker, quote_uri, path_from_uri
-from pitivi.utils.signal import SignalGroup
 from pitivi.utils.loggable import Loggable
 import pitivi.utils.ui as dnd
-from pitivi.utils.ui import beautify_info, info_name, SPACING
-
-from pitivi.utils.ui import TYPE_PITIVI_FILESOURCE
+from pitivi.utils.ui import beautify_info, info_name, FILESOURCE_TARGET_ENTRY, SPACING
 
 # Values used in the settings file.
 SHOW_TREEVIEW = 1
@@ -87,7 +84,7 @@ STORE_MODEL_STRUCTURE = (
  COL_ASSET,
  COL_URI,
  COL_LENGTH,
- COL_SEARCH_TEXT) = range(len(STORE_MODEL_STRUCTURE))
+ COL_SEARCH_TEXT) = list(range(len(STORE_MODEL_STRUCTURE)))
 
 ui = '''
 <ui>
@@ -137,6 +134,7 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
         builder.connect_signals(self)
         self._welcome_infobar = builder.get_object("welcome_infobar")
         self._import_warning_infobar = builder.get_object("warning_infobar")
+        self._import_warning_infobar.hide()
         self._warning_label = builder.get_object("warning_label")
         self._view_error_button = builder.get_object("view_error_button")
         toolbar = builder.get_object("medialibrary_toolbar")
@@ -180,7 +178,6 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
         self.treeview.connect("button-press-event", self._treeViewButtonPressEventCb)
         self.treeview.connect("button-release-event", self._treeViewButtonReleaseEventCb)
         self.treeview.connect("row-activated", self._itemOrRowActivatedCb)
-        self.treeview.set_property("rules_hint", True)
         self.treeview.set_headers_visible(False)
         self.treeview.set_property("search_column", COL_SEARCH_TEXT)
         tsel = self.treeview.get_selection()
@@ -251,10 +248,10 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
 
         # Connect to project.  We must remove and reset the callbacks when
         # changing project.
-        self.project_signals = SignalGroup()
-        self.app.connect("new-project-created", self._newProjectCreatedCb)
-        self.app.connect("new-project-loaded", self._newProjectLoadedCb)
-        self.app.connect("new-project-failed", self._newProjectFailedCb)
+        project_manager = self.app.project_manager
+        project_manager.connect("new-project-created", self._newProjectCreatedCb)
+        project_manager.connect("new-project-loaded", self._newProjectLoadedCb)
+        project_manager.connect("new-project-failed", self._newProjectFailedCb)
 
         # Drag and Drop
         self.drag_dest_set(Gtk.DestDefaults.DROP | Gtk.DestDefaults.MOTION,
@@ -263,8 +260,8 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
         self.drag_dest_add_uri_targets()
         self.connect("drag_data_received", self._dndDataReceivedCb)
 
-        self._setup_view_for_drag_and_drop(self.treeview, [("pitivi/file-source", 0, TYPE_PITIVI_FILESOURCE)])
-        self._setup_view_for_drag_and_drop(self.iconview, [Gtk.TargetEntry.new("pitivi/file-source", 0, TYPE_PITIVI_FILESOURCE)])
+        self._setup_view_for_drag_and_drop(self.treeview, [FILESOURCE_TARGET_ENTRY])
+        self._setup_view_for_drag_and_drop(self.iconview, [FILESOURCE_TARGET_ENTRY])
 
         # Hack so that the views have the same method as self
         self.treeview.getSelectedItems = self.getSelectedItems
@@ -300,7 +297,7 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
 
     @staticmethod
     def _getThumbnailer():
-        if not GNOMEDESKTOP_SOFT_DEPENDENCY:
+        if "GnomeDesktop" in missing_soft_deps:
             return None
         from gi.repository import GnomeDesktop
         # We need to instanciate the thumbnail factory on the main thread...
@@ -324,15 +321,16 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
         return 1
 
     def getAssetForUri(self, uri):
-        # Sanitization
-        uri = filter(lambda c: c != '\n' and c != '\r', uri)
         for path in self.modelFilter:
             asset = path[COL_ASSET]
             info = asset.get_info()
             asset_uri = info.get_uri()
             if asset_uri == uri:
+                self.debug("Found asset: %s for uri: %s" % (asset, uri))
                 return asset
 
+        self.warning("Did not find any asser for uri: %s" % (uri))
+
     def _setup_view_for_drag_and_drop(self, view, target_entries):
         view.drag_source_set(0, [], Gdk.DragAction.COPY)
         view.enable_model_drag_source(Gdk.ModifierType.BUTTON1_MASK, target_entries, Gdk.DragAction.COPY)
@@ -394,21 +392,14 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
         return icon
 
     def _connectToProject(self, project):
-        """Connect signal handlers to a project.
-
-        This first disconnects any handlers connected to an old project.
-        If project is None, this just disconnects any connected handlers.
         """
-        self.project_signals.connect(project, "asset-added", None,
-                self._assetAddedCb)
-        self.project_signals.connect(project, "asset-removed", None,
-                self._assetRemovedCb)
-        self.project_signals.connect(project, "error-loading-asset",
-                 None, self._errorCreatingAssetCb)
-        self.project_signals.connect(project, "done-importing", None,
-                self._sourcesStoppedImportingCb)
-        self.project_signals.connect(project, "start-importing", None,
-                self._sourcesStartedImportingCb)
+        Connect signal handlers to a project.
+        """
+        project.connect("asset-added", self._assetAddedCb)
+        project.connect("asset-removed", self._assetRemovedCb)
+        project.connect("error-loading-asset", self._errorCreatingAssetCb)
+        project.connect("done-importing", self._sourcesStoppedImportingCb)
+        project.connect("start-importing", self._sourcesStartedImportingCb)
 
         # The start-importing signal would have already been emited at that
         # time, make sure to catch if it is the case
@@ -453,11 +444,11 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
         close_after.set_active(self.app.settings.closeImportDialog)
 
         self._importDialog = Gtk.FileChooserDialog(title=dialogtitle, transient_for=None,
-                                           action=chooser_action)
+                                                   action=chooser_action)
 
-        self._importDialog.add_buttons(Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE,
-                                       Gtk.STOCK_ADD, Gtk.ResponseType.OK)
         self._importDialog.set_icon_name("pitivi")
+        self._importDialog.add_buttons(_("Cancel"), Gtk.ResponseType.CANCEL,
+                                       _("Add"), Gtk.ResponseType.OK)
         self._importDialog.props.extra_widget = close_after
         self._importDialog.set_default_response(Gtk.ResponseType.OK)
         self._importDialog.set_select_multiple(True)
@@ -465,7 +456,6 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
         self._importDialog.set_transient_for(self.app.gui)
         self._importDialog.set_current_folder(self.app.settings.lastImportFolder)
         self._importDialog.connect('response', self._dialogBoxResponseCb)
-        self._importDialog.connect('close', self._dialogBoxCloseCb)
         previewer = PreviewWidget(self.app.settings)
         self._importDialog.set_preview_widget(previewer)
         self._importDialog.set_use_preview_label(False)
@@ -474,7 +464,7 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
         filt_supported = Gtk.FileFilter()
         filt_known = Gtk.FileFilter()
         filt_supported.set_name(_("Supported file formats"))
-        for category, mime_types in SUPPORTED_FILE_FORMATS.iteritems():
+        for category, mime_types in SUPPORTED_FILE_FORMATS.items():
             for mime in mime_types:
                 filt_supported.add_mime_type(category + "/" + mime)
                 filt_known.add_mime_type(category + "/" + mime)
@@ -498,10 +488,10 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
         # The clip iter has a +1 offset in the progressbar label (to refer to
         # the actual # of the clip we're processing), but there is no offset
         # in the progressbar itself (to reflect the process being incomplete).
-        current_clip_iter = self.app.current_project.nb_imported_files
-        total_clips = self.app.current_project.nb_remaining_file_to_import + current_clip_iter
+        current_clip_iter = self.app.project_manager.current_project.nb_imported_files
+        total_clips = self.app.project_manager.current_project.nb_remaining_file_to_import + current_clip_iter
 
-        progressbar_text = _("Importing clip %(current_clip)d of %(total)d" %
+        progressbar_text = (_("Importing clip %(current_clip)d of %(total)d") %
             {"current_clip": current_clip_iter + 1,
             "total": total_clips})
         self._progressbar.set_text(progressbar_text)
@@ -578,7 +568,7 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
             # $HOME/.cache/thumbnails will be used."
             # Older version of the spec also mentioned $HOME/.thumbnails
             quoted_uri = quote_uri(info.get_uri())
-            thumbnail_hash = md5(quoted_uri).hexdigest()
+            thumbnail_hash = md5(quoted_uri.encode()).hexdigest()
             try:
                 thumb_dir = os.environ['XDG_CACHE_HOME']
                 thumb_64, thumb_128 = self._getThumbnailInDir(thumb_dir, thumbnail_hash)
@@ -708,7 +698,7 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
                 # Can happen if the user removed the asset in the meanwhile.
                 self.log("%s needed a thumbnail, but vanished from storemodel", uri)
 
-    ## Error Dialog Box callbacks
+    # Error Dialog Box callbacks
 
     def _errorDialogBoxCloseCb(self, dialog):
         dialog.destroy()
@@ -716,7 +706,7 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
     def _errorDialogBoxResponseCb(self, dialog, unused_response):
         dialog.destroy()
 
-    ## Import Sources Dialog Box callbacks
+    # Import Sources Dialog Box callbacks
 
     def _dialogBoxResponseCb(self, dialogbox, response):
         self.debug("response: %r", response)
@@ -726,7 +716,7 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
             self.app.settings.closeImportDialog = \
                 dialogbox.props.extra_widget.get_active()
             filenames = dialogbox.get_uris()
-            self.app.current_project.addUris(filenames)
+            self.app.project_manager.current_project.addUris(filenames)
             if self.app.settings.closeImportDialog:
                 dialogbox.destroy()
                 self._importDialog = None
@@ -734,10 +724,6 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
             dialogbox.destroy()
             self._importDialog = None
 
-    def _dialogBoxCloseCb(self, unused_dialogbox):
-        self.debug("closing")
-        self._importDialog = None
-
     def _removeSources(self):
         """
         Determine which clips are selected in the icon or list view,
@@ -745,7 +731,7 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
         """
         model = self.treeview.get_model()
         paths = self.getSelectedPaths()
-        if paths is None or paths < 1:
+        if not paths:
             return
         # use row references so we don't have to care if a path has been removed
         rows = []
@@ -756,12 +742,12 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
         self.app.action_log.begin("remove clip from source list")
         for row in rows:
             asset = model[row.get_path()][COL_ASSET]
-            self.app.current_project.remove_asset(asset)
+            self.app.project_manager.current_project.remove_asset(asset)
         self.app.action_log.commit()
 
     def _sourceIsUsed(self, asset):
         """Check if a given URI is present in the timeline"""
-        layers = self.app.current_project.timeline.get_layers()
+        layers = self.app.project_manager.current_project.timeline.get_layers()
         for layer in layers:
             for clip in layer.get_clips():
                 if clip.get_asset() == asset:
@@ -772,7 +758,7 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
         """
         Select, in the media library, unused sources in the project.
         """
-        assets = self.app.current_project.list_assets(GES.UriClip)
+        assets = self.app.project_manager.current_project.list_assets(GES.UriClip)
         unused_sources_uris = []
 
         model = self.treeview.get_model()
@@ -795,7 +781,7 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
                 else:
                     self.iconview.unselect_path(row.path)
 
-    ## UI callbacks
+    # UI callbacks
 
     def _removeClickedCb(self, unused_widget=None):
         """ Called when a user clicks on the remove button """
@@ -813,7 +799,8 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
         # Only use the first item.
         path = paths[0]
         asset = self.storemodel[path][COL_ASSET]
-        dialog = ClipMediaPropsDialog(self.app.current_project, asset)
+        dialog = ClipMediaPropsDialog(self.app.project_manager.current_project, asset)
+        dialog.dialog.set_transient_for(self.app.gui)
         dialog.run()
 
     def _warningInfoBarDismissedCb(self, unused_button):
@@ -836,8 +823,10 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
         error_dialogbox = FileListErrorDialog(*msgs)
         error_dialogbox.connect("close", self._errorDialogBoxCloseCb)
         error_dialogbox.connect("response", self._errorDialogBoxResponseCb)
+
         for uri, reason, extra in self._errors:
             error_dialogbox.addFailedFile(uri, reason, extra)
+        error_dialogbox.window.set_transient_for(self.app.gui)
         error_dialogbox.window.show()
         # Reset the error list, since the user has read them.
         self._resetErrorList()
@@ -867,9 +856,6 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
 
         return False
 
-    def _nothingUnderMouse(self, view, event):
-        return not bool(view.get_path_at_pos(int(event.x), int(event.y)))
-
     def _viewGetFirstSelected(self):
         paths = self.getSelectedPaths()
         return paths[0]
@@ -990,15 +976,15 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
                     iconview.select_path(current_cursor_pos)
 
     def _newProjectCreatedCb(self, unused_app, project):
-        if not self._project is project:
+        if self._project is not project:
             self._project = project
             self._resetErrorList()
             self.storemodel.clear()
             self._welcome_infobar.show_all()
             self._connectToProject(project)
 
-    def _newProjectLoadedCb(self, unused_pitivi, project):
-        if not self._project is project:
+    def _newProjectLoadedCb(self, unused_app, project, unused_fully_ready):
+        if self._project is not project:
             self._project = project
             self.storemodel.clear()
             self._connectToProject(project)
@@ -1008,17 +994,16 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
 
     def _newProjectFailedCb(self, unused_pitivi, unused_reason, unused_uri):
         self.storemodel.clear()
-        self.project_signals.disconnectAll()
         self._project = None
 
     def _addUris(self, uris):
-        if self.app.current_project:
-            self.app.current_project.addUris(uris)
+        if self.app.project_manager.current_project:
+            self.app.project_manager.current_project.addUris(uris)
         else:
             self.warning("Adding uris to project, but the project has changed in the meantime")
         return False
 
-    ## Drag and Drop
+    # Drag and Drop
     def _dndDataReceivedCb(self, unused_widget, unused_context, unused_x,
                            unused_y, selection, targettype, unused_time):
         self.debug("targettype: %d, selection.data: %r", targettype, selection.get_data())
@@ -1026,9 +1011,9 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
         directories = []
         filenames = []
 
-        uris = selection.get_data().split("\r\n")
+        uris = selection.get_uris()
         # Filter out the empty uris.
-        uris = filter(lambda x: x, uris)
+        uris = [x for x in uris if x]
         for raw_uri in uris:
             # Strip out NULL chars first.
             raw_uri = raw_uri.strip('\x00')
@@ -1048,9 +1033,9 @@ class MediaLibraryWidget(Gtk.VBox, Loggable):
             # Recursively import from folders that were dragged into the library
             self.app.threads.addThread(PathWalker, directories, self._addUris)
         if filenames:
-            self.app.current_project.addUris(filenames)
+            self.app.project_manager.current_project.addUris(filenames)
 
-    #used with TreeView and IconView
+    # Used with TreeView and IconView
     def _dndDragDataGetCb(self, unused_view, unused_context, data, unused_info, unused_timestamp):
         paths = self.getSelectedPaths()
         uris = [self.modelFilter[path][COL_URI] for path in paths]
