@@ -104,15 +104,8 @@ class PresetManager(object):
             file_name = self.system.getUniqueFilename(preset_name + ".json")
             file_path = os.path.join(self.user_path, file_name)
             self.presets[preset_name]["filepath"] = file_path
-        try:
-            with open(file_path, "w") as fout:
-                self._saveSection(fout, preset_name)
-        except IOError:
-            # FIXME: this can happen in two cases: a permissions error,
-            # or an invalid filename (ex: gibberish). In the latter case
-            # we should log an error message or show an infobar, and
-            # the test suite should verify this
-            pass
+        with open(file_path, "w") as fout:
+            self._saveSection(fout, preset_name)
 
     def _convertSectionNameToPresetName(self, section):
         # A section name for a ConfigParser can have any name except "default"!
@@ -137,9 +130,6 @@ class PresetManager(object):
         @param values: The values of the new preset.
         @type values: dict
         """
-        if type(name) == unicode:
-            # We need utf-8 string objects, not unicode objects!
-            name = name.encode("utf-8")
         if self.hasPreset(name):
             raise DuplicatePresetNameException(name)
         self.presets[name] = values
@@ -208,11 +198,11 @@ class PresetManager(object):
         if preset is None:
             self.cur_preset = None
             return
-        elif not preset in self.presets:
+        elif preset not in self.presets:
             return
         values = self.presets[preset]
         self.cur_preset = preset
-        for field, (setter, getter) in self.widget_map.iteritems():
+        for field, (setter, getter) in self.widget_map.items():
             if values[field] != 0:
                 setter(values[field])
             else:
@@ -228,7 +218,7 @@ class PresetManager(object):
     def _updatePreset(self):
         """Copy the values from the widgets to the preset."""
         values = self.presets[self.cur_preset]
-        for field, (setter, getter) in self.widget_map.iteritems():
+        for field, (setter, getter) in self.widget_map.items():
             values[field] = getter()
 
     def _isCurrentPresetChanged(self):
@@ -238,7 +228,7 @@ class PresetManager(object):
             return False
         values = self.presets[self.cur_preset]
         return any((values[field] != getter()
-                    for field, (setter, getter) in self.widget_map.iteritems()))
+                    for field, (setter, getter) in self.widget_map.items()))
 
     def removePreset(self, name):
         try:
@@ -293,9 +283,7 @@ class PresetManager(object):
             # default_path is the system-wide directory where the default
             # presets are installed; they are not expected to be editable.
             return False
-        else:
-            return True
-        return False
+        return True
 
     def _saveSection(self, fout, section):
         """Save the specified section into the specified file.
