@@ -40,10 +40,9 @@ from pwd import getpwuid
 from pitivi.undo.undo import UndoableAction
 from pitivi.configure import get_ui_dir
 
-from pitivi.utils.misc import quote_uri, path_from_uri, isWritable
+from pitivi.utils.misc import quote_uri, path_from_uri, isWritable, unicode_error_dialog
 from pitivi.utils.pipeline import PipelineError, Seeker
 from pitivi.utils.loggable import Loggable
-from pitivi.utils.signal import Signallable
 from pitivi.utils.pipeline import Pipeline
 from pitivi.utils.widgets import FractionWidget
 from pitivi.utils.ripple_update_group import RippleUpdateGroup
@@ -59,12 +58,39 @@ DEFAULT_MUXER = "oggmux"
 DEFAULT_VIDEO_ENCODER = "theoraenc"
 DEFAULT_AUDIO_ENCODER = "vorbisenc"
 
-#------------------ Backend classes ------------------------------------------#
+# ------------------ Backend classes ---------------------------------------- #
+
+
+class AssetRemovedAction(UndoableAction):
+    def __init__(self, project, asset):
+        UndoableAction.__init__(self)
+        self.project = project
+        self.asset = asset
+
+    def undo(self):
+        self.project.add_asset(self.asset)
+
+    def do(self):
+        self.project.remove_asset(self.asset)
+
+
+class AssetAddedAction(UndoableAction):
+    def __init__(self, project, asset):
+        UndoableAction.__init__(self)
+        self.project = project
+        self.asset = asset
+
+    def undo(self):
+        self.project.remove_asset(self.asset)
+
+    def do(self):
+        self.project.add_asset(self.asset)
 
 
 class ProjectSettingsChanged(UndoableAction):
 
     def __init__(self, project, old, new):
+        UndoableAction.__init__(self)
         self.project = project
         self.oldsettings = old
         self.newsettings = new
@@ -81,14 +107,19 @@ class ProjectSettingsChanged(UndoableAction):
 class ProjectLogObserver(UndoableAction):
 
     def __init__(self, log):
+        UndoableAction.__init__(self)
         self.log = log
 
     def startObserving(self, project):
         project.connect("notify-meta", self._settingsChangedCb)
+        project.connect("asset-added", self._assetAddedCb)
+        project.connect("asset-removed", self._assetRemovedCb)
 
     def stopObserving(self, project):
         try:
             project.disconnect_by_func(self._settingsChangedCb)
+            project.disconnect_by_func(self._assetAddedCb)
+            project.disconnect_by_func(self._assetRemovedCb)
         except Exception:
             # This can happen when we interrupt the loading of a project,
             # such as in mainwindow's _projectManagerMissingUriCb
@@ -104,27 +135,41 @@ class ProjectLogObserver(UndoableAction):
         """
         pass
 
+    def _assetAddedCb(self, project, asset):
+        action = AssetAddedAction(project, asset)
+        self.log.push(action)
 
-class ProjectManager(Signallable, Loggable):
-    __signals__ = {
-        "new-project-loading": ["uri"],
-        "new-project-created": ["project"],
-        "new-project-failed": ["uri", "exception"],
-        "new-project-loaded": ["project", "fully_ready"],
-        "save-project-failed": ["uri", "exception"],
-        "project-saved": ["project", "uri"],
-        "closing-project": ["project"],
-        "project-closed": ["project"],
-        "missing-uri": ["formatter", "uri", "factory"],
-        "reverting-to-saved": ["project"],
+    def _assetRemovedCb(self, project, asset):
+        action = AssetRemovedAction(project, asset)
+        self.log.push(action)
+
+
+class ProjectManager(GObject.Object, Loggable):
+    """
+    @type app: L{Pitivi}
+    @type current_project: L{Project}
+    @param disable_save: Whether saving is disabled to enforce using save-as.
+    """
+
+    __gsignals__ = {
+        "new-project-loading": (GObject.SIGNAL_RUN_LAST, None, (str,)),
+        "new-project-created": (GObject.SIGNAL_RUN_LAST, None, (object,)),
+        "new-project-failed": (GObject.SIGNAL_RUN_LAST, None, (str, object)),
+        "new-project-loaded": (GObject.SIGNAL_RUN_LAST, None, (object, bool)),
+        "save-project-failed": (GObject.SIGNAL_RUN_LAST, None, (str, object)),
+        "project-saved": (GObject.SIGNAL_RUN_LAST, None, (object, str)),
+        "closing-project": (GObject.SIGNAL_RUN_LAST, bool, (object,)),
+        "project-closed": (GObject.SIGNAL_RUN_LAST, None, (object,)),
+        "missing-uri": (GObject.SIGNAL_RUN_LAST, str, (object, str, object)),
+        "reverting-to-saved": (GObject.SIGNAL_RUN_LAST, bool, (object,)),
     }
 
-    def __init__(self, app_instance):
-        Signallable.__init__(self)
+    def __init__(self, app):
+        GObject.Object.__init__(self)
         Loggable.__init__(self)
-        self.app = app_instance
+        self.app = app
         self.current_project = None
-        self.disable_save = False  # Enforce "Save as" for backup and xptv files
+        self.disable_save = False
         self._backup_lock = 0
 
     def loadProject(self, uri):
@@ -147,6 +192,8 @@ class ProjectManager(Signallable, Loggable):
             self.debug('Backup file is %d secs newer: %s', time_diff, backup_path)
         except OSError:
             self.debug('Backup file does not exist: %s', backup_path)
+        except UnicodeEncodeError:
+            unicode_error_dialog()
         else:
             if time_diff > 0:
                 use_backup = self._restoreFromBackupDialog(time_diff)
@@ -156,7 +203,7 @@ class ProjectManager(Signallable, Loggable):
             self.debug('Loading project from backup: %s', uri)
 
         # Load the project:
-        self.current_project = Project(uri=uri)
+        self.current_project = Project(self.app, uri=uri)
         # For backup files and legacy formats, force the user to use "Save as"
         if use_backup or path.endswith(".xptv"):
             self.debug("Enforcing read-only mode")
@@ -176,7 +223,6 @@ class ProjectManager(Signallable, Loggable):
                       _('This might be due to a bug or an unsupported project file format. '
                       'If you were trying to add a media file to your project, '
                       'use the "Import" button instead.'))
-            # Reset projectManager and disconnect all the signals:
             self.newBlankProject(ignore_unsaved_changes=True)
             return False
 
@@ -281,7 +327,7 @@ class ProjectManager(Signallable, Loggable):
             # set to always ask the user on our behalf about overwriting, so
             # if saveProject is actually called, that means overwriting is OK.
             saved = self.current_project.save(self.current_project.timeline, uri, formatter_type, overwrite=True)
-        except Exception, e:
+        except Exception as e:
             saved = False
             self.emit("save-project-failed", uri, e)
 
@@ -342,7 +388,7 @@ class ProjectManager(Signallable, Loggable):
         # This catches errors with tarring; the GUI already shows errors while
         # saving projects (ex: permissions), so probably no GUI needed here.
         # Keep the exception generic enough to catch programming errors:
-        except Exception, e:
+        except Exception as e:
             everything_ok = False
             self.error(e)
             tar_file = path_from_uri(uri)
@@ -416,7 +462,7 @@ class ProjectManager(Signallable, Loggable):
         if emission:
             self.emit("new-project-loading", None)
         # We don't have a URI here, None means we're loading a new project
-        project = Project(_("New Project"))
+        project = Project(self.app, _("New Project"))
 
         # setting default values for project metadata
         project.author = getpwuid(os.getuid()).pw_gecos.split(",")[0]
@@ -426,6 +472,7 @@ class ProjectManager(Signallable, Loggable):
         self.emit("new-project-created", project)
 
         project.connect("project-changed", self._projectChangedCb)
+        project.setModificationState(False)
         self.emit("new-project-loaded", self.current_project, emission)
         self.time_loaded = time()
 
@@ -489,7 +536,7 @@ class ProjectManager(Signallable, Loggable):
         name, ext = os.path.splitext(uri)
         return name + ext + "~"
 
-    def _missingURICb(self, project, error, asset, unused_what=None):
+    def _missingURICb(self, project, error, asset):
         return self.emit("missing-uri", project, error, asset)
 
     def _projectLoadedCb(self, unused_project, unused_timeline):
@@ -499,7 +546,8 @@ class ProjectManager(Signallable, Loggable):
 
 
 class Project(Loggable, GES.Project):
-    """The base class for Pitivi projects
+    """
+    The base class for Pitivi projects
 
     @ivar name: The name of the project
     @type name: C{str}
@@ -527,7 +575,7 @@ class Project(Loggable, GES.Project):
                                         GObject.TYPE_PYOBJECT,))
     }
 
-    def __init__(self, name="", uri=None, **unused_kwargs):
+    def __init__(self, app, name="", uri=None, **unused_kwargs):
         """
         @param name: the name of the project
         @param uri: the uri of the project
@@ -539,6 +587,8 @@ class Project(Loggable, GES.Project):
         self.timeline = None
         self.seeker = Seeker()
         self.uri = uri
+        self.loaded = False
+        self.app = app
 
         # Follow imports
         self._dirty = False
@@ -602,9 +652,9 @@ class Project(Loggable, GES.Project):
         self._acodecsettings_cache = {}
         self._has_rendering_values = False
 
-    #-----------------#
+    # --------------- #
     # Our properties  #
-    #-----------------#
+    # --------------- #
 
     # Project specific properties
     @property
@@ -662,9 +712,10 @@ class Project(Loggable, GES.Project):
     def set_video_restriction_value(self, name, value):
         if self.video_profile.get_restriction()[0][name] != value and value:
             restriction = self.video_profile.get_restriction().copy_nth(0)
-            restriction[0][name] = value
+            restriction.set_value(name, value)
             self.video_profile.set_restriction(restriction)
             return True
+
         return False
 
     def set_audio_restriction_value(self, name, value):
@@ -800,11 +851,11 @@ class Project(Loggable, GES.Project):
     @render_scale.setter
     def render_scale(self, value):
         if value:
-            return self.set_meta("render-scale", value)
+            self.set_meta("render-scale", value)
 
-    #--------------------------------------------#
+    # ------------------------------------------ #
     # GES.Project virtual methods implementation #
-    #--------------------------------------------#
+    # ------------------------------------------ #
 
     def _handle_asset_loaded(self, asset=None, unused_asset_id=None):
         if asset and not GObject.type_is_a(asset.get_extractable_type(), GES.UriClip):
@@ -816,6 +867,9 @@ class Project(Loggable, GES.Project):
                 GObject.type_is_a(asset.get_extractable_type(), GES.UriClip)])
         if self.nb_remaining_file_to_import == 0:
             self.nb_imported_files = 0
+            # We do not take into account asset comming from project
+            if self.loaded is True:
+                self.app.action_log.commit()
             self._emitChange("done-importing")
 
     def do_asset_added(self, asset):
@@ -831,8 +885,9 @@ class Project(Loggable, GES.Project):
 
     def do_loaded(self, unused_timeline):
         """ vmethod, get called on "loaded" """
+        self.loaded = True
         self._ensureTracks()
-        #self._ensureLayer()
+        # self._ensureLayer()
 
         encoders = CachedEncoderList()
         # The project just loaded, we need to check the new
@@ -862,9 +917,9 @@ class Project(Loggable, GES.Project):
                 else:
                     self.warning("We do not handle profile: %s" % profile)
 
-    #--------------------------------------------#
+    # ------------------------------------------ #
     #               Our API                      #
-    #--------------------------------------------#
+    # ------------------------------------------ #
 
     def createTimeline(self):
         """
@@ -881,7 +936,7 @@ class Project(Loggable, GES.Project):
         self.pipeline = Pipeline()
         try:
             self.pipeline.set_timeline(self.timeline)
-        except PipelineError, e:
+        except PipelineError as e:
             self.warning("Failed to set the timeline to the pipeline: %s", e)
             return False
 
@@ -905,6 +960,7 @@ class Project(Loggable, GES.Project):
         The uris will be analyzed before being added.
         """
         # Do not try to reload URIS that we already have loaded
+        self.app.action_log.begin("Adding assets")
         for uri in uris:
             self.create_asset(quote_uri(uri), GES.UriClip)
         self._calculateNbLoadingAssets()
@@ -1009,9 +1065,9 @@ class Project(Loggable, GES.Project):
     def acodecsettings(self, value):
         self._acodecsettings_cache[self.aencoder] = value
 
-    #--------------------------------------------#
+    # ------------------------------------------ #
     #               Private methods              #
-    #--------------------------------------------#
+    # ------------------------------------------ #
 
     def _ensureTracks(self):
         if self.timeline is None:
@@ -1034,13 +1090,13 @@ class Project(Loggable, GES.Project):
             self.timeline.append_layer()
 
     def _ensureVideoRestrictions(self):
-        if not self.videowidth:
+        if self.videowidth is None:
             self.videowidth = 720
-        if not self.videoheight:
+        if self.videoheight is None:
             self.videoheight = 576
-        if not self.videorate:
+        if self.videorate is None:
             self.videorate = Gst.Fraction(25, 1)
-        if not self.videopar:
+        if self.videopar is None:
             self.videopar = Gst.Fraction(1, 1)
 
     def _ensureAudioRestrictions(self):
@@ -1079,7 +1135,7 @@ class Project(Loggable, GES.Project):
         self.nb_remaining_file_to_import = nb_remaining_file_to_import
 
 
-#----------------------- UI classes ------------------------------------------#
+# ---------------------- UI classes ----------------------------------------- #
 class ProjectSettingsDialog():
 
     def __init__(self, parent_window, project):
@@ -1141,25 +1197,19 @@ class ProjectSettingsDialog():
         # add custom display aspect ratio widget
         self.dar_fraction_widget = FractionWidget()
         self.video_properties_table.attach(self.dar_fraction_widget,
-                                           0, 1, 6, 7,
-                                           xoptions=Gtk.AttachOptions.EXPAND | Gtk.AttachOptions.FILL,
-                                           yoptions=0)
+                                           0, 6, 1, 1)
         self.dar_fraction_widget.show()
 
         # add custom pixel aspect ratio widget
         self.par_fraction_widget = FractionWidget()
         self.video_properties_table.attach(self.par_fraction_widget,
-                                           1, 2, 6, 7,
-                                           xoptions=Gtk.AttachOptions.EXPAND | Gtk.AttachOptions.FILL,
-                                           yoptions=0)
+                                           1, 6, 1, 1)
         self.par_fraction_widget.show()
 
         # add custom framerate widget
         self.frame_rate_fraction_widget = FractionWidget()
         self.video_properties_table.attach(self.frame_rate_fraction_widget,
-                                           1, 2, 2, 3,
-                                           xoptions=Gtk.AttachOptions.EXPAND | Gtk.AttachOptions.FILL,
-                                           yoptions=0)
+                                           1, 2, 1, 1)
         self.frame_rate_fraction_widget.show()
 
         # populate coboboxes with appropriate data
