@@ -25,22 +25,23 @@ Rendering-related utilities and classes
 """
 
 import os
+import subprocess
 import time
 
-from gi.repository import GLib
-from gi.repository import Gtk
-from gi.repository import Gst
 from gi.repository import GES
+from gi.repository import GLib
+from gi.repository import GObject
+from gi.repository import Gst
+from gi.repository import Gtk
 
 from gettext import gettext as _
 
 from pitivi import configure
 
-from pitivi.check import PYCANBERRA_SOFT_DEPENDENCY
+from pitivi.check import missing_soft_deps
 from pitivi.utils.loggable import Loggable
 from pitivi.utils.misc import show_user_manual, path_from_uri
 from pitivi.utils.ripple_update_group import RippleUpdateGroup
-from pitivi.utils.signal import Signallable
 from pitivi.utils.ui import model, frame_rates, audio_rates,\
     audio_channels, get_combo_value, set_combo_value, beautify_ETA
 from pitivi.utils.widgets import GstElementSettingsDialog
@@ -219,14 +220,18 @@ def factorylist(factories):
     return model(columns, data)
 
 
-#--------------------------------- Public classes -----------------------------#
-class RenderingProgressDialog(Signallable):
-    __signals__ = {
-        "pause": [],
-        "cancel": [],
+# --------------------------------- Public classes -----------------------------#
+
+class RenderingProgressDialog(GObject.Object):
+
+    __gsignals__ = {
+        "pause": (GObject.SIGNAL_RUN_LAST, None, ()),
+        "cancel": (GObject.SIGNAL_RUN_LAST, None, ()),
     }
 
     def __init__(self, app, parent):
+        GObject.Object.__init__(self)
+
         self.app = app
         self.main_render_dialog = parent
         self.builder = Gtk.Builder()
@@ -292,7 +297,7 @@ class RenderingProgressDialog(Signallable):
         self.main_render_dialog.window.show()
 
     def _playRenderedFileButtonClickedCb(self, unused_button):
-        os.system('xdg-open "%s"' % self.main_render_dialog.outfile)
+        subprocess.Popen(["xdg-open", self.main_render_dialog.outfile])
 
 
 class RenderDialog(Loggable):
@@ -726,7 +731,7 @@ class RenderDialog(Loggable):
             return None
 
         current_filesize = os.stat(path_from_uri(self.outfile)).st_size
-        length = self.app.current_project.timeline.props.duration
+        length = self.app.project_manager.current_project.timeline.props.duration
         estimated_size = float(current_filesize * float(length) / self.current_position)
         # Now let's make it human-readable (instead of octets).
         # If it's in the giga range (10⁹) instead of mega (10⁶), use 2 decimals
@@ -842,7 +847,7 @@ class RenderDialog(Loggable):
         else:
             self._time_spent_paused += time.time() - self._last_timestamp_when_pausing
             self.debug("Resuming render after %d seconds in pause", self._time_spent_paused)
-        self.app.current_project.pipeline.togglePlayback()
+        self.app.project_manager.current_project.pipeline.togglePlayback()
 
     def _destroyProgressWindow(self):
         """ Handle the completion or the cancellation of the render process. """
@@ -851,11 +856,11 @@ class RenderDialog(Loggable):
         self.window.show()  # Show the rendering dialog again
 
     def _disconnectFromGst(self):
-        for obj, id in self._gstSigId.iteritems():
+        for obj, id in self._gstSigId.items():
             obj.disconnect(id)
         self._gstSigId = {}
         try:
-            self.app.current_project.pipeline.disconnect_by_func(self._updatePositionCb)
+            self.app.project_manager.current_project.pipeline.disconnect_by_func(self._updatePositionCb)
         except TypeError:
             # The render was successful, so this was already disconnected
             pass
@@ -865,15 +870,15 @@ class RenderDialog(Loggable):
 
     @staticmethod
     def _maybePlayFinishedSound():
-        if not PYCANBERRA_SOFT_DEPENDENCY:
+        if "pycanberra" in missing_soft_deps:
             return
         import pycanberra
         canberra = pycanberra.Canberra()
         canberra.play(1, pycanberra.CA_PROP_EVENT_ID, "complete-media", None)
 
-    #------------------- Callbacks ------------------------------------------#
+    # ------------------- Callbacks ------------------------------------------ #
 
-    #-- UI callbacks
+    # -- UI callbacks
     def _okButtonClickedCb(self, unused_button, settings_attr):
         setattr(self.project, settings_attr, self.dialog.getSettings())
         self.dialog.window.destroy()
@@ -914,7 +919,7 @@ class RenderDialog(Loggable):
         bus = self._pipeline.get_bus()
         bus.add_signal_watch()
         self._gstSigId[bus] = bus.connect('message', self._busMessageCb)
-        self.app.current_project.pipeline.connect("position", self._updatePositionCb)
+        self.app.project_manager.current_project.pipeline.connect("position", self._updatePositionCb)
         # Force writing the config now, or the path will be reset
         # if the user opens the rendering dialog again
         self.app.settings.lastExportFolder = self.filebutton.get_current_folder()
@@ -931,13 +936,13 @@ class RenderDialog(Loggable):
     def _containerContextHelpClickedCb(self, unused_button):
         show_user_manual("codecscontainers")
 
-    #-- Periodic (timer) callbacks
+    # -- Periodic (timer) callbacks --
     def _updateTimeEstimateCb(self):
         if self._rendering_is_paused:
             return True  # Do nothing until we resume rendering
         elif self._is_rendering:
             timediff = time.time() - self._time_started - self._time_spent_paused
-            length = self.app.current_project.timeline.props.duration
+            length = self.app.project_manager.current_project.timeline.props.duration
             totaltime = (timediff * float(length) / float(self.current_position)) - timediff
             time_estimate = beautify_ETA(int(totaltime * Gst.SECOND))
             if time_estimate:
@@ -961,7 +966,7 @@ class RenderDialog(Loggable):
             self._filesizeEstimateTimer = None
             return False  # Stop the timer
 
-    #-- GStreamer callbacks
+    # -- GStreamer callbacks --
     def _busMessageCb(self, unused_bus, message):
         if message.type == Gst.MessageType.EOS:  # Render complete
             self.debug("got EOS message, render complete")
@@ -1006,7 +1011,7 @@ class RenderDialog(Loggable):
         if not self.progress or not position:
             return
 
-        length = self.app.current_project.timeline.props.duration
+        length = self.app.project_manager.current_project.timeline.props.duration
         fraction = float(min(position, length)) / float(length)
         self.progress.updatePosition(fraction)
 
@@ -1034,11 +1039,11 @@ class RenderDialog(Loggable):
         elif factory == get_combo_value(self.audio_encoder_combo):
             settings = self.project.acodecsettings
 
-        for propname, value in settings.iteritems():
+        for propname, value in settings.items():
             element.set_property(propname, value)
             self.debug("Setting %s to %s", propname, value)
 
-    #-- Settings changed callbacks
+    # -- Settings changed callbacks --
     def _scaleSpinbuttonChangedCb(self, unused_button):
         render_scale = self.scale_spinbutton.get_value()
         self.project.render_scale = render_scale
@@ -1046,7 +1051,7 @@ class RenderDialog(Loggable):
 
     def updateResolution(self):
         width, height = self.project.getVideoWidthAndHeight(True)
-        self.resolution_label.set_text(u"%d×%d" % (width, height))
+        self.resolution_label.set_text("%d×%d" % (width, height))
 
     def _projectSettingsButtonClickedCb(self, unused_button):
         from pitivi.project import ProjectSettingsDialog
