@@ -20,10 +20,12 @@
 # Boston, MA 02110-1301, USA.
 
 import os
-from ConfigParser import SafeConfigParser, ParsingError
+from configparser import SafeConfigParser, ParsingError
 
 from gi.repository import GLib
-from pitivi.utils.signal import Signallable
+from gi.repository import GObject
+
+from pitivi.utils.misc import unicode_error_dialog
 
 
 def get_bool_env(var):
@@ -59,44 +61,37 @@ def get_env_by_type(type_, var):
     return None
 
 
-def get_env_default(var, default):
-    value = os.getenv(var)
-    if value:
-        return value
-    return default
-
-
 def get_dir(path, autocreate=True):
     if autocreate and not os.path.exists(path):
         os.makedirs(path)
     return path
 
 
-def get_dirs(glob):
-    return [d for d in glob.split(os.path.pathsep) if os.path.exists(d)]
-
-
-def get_env_dir(var, default, unused_autocreate=True):
-    return get_dir(get_env_default(var, default))
-
-
-def get_env_dirs(var, default):
-    return get_dirs(get_env_default(var, default))
-
-
 def xdg_config_home(autocreate=True):
-    """Get the directory for storing the user's pitivi configuration"""
-    return get_dir(os.path.join(GLib.get_user_config_dir(), "pitivi"), autocreate)
+    """
+    Get the directory for storing the user's pitivi configuration
+    """
+    default = os.path.join(GLib.get_user_config_dir(), "pitivi")
+    path = os.getenv("PITIVI_USER_CONFIG_DIR", default)
+    return get_dir(path, autocreate)
 
 
 def xdg_data_home(autocreate=True):
-    """Get the directory for storing the user's data: presets, plugins, etc."""
-    return get_dir(os.path.join(GLib.get_user_data_dir(), "pitivi"), autocreate)
+    """
+    Get the directory for storing the user's data: presets, plugins, etc.
+    """
+    default = os.path.join(GLib.get_user_data_dir(), "pitivi")
+    path = os.getenv("PITIVI_USER_DATA_DIR", default)
+    return get_dir(path, autocreate)
 
 
 def xdg_cache_home(autocreate=True):
-    """Get the Pitivi cache directory"""
-    return get_dir(os.path.join(GLib.get_user_cache_dir(), "pitivi"), autocreate)
+    """
+    Get the Pitivi cache directory
+    """
+    default = os.path.join(GLib.get_user_cache_dir(), "pitivi")
+    path = os.getenv("PITIVI_USER_CACHE_DIR", default)
+    return get_dir(path, autocreate)
 
 
 class ConfigError(Exception):
@@ -104,12 +99,15 @@ class ConfigError(Exception):
 
 
 class Notification(object):
-
     """A descriptor to help with the implementation of signals"""
 
     def __init__(self, attrname):
         self.attrname = "_" + attrname
-        self.signame = attrname + "Changed"
+        self.signame = self.signalName(attrname)
+
+    @staticmethod
+    def signalName(attrname):
+        return attrname + "Changed"
 
     def __get__(self, instance, unused):
         return getattr(instance, self.attrname)
@@ -119,12 +117,14 @@ class Notification(object):
         instance.emit(self.signame)
 
 
-class GlobalSettings(Signallable):
+class GlobalSettings(GObject.Object):
     """
-    Global Pitivi settings.
+    Pitivi app settings.
+
+    The settings object loads settings from different sources, currently:
+    - the local configuration file,
+    - environment variables.
 
-    The settings object loads settings from three different sources: the
-    global configuration, the local configuration file, and the environment.
     Modules declare which settings they wish to access by calling the
     addConfigOption() class method during initialization.
 
@@ -135,24 +135,26 @@ class GlobalSettings(Signallable):
     options = {}
     environment = set()
     defaults = {}
-    __signals__ = {}
+
+    __gsignals__ = {}
 
     def __init__(self, **unused_kwargs):
-        Signallable.__init__(self)
+        GObject.Object.__init__(self)
         self._config = SafeConfigParser()
-        self._readSettingsFromGlobalConfiguration()
         self._readSettingsFromConfigurationFile()
         self._readSettingsFromEnvironmentVariables()
 
-    def _readSettingsFromGlobalConfiguration(self):
-        # ideally, this should read settings from GConf for ex
-        pass
-
     def _readSettingsFromConfigurationFile(self):
-        # This reads the configuration from the user configuration file
+        """
+        Read the configuration from the user configuration file.
+        """
+
         try:
             conf_file_path = os.path.join(xdg_config_home(), "pitivi.conf")
             self._config.read(conf_file_path)
+        except UnicodeDecodeError:
+            unicode_error_dialog()
+            return
         except ParsingError:
             return
 
@@ -160,7 +162,7 @@ class GlobalSettings(Signallable):
             if not self._config.has_section(section):
                 continue
             if key and self._config.has_option(section, key):
-                if typ == int or typ == long:
+                if typ == int or typ == int:
                     try:
                         value = self._config.getint(section, key)
                     except ValueError:
@@ -203,10 +205,16 @@ class GlobalSettings(Signallable):
                 setattr(cls, section + option, value)
 
     def _readSettingsFromEnvironmentVariables(self):
-        for (section, attrname, typ, key, env, value) in self.iterAllOptions():
+        """
+        Override options values using their registered environment variables.
+        """
+        for section, attrname, typ, key, env, value in self.iterAllOptions():
+            if not env:
+                # This option does not have an environment variable name.
+                continue
             var = get_env_by_type(typ, env)
             if var is not None:
-                setattr(self, attrname, value)
+                setattr(self, attrname, var)
 
     def _writeSettingsToConfigurationFile(self):
         conf_file_path = os.path.join(xdg_config_home(), "pitivi.conf")
@@ -221,7 +229,7 @@ class GlobalSettings(Signallable):
                     self._config.remove_option(section, key)
         try:
             file = open(conf_file_path, 'w')
-        except IOError, OSError:
+        except IOError as OSError:
             return
         self._config.write(file)
         file.close()
@@ -239,10 +247,10 @@ class GlobalSettings(Signallable):
         Iterate over all registered options
 
         @return: an iterator which yields a tuple of (attrname, type, key,
-        environment, value for each option)
+        environment, value) for each option.
         """
-        for section, options in self.options.iteritems():
-            for attrname, (typ, key, environment) in options.iteritems():
+        for section, options in list(self.options.items()):
+            for attrname, (typ, key, environment) in list(options.items()):
                 yield section, attrname, typ, key, environment, getattr(self, attrname)
 
     def isDefault(self, attrname):
@@ -280,7 +288,7 @@ class GlobalSettings(Signallable):
         signals when modified (default is False).
         @type notify: C{boolean}
         """
-        if section and not section in cls.options:
+        if section and section not in cls.options:
             raise ConfigError("You must add the section \"%s\" first." % section)
         if key and not section:
             raise ConfigError("You must specify a section for key \"%s\"" % key)
@@ -297,9 +305,14 @@ class GlobalSettings(Signallable):
         if not type_:
             type_ = type(default)
         if notify:
-            setattr(cls, attrname, Notification(attrname))
+            notification = Notification(attrname)
+            setattr(cls, attrname, notification)
             setattr(cls, "_" + attrname, default)
-            cls.__signals__[attrname + 'Changed'] = []
+            GObject.signal_new(notification.signame,
+                               cls,
+                               GObject.SIGNAL_RUN_LAST,
+                               None,
+                               ())
         else:
             setattr(cls, attrname, default)
         if section and key:
@@ -318,3 +331,8 @@ class GlobalSettings(Signallable):
         if section in cls.options:
             raise ConfigError("Duplicate Section \"%s\"." % section)
         cls.options[section] = {}
+
+    @classmethod
+    def notifiesConfigOption(cls, attrname):
+        signal_name = Notification.signalName(attrname)
+        GObject.signal_lookup(signal_name, cls)
