@@ -125,21 +125,16 @@ class BaseLayerControl(Gtk.VBox, Loggable):
 
         # Popup Menu
         self.popup = Gtk.Menu()
-        layer_delete = Gtk.ImageMenuItem.new_with_label(_("_Delete layer"))
+        layer_delete = Gtk.MenuItem.new_with_label(_("_Delete layer"))
         layer_delete.connect("activate", self._deleteLayerCb)
-        layer_delete.set_image(Gtk.Image.new_from_icon_name("edit-delete", Gtk.IconSize.MENU))
-        self.layer_up = Gtk.ImageMenuItem.new_with_label(_("Move layer up"))
+        self.layer_up = Gtk.MenuItem.new_with_label(_("Move layer up"))
         self.layer_up.connect("activate", self._moveLayerCb, -1)
-        self.layer_up.set_image(Gtk.Image.new_from_icon_name("go-up", Gtk.IconSize.MENU))
-        self.layer_down = Gtk.ImageMenuItem.new_with_label(_("Move layer down"))
+        self.layer_down = Gtk.MenuItem.new_with_label(_("Move layer down"))
         self.layer_down.connect("activate", self._moveLayerCb, 1)
-        self.layer_down.set_image(Gtk.Image.new_from_icon_name("go-down", Gtk.IconSize.MENU))
-        self.layer_first = Gtk.ImageMenuItem.new_with_label(_("Move layer to top"))
+        self.layer_first = Gtk.MenuItem.new_with_label(_("Move layer to top"))
         self.layer_first.connect("activate", self._moveLayerCb, -2)
-        self.layer_first.set_image(Gtk.Image.new_from_icon_name("go-top", Gtk.IconSize.MENU))
-        self.layer_last = Gtk.ImageMenuItem.new_with_label(_("Move layer to bottom"))
+        self.layer_last = Gtk.MenuItem.new_with_label(_("Move layer to bottom"))
         self.layer_last.connect("activate", self._moveLayerCb, 2)
-        self.layer_last.set_image(Gtk.Image.new_from_icon_name("go-bottom", Gtk.IconSize.MENU))
 
         self.popup.append(self.layer_first)
         self.popup.append(self.layer_up)
