@@ -21,7 +21,6 @@
 # Boston, MA 02110-1301, USA.
 
 from datetime import datetime, timedelta
-from gi.repository import Clutter, Gst, GLib, GdkPixbuf, Cogl, GES
 from random import randrange
 import cairo
 import numpy
@@ -29,11 +28,22 @@ import os
 import pickle
 import sqlite3
 
+from gi.repository import Clutter
+from gi.repository import Cogl
+from gi.repository import GES
+from gi.repository import GObject
+from gi.repository import GLib
+from gi.repository import GdkPixbuf
+from gi.repository import Gst
+
 # Our C module optimizing waveforms rendering
-import renderer
+try:
+    from . import renderer
+except ImportError:
+    # Running uninstalled?
+    import renderer
 
 from pitivi.settings import get_dir, xdg_cache_home
-from pitivi.utils.signal import Signallable
 from pitivi.utils.loggable import Loggable
 from pitivi.utils.misc import binary_search, filename_from_uri, quantize, quote_uri, hash_file, format_ns
 from pitivi.utils.system import CPUUsageTracker
@@ -51,6 +61,12 @@ THUMB_MARGIN_PX = 3
 WAVEFORM_UPDATE_INTERVAL = timedelta(microseconds=500000)
 MARGIN = 500  # For the waveforms, ensures we always have a little extra surface when scrolling while playing.
 
+PREVIEW_GENERATOR_SIGNALS = {
+    "done": (GObject.SIGNAL_RUN_LAST, None, ()),
+    "error": (GObject.SIGNAL_RUN_LAST, None, ()),
+}
+
+
 """
 Convention throughout this file:
 Every GES element which name could be mistaken with a UI element
@@ -63,10 +79,9 @@ class PreviewGeneratorManager():
     Manage the execution of PreviewGenerators
     """
     def __init__(self):
-        self._cpipeline = {
-            GES.TrackType.AUDIO: None,
-            GES.TrackType.VIDEO: None
-        }
+        # The current PreviewGenerator per GES.TrackType.
+        self._cpipeline = {}
+        # The queue of PreviewGenerators.
         self._pipelines = {
             GES.TrackType.AUDIO: [],
             GES.TrackType.VIDEO: []
@@ -75,32 +90,33 @@ class PreviewGeneratorManager():
     def addPipeline(self, pipeline):
         track_type = pipeline.track_type
 
+        current_pipeline = self._cpipeline.get(track_type)
         if pipeline in self._pipelines[track_type] or \
-                pipeline is self._cpipeline[track_type]:
+                pipeline is current_pipeline:
+            # Already in the queue or already processing.
             return
 
-        if not self._pipelines[track_type] and self._cpipeline[track_type] is None:
+        if not self._pipelines[track_type] and current_pipeline is None:
             self._setPipeline(pipeline)
         else:
             self._pipelines[track_type].insert(0, pipeline)
 
     def _setPipeline(self, pipeline):
         self._cpipeline[pipeline.track_type] = pipeline
-        PreviewGenerator.connect(pipeline, "done", self._nextPipeline)
+        pipeline.connect("done", self._nextPipeline)
         pipeline.startGeneration()
 
     def _nextPipeline(self, controlled):
         track_type = controlled.track_type
-        if self._cpipeline[track_type]:
-            PreviewGenerator.disconnect_by_function(self._cpipeline[track_type],
-                                                    self._nextPipeline)
-            self._cpipeline[track_type] = None
+        pipeline = self._cpipeline.pop(track_type, None)
+        if pipeline:
+            pipeline.disconnect_by_func(self._nextPipeline)
 
         if self._pipelines[track_type]:
             self._setPipeline(self._pipelines[track_type].pop())
 
 
-class PreviewGenerator(Signallable):
+class PreviewGenerator(object):
     """
     Interface to be implemented by classes that generate previews
     It is need to implement it so PreviewGeneratorManager can manage
@@ -111,16 +127,10 @@ class PreviewGenerator(Signallable):
     # all the generators.
     __manager = PreviewGeneratorManager()
 
-    __signals__ = {
-        "done": [],
-        "error": [],
-    }
-
     def __init__(self, track_type):
         """
         @param track_type : GES.TrackType.*
         """
-        Signallable.__init__(self)
         self.track_type = track_type
 
     def startGeneration(self):
@@ -137,16 +147,21 @@ class PreviewGenerator(Signallable):
 
 
 class VideoPreviewer(Clutter.ScrollActor, PreviewGenerator, Zoomable, Loggable):
+
+    # We could define them in PreviewGenerator, but then for some reason they
+    # are ignored.
+    __gsignals__ = PREVIEW_GENERATOR_SIGNALS
+
     def __init__(self, bElement, timeline):
         """
         @param bElement : the backend GES.TrackElement
         @param track : the track to which the bElement belongs
         @param timeline : the containing graphic timeline.
         """
-        Zoomable.__init__(self)
         Clutter.ScrollActor.__init__(self)
-        Loggable.__init__(self)
         PreviewGenerator.__init__(self, GES.TrackType.VIDEO)
+        Zoomable.__init__(self)
+        Loggable.__init__(self)
 
         # Variables related to the timeline objects
         self.timeline = timeline
@@ -156,13 +171,12 @@ class VideoPreviewer(Clutter.ScrollActor, PreviewGenerator, Zoomable, Loggable):
 
         # Variables related to thumbnailing
         self.wishlist = []
-        self._callback_id = None
         self._thumb_cb_id = None
         self._allAnimated = False
         self._running = False
         # We should have one thumbnail per thumb_period.
         # TODO: get this from the user settings
-        self.thumb_period = long(0.5 * Gst.SECOND)
+        self.thumb_period = int(0.5 * Gst.SECOND)
         self.thumb_height = EXPANDED_SIZE - 2 * THUMB_MARGIN_PX
         self.thumb_width = None  # will be set by self._setupPipeline()
 
@@ -183,11 +197,7 @@ class VideoPreviewer(Clutter.ScrollActor, PreviewGenerator, Zoomable, Loggable):
         self.becomeControlled()
 
     # Internal API
-
     def _update(self, unused_msg_source=None):
-        if self._callback_id:
-            GLib.source_remove(self._callback_id)
-
         if self.thumb_width:
             self._addVisibleThumbnails()
             if self.wishlist:
@@ -275,7 +285,7 @@ class VideoPreviewer(Clutter.ScrollActor, PreviewGenerator, Zoomable, Loggable):
         else:
             self.duration = duration
 
-        self.queue = range(0, duration, self.thumb_period)
+        self.queue = list(range(0, duration, self.thumb_period))
 
         self._checkCPU()
 
@@ -519,7 +529,7 @@ class VideoPreviewer(Clutter.ScrollActor, PreviewGenerator, Zoomable, Loggable):
             self.pipeline.set_state(Gst.State.NULL)
             self.pipeline.get_state(Gst.CLOCK_TIME_NONE)
             self.pipeline = None
-        PreviewGenerator.emit(self, "done")
+        self.emit("done")
 
     def cleanup(self):
         self.stopGeneration()
@@ -533,7 +543,6 @@ class Thumbnail(Clutter.Actor):
         self.props.content = image
         self.width = width
         self.height = height
-        #self.set_background_color(Clutter.Color.new(0, 100, 150, 100))
         self.set_opacity(0)
         self.set_size(self.width, self.height)
         self.has_pixel_data = False
@@ -615,7 +624,7 @@ class ThumbnailCache(Loggable):
             self.warning("JPEG compression failed")
             return
         blob = sqlite3.Binary(jpeg)
-        #Replace if the key already existed
+        # Replace if a row with the same time already exists.
         self._cur.execute("DELETE FROM Thumbs WHERE  time=?", (key,))
         self._cur.execute("INSERT INTO Thumbs VALUES (?,?)", (key, blob,))
 
@@ -721,11 +730,15 @@ class AudioPreviewer(Clutter.Actor, PreviewGenerator, Zoomable, Loggable):
     """
     Audio previewer based on the results from the "level" gstreamer element.
     """
+
+    __gsignals__ = PREVIEW_GENERATOR_SIGNALS
+
     def __init__(self, bElement, timeline):
         Clutter.Actor.__init__(self)
+        PreviewGenerator.__init__(self, GES.TrackType.AUDIO)
         Zoomable.__init__(self)
         Loggable.__init__(self)
-        PreviewGenerator.__init__(self, GES.TrackType.AUDIO)
+
         self.pipeline = None
         self.discovered = False
         self.bElement = bElement
@@ -738,7 +751,7 @@ class AudioPreviewer(Clutter.Actor, PreviewGenerator, Zoomable, Loggable):
         self.set_content(self.canvas)
         self.width = 0
         self._num_failures = 0
-        self.lastUpdate = datetime.now()
+        self.lastUpdate = None
 
         self.current_geometry = (-1, -1)
 
@@ -793,8 +806,8 @@ class AudioPreviewer(Clutter.Actor, PreviewGenerator, Zoomable, Loggable):
     def _maybeUpdate(self):
         if self.discovered:
             self.log('Checking if the waveform for "%s" needs to be redrawn' % self._uri)
-            if datetime.now() - self.lastUpdate > WAVEFORM_UPDATE_INTERVAL:
-                self.lastUpdate = datetime.now()
+            if self.lastUpdate is None or datetime.now() - self.lastUpdate > WAVEFORM_UPDATE_INTERVAL:
+                # Last update was long ago or never.
                 self._compute_geometry()
             else:
                 if self._callback_id:
@@ -802,7 +815,9 @@ class AudioPreviewer(Clutter.Actor, PreviewGenerator, Zoomable, Loggable):
                 self._callback_id = GLib.timeout_add(500, self._compute_geometry)
 
     def _compute_geometry(self):
+        self._callback_id = 0
         self.log("Computing the clip's geometry for waveforms")
+        self.lastUpdate = datetime.now()
         width_px = self.nsToPixel(self.bElement.props.duration)
         if width_px <= 0:
             return
@@ -844,7 +859,7 @@ class AudioPreviewer(Clutter.Actor, PreviewGenerator, Zoomable, Loggable):
             samples = numpy.array(self.peaks[0])
 
         self.samples = samples.tolist()
-        f = open(self.wavefile, 'w')
+        f = open(self.wavefile, 'wb')
         pickle.dump(self.samples, f)
 
     def _startRendering(self):
@@ -869,7 +884,7 @@ class AudioPreviewer(Clutter.Actor, PreviewGenerator, Zoomable, Loggable):
                 if self.peaks is None:
                     self.peaks = []
                     for channel in p:
-                        self.peaks.append([0] * self.nSamples)
+                        self.peaks.append([0] * int(self.nSamples))
 
                 pos = int(st / 10000000)
                 if pos >= len(self.peaks[0]):
@@ -963,7 +978,7 @@ class AudioPreviewer(Clutter.Actor, PreviewGenerator, Zoomable, Loggable):
             self.pipeline.set_state(Gst.State.NULL)
             self.pipeline.get_state(Gst.CLOCK_TIME_NONE)
 
-        PreviewGenerator.emit(self, "done")
+        self.emit("done")
 
     def cleanup(self):
         self.stopGeneration()
