@@ -137,7 +137,7 @@ class ScaleRuler(Gtk.DrawingArea, Zoomable, Loggable):
             GLib.source_remove(self.callback_id_scroll)
         self.callback_id_scroll = GLib.timeout_add(100, self._maybeUpdate)
 
-## Zoomable interface override
+# Zoomable interface override
 
     def _maybeUpdate(self):
         self.queue_draw()
@@ -150,7 +150,7 @@ class ScaleRuler(Gtk.DrawingArea, Zoomable, Loggable):
             GLib.source_remove(self.callback_id)
         self.callback_id = GLib.timeout_add(100, self._maybeUpdate)
 
-## timeline position changed method
+# Timeline position changed method
 
     def setPipeline(self, pipeline):
         pipeline.connect('position', self.timelinePositionCb)
@@ -159,7 +159,7 @@ class ScaleRuler(Gtk.DrawingArea, Zoomable, Loggable):
         self.position = position
         self.queue_draw()
 
-## Gtk.Widget overrides
+# Gtk.Widget overrides
     def configureEventCb(self, widget, unused_event, unused_data=None):
         width = widget.get_allocated_width()
         height = widget.get_allocated_height()
@@ -244,7 +244,7 @@ class ScaleRuler(Gtk.DrawingArea, Zoomable, Loggable):
         self.ns_per_frame = float(1 / self.frame_rate) * Gst.SECOND
         self.scales = (float(2 / rate), float(5 / rate), float(10 / rate)) + SCALES
 
-## Drawing methods
+# Drawing methods
 
     def drawBackground(self, context):
         style = self.get_style_context()
@@ -302,7 +302,7 @@ class ScaleRuler(Gtk.DrawingArea, Zoomable, Loggable):
 
     def drawTimes(self, context, offset, spacing, scale):
         # figure out what the optimal offset is
-        interval = long(Gst.SECOND * scale)
+        interval = int(Gst.SECOND * scale)
         current_time = self.pixelToNs(self.pixbuf_offset)
         paintpos = TIMES_LEFT_MARGIN_PIXELS
         if offset > 0:
@@ -325,7 +325,7 @@ class ScaleRuler(Gtk.DrawingArea, Zoomable, Loggable):
         width = context.get_target().get_width()
         while paintpos < width:
             context.move_to(int(paintpos), 1 - y_bearing)
-            current = split(time_to_string(long(current_time)))
+            current = split(time_to_string(int(current_time)))
             self._drawTime(context, current, previous, millis)
             previous = current
             paintpos += spacing
