@@ -22,24 +22,30 @@
 
 import os
 
-from gi.repository import GtkClutter
+from gettext import gettext as _
 
-from gi.repository import Gst, GES, GObject, Clutter, Gtk, GLib, Gdk
+from gi.repository import Clutter
+from gi.repository import GES
+from gi.repository import GLib
+from gi.repository import GObject
+from gi.repository import Gdk
+from gi.repository import Gst
+from gi.repository import Gtk
+from gi.repository import GtkClutter
 
 from pitivi.autoaligner import AlignmentProgressDialog, AutoAligner
 from pitivi.configure import get_ui_dir
 from pitivi.dialogs.prefs import PreferencesDialog
 from pitivi.settings import GlobalSettings
+from pitivi.timeline.controls import ControlContainer
+from pitivi.timeline.elements import URISourceElement, TransitionElement, Ghostclip
+from pitivi.timeline.ruler import ScaleRuler
 from pitivi.utils.loggable import Loggable
+from pitivi.utils.pipeline import PipelineError
 from pitivi.utils.timeline import Zoomable, Selection, SELECT, TimelineError
-from pitivi.utils.ui import alter_style_class, EXPANDED_SIZE, SPACING, PLAYHEAD_COLOR, PLAYHEAD_WIDTH, CONTROL_WIDTH
+from pitivi.utils.ui import alter_style_class, EFFECT_TARGET_ENTRY, EXPANDED_SIZE, SPACING, PLAYHEAD_COLOR, PLAYHEAD_WIDTH, CONTROL_WIDTH
 from pitivi.utils.widgets import ZoomBox
 
-from ruler import ScaleRuler
-from gettext import gettext as _
-from pitivi.utils.pipeline import PipelineError
-from elements import URISourceElement, TransitionElement, Ghostclip
-from controls import ControlContainer
 
 GlobalSettings.addConfigOption('edgeSnapDeadband',
     section="user-interface",
@@ -66,8 +72,6 @@ PreferencesDialog.addNumericPreference('imageClipLength',
     description=_("Default clip length (in miliseconds) of images when inserting on the timeline."),
     lower=1)
 
-TARGET_TYPE_URI_LIST = 80
-
 # Colors
 TIMELINE_BACKGROUND_COLOR = Clutter.Color.new(31, 30, 33, 255)
 SELECTION_MARQUEE_COLOR = Clutter.Color.new(100, 100, 100, 200)
@@ -374,14 +378,9 @@ class TimelineStage(Clutter.ScrollActor, Zoomable, Loggable):
         self.lastPosition = position
 
     def _updatePlayHead(self):
-        if self._project and self._project.pipeline.getState() != Gst.State.PLAYING:
-            self.playhead.save_easing_state()
-            self.playhead.set_easing_duration(600)
         height = len(self.bTimeline.get_layers()) * (EXPANDED_SIZE + SPACING) * 2
         self.playhead.set_size(PLAYHEAD_WIDTH, height)
         self._movePlayhead(self.lastPosition)
-        if self._project and self._project.pipeline.getState() != Gst.State.PLAYING:
-            self.playhead.restore_easing_state()
 
     def _movePlayhead(self, position):
         self.playhead.props.x = self.nsToPixel(position)
@@ -425,7 +424,7 @@ class TimelineStage(Clutter.ScrollActor, Zoomable, Loggable):
 
         self.elements.append(element)
 
-        self._setElementX(element)
+        self._setElementX(element, ease=True)
         self._setElementY(element)
 
         self.insert_child_above(element, marker)
@@ -452,7 +451,7 @@ class TimelineStage(Clutter.ScrollActor, Zoomable, Loggable):
                 return element
         return None
 
-    def _setElementX(self, element, ease=True):
+    def _setElementX(self, element, ease=False):
         if ease:
             element.save_easing_state()
             element.set_easing_duration(600)
@@ -603,7 +602,7 @@ class TimelineStage(Clutter.ScrollActor, Zoomable, Loggable):
 
     def _trackAddedCb(self, unused_timeline, track):
         self._connectTrack(track)
-        self._container.app.current_project.update_restriction_caps()
+        self._container.app.project_manager.current_project.update_restriction_caps()
 
     def _trackRemovedCb(self, unused_timeline, track):
         self._disconnectTrack(track)
@@ -623,20 +622,16 @@ class TimelineStage(Clutter.ScrollActor, Zoomable, Loggable):
     def _elementStartChangedCb(self, unused_bElement, unused_start, element):
         self._updateSize()
         self.allowSeek = False
-
-        if element.isDragged:
-            self._setElementX(element, ease=False)
-        else:
-            self._setElementX(element)
+        self._setElementX(element)
 
     def _elementDurationChangedCb(self, unused_bElement, unused_duration, element):
         self._updateSize()
         self.allowSeek = False
-        element.update(False)
+        element.update(ease=False)
 
     def _elementInPointChangedCb(self, unused_bElement, unused_inpoint, element):
         self.allowSeek = False
-        self._setElementX(element, ease=False)
+        self._setElementX(element)
 
     def _layerPriorityChangedCb(self, unused_layer, unused_priority):
         self._redraw()
@@ -921,9 +916,9 @@ class TimelineContainer(Gtk.Grid, Zoomable, Loggable):
         return True
 
     def _setUpDragAndDrop(self):
-        dnd_list = [Gtk.TargetEntry.new('text/uri-list', Gtk.TargetFlags.OTHER_APP, TARGET_TYPE_URI_LIST)]
-
-        self.drag_dest_set(0, dnd_list, Gdk.DragAction.COPY)
+        # To be able to receive effects dragged on clips.
+        self.drag_dest_set(0, [EFFECT_TARGET_ENTRY], Gdk.DragAction.COPY)
+        # To be able to receive assets dragged from the media library.
         self.drag_dest_add_uri_targets()
 
         self.connect('drag-motion', self._dragMotionCb)
@@ -983,10 +978,6 @@ class TimelineContainer(Gtk.Grid, Zoomable, Loggable):
             ("ZoomFit", Gtk.STOCK_ZOOM_FIT, None,
             "<Control>0", zoom_fit_tooltip, self._zoomFitCb),
 
-            ("Screenshot", None, _("Export current frame..."),
-            None, _("Export the frame at the current playhead "
-                    "position as an image file."), self._screenshotCb),
-
             # Alternate keyboard shortcuts to the actions above
             ("ControlEqualAccel", Gtk.STOCK_ZOOM_IN, None,
             "<Control>equal", zoom_in_tooltip, self._zoomInCb),
@@ -1120,7 +1111,7 @@ class TimelineContainer(Gtk.Grid, Zoomable, Loggable):
         canvas_width = self.embed.get_allocation().width - CONTROL_WIDTH
         try:
             new_pos = Zoomable.nsToPixel(self._project.pipeline.getPosition())
-        except PipelineError, e:
+        except PipelineError as e:
             self.info("Pipeline error: %s", e)
             return
         except AttributeError:  # Standalone, no pipeline.
@@ -1132,7 +1123,7 @@ class TimelineContainer(Gtk.Grid, Zoomable, Loggable):
         if self.bTimeline:
             self.app.action_log.begin("delete clip")
 
-            #FIXME GES port: Handle unlocked TrackElement-s
+            # FIXME GES port: Handle unlocked TrackElement-s
             for clip in self.timeline.selection:
                 layer = clip.get_layer()
                 layer.remove_clip(clip)
@@ -1204,7 +1195,7 @@ class TimelineContainer(Gtk.Grid, Zoomable, Loggable):
         try:
             progress_meter = auto_aligner.start()
             progress_meter.addWatcher(progress_dialog.updatePosition)
-        except Exception, e:
+        except Exception as e:
             self.error("Could not start the autoaligner: %s" % e)
             progress_dialog.window.destroy()
 
@@ -1265,41 +1256,6 @@ class TimelineContainer(Gtk.Grid, Zoomable, Loggable):
         x += self.timeline.get_scroll_point().x
         return x - CONTROL_WIDTH, y - height
 
-    def _showSaveScreenshotDialog(self):
-        """
-        Show a filechooser dialog asking the user where to save the snapshot
-        and what file type to use.
-
-        Returns a list containing the full path and the mimetype if successful,
-        returns none otherwise.
-        """
-        chooser = Gtk.FileChooserDialog(title=_("Save As..."), transient_for=self.app.gui,
-            action=Gtk.FileChooserAction.SAVE)
-        chooser.add_buttons(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
-            Gtk.STOCK_SAVE, Gtk.ResponseType.OK)
-        chooser.set_icon_name("pitivi")
-        chooser.set_select_multiple(False)
-        chooser.set_current_name(_("Untitled"))
-        chooser.props.do_overwrite_confirmation = True
-        formats = {_("PNG image"): ["image/png", ("png",)],
-            _("JPEG image"): ["image/jpeg", ("jpg", "jpeg")]}
-        for format in formats:
-            filt = Gtk.FileFilter()
-            filt.set_name(format)
-            filt.add_mime_type(formats.get(format)[0])
-            chooser.add_filter(filt)
-        response = chooser.run()
-        if response == Gtk.ResponseType.OK:
-            chosen_format = formats.get(chooser.get_filter().get_name())
-            chosen_ext = chosen_format[1][0]
-            chosen_mime = chosen_format[0]
-            uri = os.path.join(chooser.get_current_folder(), chooser.get_filename())
-            ret = [uri + "." + chosen_ext, chosen_mime]
-        else:
-            ret = None
-        chooser.destroy()
-        return ret
-
     # Zoomable
 
     def zoomChanged(self):
@@ -1425,32 +1381,23 @@ class TimelineContainer(Gtk.Grid, Zoomable, Loggable):
     def _zoomFitCb(self, unused, unused_2=None):
         self._setBestZoomRatio(allow_zoom_in=True)
 
-    def _screenshotCb(self, unused_action):
-        """
-        Export a snapshot of the current frame as an image file.
-        """
-        foo = self._showSaveScreenshotDialog()
-        if foo:
-            path, mime = foo[0], foo[1]
-            self._project.pipeline.save_thumbnail(-1, -1, mime, path)
-
     def _scrollEventCb(self, unused_embed, event):
-        deltas = event.get_scroll_deltas()
+        unused_res, delta_x, delta_y = event.get_scroll_deltas()
         if event.state & Gdk.ModifierType.CONTROL_MASK:
-            if deltas[2] < 0:
+            if delta_y < 0:
                 Zoomable.zoomIn()
-            elif deltas[2] > 0:
+            elif delta_y > 0:
                 Zoomable.zoomOut()
             self._scrollToPlayhead()
         elif event.state & Gdk.ModifierType.SHIFT_MASK:
-            if deltas[2] > 0:
+            if delta_y > 0:
                 self.scroll_down()
-            elif deltas[2] < 0:
+            elif delta_y < 0:
                 self.scroll_up()
         else:
-            if deltas[2] > 0:
+            if delta_y > 0:
                 self.scroll_right()
-            elif deltas[2] < 0:
+            elif delta_y < 0:
                 self.scroll_left()
         self.scrolled += 1
 
@@ -1478,22 +1425,42 @@ class TimelineContainer(Gtk.Grid, Zoomable, Loggable):
 
     # drag and drop
 
-    def _dragDataReceivedCb(self, widget, context, unused_x, unused_y, data, unused_info, time):
+    def _dragMotionCb(self, widget, context, x, y, timestamp):
+        target = widget.drag_dest_find_target(context, None)
         if not self.dropDataReady:
-            if data.get_length() > 0:
-                if not self.dropOccured:
-                    self.timeline.resetGhostClips()
-                self.dropData = data.get_uris()
-                self.dropDataReady = True
-
-        if self.dropOccured:
-            self.dropOccured = False
-            Gtk.drag_finish(context, True, False, time)
-            self._dragLeaveCb(widget, context, time)
+            # We don't know yet the details of what's being dragged.
+            # Ask for the details.
+            widget.drag_get_data(context, target, timestamp)
+            Gdk.drag_status(context, 0, timestamp)
         else:
-            self.isDraggedClip = True
+            if self.isDraggedClip:
+                # From the media library
+                x, y = self.transposeXY(x, y)
+                if not self.timeline.ghostClips:
+                    for uri in self.dropData:
+                        asset = self.app.gui.medialibrary.getAssetForUri(uri)
+                        if asset is None:
+                            self.isDraggedClip = False
+                            break
+                        self.timeline.addGhostClip(asset, x, y)
+                self.timeline.updateGhostClips(x, y)
 
-    def _dragDropCb(self, widget, context, x, y, time):
+            Gdk.drag_status(context, Gdk.DragAction.COPY, timestamp)
+            if not self.dropHighlight:
+                widget.drag_highlight()
+                self.dropHighlight = True
+        return True
+
+    def _dragLeaveCb(self, widget, unused_context, unused_timestamp):
+        if self.dropHighlight:
+            widget.drag_unhighlight()
+            self.dropHighlight = False
+        # Cleanup because the user might have moved the mouse cursor outside
+        # and abandon this widget.
+        self.dropDataReady = False
+        self.timeline.removeGhostClips()
+
+    def _dragDropCb(self, widget, context, x, y, timestamp):
         # Same as in insertEnd: this value changes during insertion, snapshot it
         zoom_was_fitted = self.zoomed_fitted
 
@@ -1501,10 +1468,12 @@ class TimelineContainer(Gtk.Grid, Zoomable, Loggable):
         y -= self.ruler.get_allocation().height
         if target.name() == "text/uri-list":
             self.dropOccured = True
-            widget.drag_get_data(context, target, time)
+            widget.drag_get_data(context, target, timestamp)
             if self.isDraggedClip:
                 self.timeline.convertGhostClips()
                 self.timeline.resetGhostClips()
+                self.dropData = None
+                self.dropDataReady = False
                 if zoom_was_fitted:
                     self._setBestZoomRatio()
                 else:
@@ -1513,49 +1482,33 @@ class TimelineContainer(Gtk.Grid, Zoomable, Loggable):
                     # disorientation & clarifies to users where the clip starts
                     margin = min(x, 50)
                     self.scrollToPixel(x - margin)
-            else:
-                actor = self.stage.get_actor_at_pos(Clutter.PickMode.ALL, x, y)
-                try:
-                    bElement = actor.bElement
-                    self.app.gui.clipconfig.effect_expander.addEffectToClip(bElement.get_parent(), self.dropData[0])
-                except AttributeError:
-                    return False
-            return True
-        else:
-            return False
-
-    def _dragMotionCb(self, widget, context, x, y, time):
-        target = widget.drag_dest_find_target(context, None)
-        if target.name() not in ["text/uri-list", "pitivi/effect"]:
-            return False
-        if not self.dropDataReady:
-            widget.drag_get_data(context, target, time)
-            Gdk.drag_status(context, 0, time)
-        else:
-            x, y = self.transposeXY(x, y)
-
-            # dragged from the media library
-            if not self.timeline.ghostClips and self.isDraggedClip:
-                for uri in self.dropData:
-                    asset = self.app.gui.medialibrary.getAssetForUri(uri)
-                    if asset is None:
-                        self.isDraggedClip = False
-                        break
-                    self.timeline.addGhostClip(asset, x, y)
-
-            if self.isDraggedClip:
-                self.timeline.updateGhostClips(x, y)
-
-            Gdk.drag_status(context, Gdk.DragAction.COPY, time)
-            if not self.dropHighlight:
-                widget.drag_highlight()
-                self.dropHighlight = True
+        elif target.name() == "pitivi/effect":
+            actor = self.stage.get_actor_at_pos(Clutter.PickMode.REACTIVE, x, y)
+            bElement = actor.bElement
+            clip = bElement.get_parent()
+            factory_name = self.dropData
+            self.app.gui.clipconfig.effect_expander.addEffectToClip(clip, factory_name)
         return True
 
-    def _dragLeaveCb(self, widget, unused_context, unused_time):
-        self.dropDataReady = False
-        if self.dropHighlight:
-            widget.drag_unhighlight()
-            self.dropHighlight = False
+    def _dragDataReceivedCb(self, widget, drag_context, unused_x, unused_y, selection_data, unused_info, timestamp):
+        dragging_effect = selection_data.get_data_type().name() == "pitivi/effect"
+        if not self.dropDataReady:
+            if dragging_effect:
+                # Dragging an effect from the Effect Library.
+                factory_name = str(selection_data.get_data(), "UTF-8")
+                self.dropData = factory_name
+                self.dropDataReady = True
+            elif selection_data.get_length() > 0:
+                # Dragging assets from the Media Library.
+                if not self.dropOccured:
+                    self.timeline.resetGhostClips()
+                self.dropData = selection_data.get_uris()
+                self.dropDataReady = True
 
-        self.timeline.removeGhostClips()
+        if self.dropOccured:
+            # The data was requested by the drop handler.
+            self.dropOccured = False
+            drag_context.finish(True, False, timestamp)
+        else:
+            # The data was requested by the move handler.
+            self.isDraggedClip = not dragging_effect
