@@ -22,8 +22,9 @@
 
 import os
 
-from gi.repository import GLib
 from gi.repository import GES
+from gi.repository import GLib
+from gi.repository import GObject
 from gi.repository import Gtk
 from gi.repository import GdkPixbuf
 
@@ -31,26 +32,27 @@ from gettext import gettext as _
 
 from pitivi.configure import get_pixmap_dir
 from pitivi.utils.loggable import Loggable
-from pitivi.utils.signal import Signallable
-from pitivi.utils.ui import SPACING, PADDING
+from pitivi.utils.ui import SPACING
+
 
 (COL_TRANSITION_ASSET,
  COL_NAME_TEXT,
  COL_DESC_TEXT,
- COL_ICON) = range(4)
+ COL_ICON) = list(range(4))
 
 
-class TransitionsListWidget(Signallable, Gtk.VBox, Loggable):
+class TransitionsListWidget(Gtk.VBox, Loggable):
     """
     Widget for configuring the selected transition.
+
+    @type app: L{Pitivi}
     """
 
-    def __init__(self, instance, unused_uiman):
+    def __init__(self, app):
         Gtk.VBox.__init__(self)
         Loggable.__init__(self)
-        Signallable.__init__(self)
 
-        self.app = instance
+        self.app = app
         self.element = None
         self._pixdir = os.path.join(get_pixmap_dir(), "transitions")
         icon_theme = Gtk.IconTheme.get_default()
@@ -92,14 +94,14 @@ class TransitionsListWidget(Signallable, Gtk.VBox, Loggable):
         self._borderTypeChangedCb()
 
         self.infobar = Gtk.InfoBar()
+        self.infobar.props.message_type = Gtk.MessageType.OTHER
         txtlabel = Gtk.Label()
-        txtlabel.set_padding(PADDING, PADDING)
         txtlabel.set_line_wrap(True)
         txtlabel.set_text(
             _("Create a transition by overlapping two adjacent clips on the "
                 "same layer. Click the transition on the timeline to change "
                 "the transition type."))
-        self.infobar.add(txtlabel)
+        self.infobar.get_content_area().add(txtlabel)
 
         self.storemodel = Gtk.ListStore(GES.Asset, str, str, GdkPixbuf.Pixbuf)
 
@@ -161,7 +163,7 @@ class TransitionsListWidget(Signallable, Gtk.VBox, Loggable):
             self.props_widgets.set_sensitive(True)
 
         self.element.get_parent().set_asset(transition_asset)
-        self.app.current_project.seeker.flush(True)
+        self.app.project_manager.current_project.seeker.flush(True)
 
         return True
 
@@ -169,13 +171,13 @@ class TransitionsListWidget(Signallable, Gtk.VBox, Loggable):
         value = range_changed.get_value()
         self.debug("User changed the border property to %s", value)
         self.element.set_border(int(value))
-        self.app.current_project.seeker.flush(True)
+        self.app.project_manager.current_project.seeker.flush(True)
 
     def _invertCheckboxCb(self, widget):
         value = widget.get_active()
         self.debug("User changed the invert property to %s", value)
         self.element.set_inverted(value)
-        self.app.current_project.seeker.flush()
+        self.app.project_manager.current_project.seeker.flush()
 
     def _borderTypeChangedCb(self, widget=None):
         """
@@ -356,4 +358,3 @@ class TransitionsListWidget(Signallable, Gtk.VBox, Loggable):
         text = self.searchEntry.get_text().lower()
         return text in model.get_value(iter, COL_DESC_TEXT).lower() or\
             text in model.get_value(iter, COL_NAME_TEXT).lower()
-        return False
