@@ -20,10 +20,11 @@
 # Boston, MA 02110-1301, USA.
 
 """
-Base classes for the undo/redo feature implementation
+Base classes for undo/redo.
 """
 
-from pitivi.utils.signal import Signallable
+from gi.repository import GObject
+
 from pitivi.utils.loggable import Loggable
 
 
@@ -37,18 +38,21 @@ class UndoWrongStateError(UndoError):
     pass
 
 
-class UndoableAction(Signallable):
+class UndoableAction(GObject.Object):
     """
-    This class represents an action that can be undone.
+    An action that can be undone.
     In other words, when your object's state changes, create an UndoableAction
     to allow reverting the change if needed later on.
     """
-    __signals__ = {
-        "done": [],
-        "undone": [],
-        "undone": [],
+
+    __gsignals__ = {
+        "done": (GObject.SIGNAL_RUN_LAST, None, ()),
+        "undone": (GObject.SIGNAL_RUN_LAST, None, ()),
     }
 
+    def __init__(self):
+        GObject.Object.__init__(self)
+
     def do(self):
         raise NotImplementedError()
 
@@ -70,13 +74,13 @@ class UndoableActionStack(UndoableAction):
     """
     Simply a stack of UndoableAction objects.
     """
-    __signals__ = {
-        "done": [],
-        "undone": [],
-        "cleaned": [],
+
+    __gsignals__ = {
+        "cleaned": (GObject.SIGNAL_RUN_LAST, None, ()),
     }
 
     def __init__(self, action_group_name):
+        UndoableAction.__init__(self)
         self.action_group_name = action_group_name
         self.done_actions = []
         self.undone_actions = []
@@ -108,22 +112,23 @@ class UndoableActionStack(UndoableAction):
         self.emit("cleaned")
 
 
-class UndoableActionLog(Signallable, Loggable):
+class UndoableActionLog(GObject.Object, Loggable):
     """
     This is the "master" class that handles all the undo/redo system. There is
     only one instance of it in Pitivi: application.py's "action_log" property.
     """
-    __signals__ = {
-        "begin": ["stack", "nested"],
-        "push": ["stack", "action"],
-        "rollback": ["stack", "nested"],
-        "commit": ["stack", "nested"],
-        "undo": ["stack"],
-        "redo": ["stack"],
-        "cleaned": [],
+    __gsignals__ = {
+        "begin": (GObject.SIGNAL_RUN_LAST, None, (object, bool)),
+        "push": (GObject.SIGNAL_RUN_LAST, None, (object, object)),
+        "rollback": (GObject.SIGNAL_RUN_LAST, None, (object, bool)),
+        "commit": (GObject.SIGNAL_RUN_LAST, None, (object, bool)),
+        "undo": (GObject.SIGNAL_RUN_LAST, None, (object,)),
+        "redo": (GObject.SIGNAL_RUN_LAST, None, (object,)),
+        "cleaned": (GObject.SIGNAL_RUN_LAST, None, ()),
     }
 
     def __init__(self):
+        GObject.Object.__init__(self)
         Loggable.__init__(self)
 
         self.undo_stacks = []
@@ -133,18 +138,21 @@ class UndoableActionLog(Signallable, Loggable):
         self._checkpoint = self._takeSnapshot()
 
     def begin(self, action_group_name):
-        self.debug("Begining %s", action_group_name)
+        self.debug("Beginning %s", action_group_name)
         if self.running:
+            self.debug("Abort because already running")
             return
 
         stack = UndoableActionStack(action_group_name)
         nested = self._stackIsNested(stack)
         self.stacks.append(stack)
+        self.debug("begin action group %s, nested %s", stack.action_group_name, nested)
         self.emit("begin", stack, nested)
 
     def push(self, action):
         self.debug("Pushing %s", action)
         if self.running:
+            self.debug("Abort because already running")
             return
 
         try:
@@ -153,21 +161,27 @@ class UndoableActionLog(Signallable, Loggable):
             return
 
         stack.push(action)
+        self.debug("push action %s in action group %s", action, stack.action_group_name)
         self.emit("push", stack, action)
 
     def rollback(self):
+        self.debug("Rolling back")
         if self.running:
+            self.debug("Abort because already running")
             return
 
         stack = self._getTopmostStack(pop=True)
         if stack is None:
             return
         nested = self._stackIsNested(stack)
+        self.debug("rollback action group %s, nested %s", stack.action_group_name, nested)
         self.emit("rollback", stack, nested)
         stack.undo()
 
     def commit(self):
+        self.debug("Committing")
         if self.running:
+            self.debug("Abort because already running")
             return
 
         stack = self._getTopmostStack(pop=True)
@@ -182,7 +196,7 @@ class UndoableActionLog(Signallable, Loggable):
         if self.redo_stacks:
             self.redo_stacks = []
 
-        self.debug("%s pushed", stack)
+        self.debug("commit action group %s nested %s", stack.action_group_name, nested)
         self.emit("commit", stack, nested)
 
     def undo(self):
@@ -248,65 +262,36 @@ class UndoableActionLog(Signallable, Loggable):
         return bool(len(self.stacks))
 
 
-class DebugActionLogObserver(Loggable):
-    """
-    Allows getting more debug output from the UndoableActionLog than the default
-    """
-    # FIXME: this looks overengineered at first glance. This is used in only one
-    # place in the codebase (in application.py). Why not just put the debug
-    # directly in UndoableActionLog if we really need them anyway?
-    def startObserving(self, log):
-        self._connectToActionLog(log)
-
-    def stopObserving(self, log):
-        self._disconnectFromActionLog(log)
-
-    def _connectToActionLog(self, log):
-        log.connect("begin", self._actionLogBeginCb)
-        log.connect("commit", self._actionLogCommitCb)
-        log.connect("rollback", self._actionLogRollbackCb)
-        log.connect("push", self._actionLogPushCb)
-
-    def _disconnectFromActionLog(self, log):
-        for method in (self._actionLogBeginCb, self._actionLogCommitCb,
-                self._actionLogrollbackCb, self._actionLogPushCb):
-            log.disconnect_by_func(method)
-
-    def _actionLogBeginCb(self, unused_log, stack, nested):
-        self.debug("begin action %s nested %s", stack.action_group_name, nested)
-
-    def _actionLogCommitCb(self, unused_log, stack, nested):
-        self.debug("commit action %s nested %s", stack.action_group_name, nested)
-
-    def _actionLogRollbackCb(self, unused_log, stack, nested):
-        self.debug("rollback action %s nested %s", stack.action_group_name, nested)
-
-    def _actionLogPushCb(self, unused_log, stack, action):
-        self.debug("push %s in %s", action, stack.action_group_name)
-
-
-class PropertyChangeTracker(Signallable):
+class PropertyChangeTracker(GObject.Object):
     """
     BaseClass to track a class property, Used for undo/redo
     """
-    __signals__ = {}
+
+    __gsignals__ = {
+        "monitored-property-changed": (GObject.SIGNAL_RUN_LAST, None, (object, str, object, object)),
+    }
+
+    # The properties monitored by this class
+    property_names = []
 
     def __init__(self):
+        GObject.Object.__init__(self)
         self.properties = {}
         self.obj = None
 
     def connectToObject(self, obj):
         self.obj = obj
         self.properties = self._takeCurrentSnapshot(obj)
+        # Connect to obj to keep track when the monitored properties
+        # are changed.
         for property_name in self.property_names:
-            signal_name = "notify::" + property_name
-            self.__signals__[signal_name] = []
-            obj.connect(signal_name,
-                    self._propertyChangedCb, property_name)
+            signal_name = "notify::%s" % property_name
+            obj.connect(signal_name, self._propertyChangedCb, property_name)
 
-    def _takeCurrentSnapshot(self, obj):
+    @classmethod
+    def _takeCurrentSnapshot(cls, obj):
         properties = {}
-        for property_name in self.property_names:
+        for property_name in cls.property_names:
             properties[property_name] = obj.get_property(property_name.replace("-", "_"))
 
         return properties
@@ -315,7 +300,7 @@ class PropertyChangeTracker(Signallable):
         self.obj = None
         obj.disconnect_by_func(self._propertyChangedCb)
 
-    def _propertyChangedCb(self, object, value, property_name):
+    def _propertyChangedCb(self, object, property_value, property_name):
         old_value = self.properties[property_name]
-        self.properties[property_name] = value
-        self.emit("notify::" + property_name, object, old_value, value)
+        self.properties[property_name] = property_value
+        self.emit("monitored-property-changed", object, property_name, old_value, property_value)
