@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python3
 #
 #       pitivi/utils/pipeline.py
 #
@@ -24,31 +24,44 @@
 """
 High-level pipelines
 """
-from pitivi.utils.loggable import Loggable
-from pitivi.utils.signal import Signallable
-from pitivi.utils.misc import format_ns
+import platform
+
 
 from gi.repository import GLib
 from gi.repository import GObject
 from gi.repository import Gst
 from gi.repository import GES
 
+from pitivi.utils.loggable import Loggable
+from pitivi.utils.misc import format_ns
+
+
 MAX_RECOVERIES = 5
 
+PIPELINE_SIGNALS = {
+    "state-change": (GObject.SignalFlags.RUN_LAST, None, (GObject.TYPE_INT,)),
+    "position": (GObject.SignalFlags.RUN_LAST, None, (GObject.TYPE_UINT64,)),
+    "duration-changed": (GObject.SignalFlags.RUN_LAST, None, (GObject.TYPE_UINT64,)),
+    "eos": (GObject.SignalFlags.RUN_LAST, None, ()),
+    "error": (GObject.SignalFlags.RUN_LAST, None, (GObject.TYPE_STRING, GObject.TYPE_STRING)),
+}
+
 
 class PipelineError(Exception):
     pass
 
 
-class Seeker(Signallable, Loggable):
+class Seeker(GObject.Object, Loggable):
     """
     The Seeker is a singleton helper class to do various seeking
     operations in the pipeline.
     """
+
     _instance = None
-    __signals__ = {
-        'seek': ['position', 'format'],
-        'seek-relative': ['time'],
+
+    __gsignals__ = {
+        "seek": (GObject.SIGNAL_RUN_LAST, None, (GObject.TYPE_UINT64,)),
+        "seek-relative": (GObject.SIGNAL_RUN_LAST, None, (GObject.TYPE_INT64,)),
     }
 
     def __new__(cls, *args, **kwargs):
@@ -64,18 +77,16 @@ class Seeker(Signallable, Loggable):
         """
         @param timeout (optional): the amount of miliseconds for a seek attempt
         """
-        Signallable.__init__(self)
+        GObject.Object.__init__(self)
         Loggable.__init__(self)
 
         self.timeout = timeout
         self.pending_seek_id = None
         self.position = None
-        self.format = None
         self._time = None
         self.pending_position = None
 
-    def seek(self, position, format=Gst.Format.TIME, on_idle=False):
-        self.format = format
+    def seek(self, position, on_idle=False):
         self.position = position
 
         if self.pending_seek_id is None:
@@ -88,7 +99,7 @@ class Seeker(Signallable, Loggable):
 
     def seekRelative(self, time, on_idle=False):
         if self.pending_seek_id is None:
-            self._time = long(time)
+            self._time = int(time)
             if on_idle:
                 self.pending_seek_id = self._scheduleSeek(self.timeout, self._seekTimeoutCb, relative=True)
             else:
@@ -113,14 +124,14 @@ class Seeker(Signallable, Loggable):
                 return False
 
             self._time = None
-        elif self.position is not None and self.format is not None:
-            position, self.position = self.position, None
-            format, self.format = self.format, None
+        elif self.position is not None:
+            position = max(0, self.position)
+            self.position = None
             try:
-                self.emit('seek', position, format)
+                self.emit('seek', position)
             except PipelineError as e:
-                self.error("Error while seeking to position:%s format: %r, reason: %s",
-                          format_ns(position), format, e)
+                self.error("Error while seeking to position: %s, reason: %s",
+                           format_ns(position), e)
                 # if an exception happened while seeking, properly
                 # reset ourselves
                 return False
@@ -132,7 +143,7 @@ class Seeker(Signallable, Loggable):
         return False
 
 
-class SimplePipeline(Signallable, Loggable):
+class SimplePipeline(GObject.Object, Loggable):
     """
     The Pipeline is only responsible for:
      - State changes
@@ -147,17 +158,11 @@ class SimplePipeline(Signallable, Loggable):
      - C{error} : An error happened.
     """
 
-    __signals__ = {
-        "state-change": ["state"],
-        "position": ["position"],
-        "duration-changed": ["duration"],
-        "eos": [],
-        "error": ["message", "details"]
-    }
+    __gsignals__ = PIPELINE_SIGNALS
 
     def __init__(self, pipeline):
+        GObject.Object.__init__(self)
         Loggable.__init__(self)
-        Signallable.__init__(self)
 
         self._pipeline = pipeline
         self._bus = self._pipeline.get_bus()
@@ -167,7 +172,7 @@ class SimplePipeline(Signallable, Loggable):
         self._listeningInterval = 300  # default 300ms
         self._listeningSigId = 0
         self._duration = Gst.CLOCK_TIME_NONE
-        self.lastPosition = long(0 * Gst.SECOND)
+        self.lastPosition = int(0 * Gst.SECOND)
         self.pendingRecovery = False
         self._attempted_recoveries = 0
         self._waiting_for_async_done = True
@@ -176,17 +181,11 @@ class SimplePipeline(Signallable, Loggable):
 
         # Create a cluttersink element used for display. Subclasses must connect
         # it to self._pipeline themselves
-        self._clutter_sink = Gst.ElementFactory.make("cluttersink", None)
+        self.video_sink = Gst.ElementFactory.make("glimagesink", None)
         if isinstance(pipeline, GES.Pipeline):
-            self._pipeline.preview_set_video_sink(self._clutter_sink)
+            self._pipeline.preview_set_video_sink(self.video_sink)
         else:
-            self._pipeline.set_property("video_sink", self._clutter_sink)
-
-    def connectWithViewer(self, viewer):
-        """
-        Connect the specified ViewerWidget so this pipeline can be displayed.
-        """
-        self._clutter_sink.props.texture = viewer.texture
+            self._pipeline.set_property("video_sink", self.video_sink)
 
     def release(self):
         """
@@ -209,7 +208,8 @@ class SimplePipeline(Signallable, Loggable):
         self.pause()
         try:
             self.seekRelative(0)
-        except PipelineError:
+        except PipelineError as e:
+            self.warning("Could not flush because: %s", e)
             pass
 
     def setState(self, state):
@@ -258,8 +258,8 @@ class SimplePipeline(Signallable, Loggable):
         # during the playback.
         try:
             position = self.getPosition()
-        except PipelineError:
-            # Getting the position failed
+        except PipelineError as e:
+            self.warning("Getting the position failed: %s", e)
             return
         if position != Gst.CLOCK_TIME_NONE and position >= 0:
             self.emit("position", position)
@@ -276,43 +276,37 @@ class SimplePipeline(Signallable, Loggable):
         else:
             self.play()
 
-    #{ Position and Seeking methods
+    # Position and Seeking methods
 
-    def getPosition(self, format=Gst.Format.TIME):
+    def getPosition(self):
         """
         Get the current position of the L{Pipeline}.
 
-        @param format: The format to return the current position in
-        @type format: C{Gst.Format}
         @return: The current position or Gst.CLOCK_TIME_NONE
         @rtype: L{long}
         @raise PipelineError: If the position couldn't be obtained.
         """
         try:
-            res, cur = self._pipeline.query_position(format)
-        except Exception, e:
+            res, cur = self._pipeline.query_position(Gst.Format.TIME)
+        except Exception as e:
             self.handleException(e)
             raise PipelineError("Couldn't get position")
 
         if not res:
-            raise PipelineError("Couldn't get position")
+            raise PipelineError("Position not available")
 
         self.log("Got position %s", format_ns(cur))
         return cur
 
-    def getDuration(self, format=Gst.Format.TIME):
+    def getDuration(self):
         """
         Get the duration of the C{Pipeline}.
         """
-        self.log("format %r", format)
-
-        dur = self._getDuration(format)
+        dur = self._getDuration()
         self.log("Got duration %s", format_ns(dur))
         if self._duration != dur:
             self.emit("duration-changed", dur)
-
         self._duration = dur
-
         return dur
 
     def activatePositionListener(self, interval=500):
@@ -347,12 +341,14 @@ class SimplePipeline(Signallable, Loggable):
 
     def _positionListenerCb(self):
         try:
-            cur = self.getPosition()
-            if cur != Gst.CLOCK_TIME_NONE:
-                self.emit('position', cur)
-                self.lastPosition = cur
-        except PipelineError:
-            pass
+            try:
+                position = self.getPosition()
+            except PipelineError as e:
+                self.warning("Could not get position because: %s", e)
+            else:
+                if position != Gst.CLOCK_TIME_NONE:
+                    self.emit('position', position)
+                    self.lastPosition = position
         finally:
             return True
 
@@ -372,56 +368,45 @@ class SimplePipeline(Signallable, Loggable):
         self._waiting_for_async_done = False
         return False
 
-    def simple_seek(self, position, format=Gst.Format.TIME):
+    def simple_seek(self, position):
         """
         Seeks in the L{Pipeline} to the given position.
 
         @param position: Position to seek to
         @type position: L{long}
-        @param format: The C{Format} of the seek position
-        @type format: C{Gst.Format}
         @raise PipelineError: If seek failed
         """
         if self._waiting_for_async_done is True:
-            self._next_seek = (position, format)
+            self._next_seek = position
             self.info("Setting next seek to %s", self._next_seek)
             return
 
-        if format == Gst.Format.TIME:
-            self.debug("position: %s", format_ns(position))
-        else:
-            self.debug("position: %d, format: %d", position, format)
+        self.debug("position: %s", format_ns(position))
 
         # clamp between [0, duration]
-        if format == Gst.Format.TIME:
-            position = max(0, min(position, self.getDuration()) - 1)
+        position = max(0, min(position, self.getDuration()) - 1)
 
-        res = self._pipeline.seek(1.0, format, Gst.SeekFlags.FLUSH,
+        res = self._pipeline.seek(1.0, Gst.Format.TIME, Gst.SeekFlags.FLUSH,
                                   Gst.SeekType.SET, position,
                                   Gst.SeekType.NONE, -1)
         self._waiting_for_async_done = True
 
         if self._timeout_async_id:
             GLib.source_remove(self._timeout_async_id)
-            self._timeout_async_id = 0
-
         self._timeout_async_id = GLib.timeout_add(1000, self._resetWaitingForAsyncDone)
 
         if not res:
-            self.debug("seeking failed")
-            raise PipelineError("seek failed")
+            raise PipelineError("seek failed: %s" % position)
 
         self.lastPosition = position
 
         self.debug("seeking successful")
         self.emit('position', position)
 
-    def seekRelative(self, time):
-        seekvalue = max(0, min(self.getPosition() + time, self.getDuration()))
-        self.simple_seek(seekvalue)
+    def seekRelative(self, time_delta):
+        self.simple_seek(self.getPosition() + time_delta)
 
-    #}
-    ## Private methods
+    # Private methods
 
     def _busMessageCb(self, unused_bus, message):
         if message.type == Gst.MessageType.EOS:
@@ -438,7 +423,8 @@ class SimplePipeline(Signallable, Loggable):
                     # trigger duration-changed
                     try:
                         self.getDuration()
-                    except PipelineError:
+                    except PipelineError as e:
+                        self.warning("Could not get duration because: %s", e)
                         # no sinks??
                         pass
                     if self.pendingRecovery:
@@ -466,7 +452,7 @@ class SimplePipeline(Signallable, Loggable):
             self._attempted_recoveries = 0
             self._waiting_for_async_done = False
             if self._next_seek is not None:
-                self.simple_seek(self._next_seek[0], self._next_seek[1])
+                self.simple_seek(self._next_seek)
                 self._next_seek = None
             if self._timeout_async_id:
                 GLib.source_remove(self._timeout_async_id)
@@ -487,18 +473,18 @@ class SimplePipeline(Signallable, Loggable):
     def _queryDurationAsync(self, *unused_args, **unused_kwargs):
         try:
             self.getDuration()
-        except:
-            self.log("Duration failed... but we don't care")
+        except Exception as e:
+            self.warning("Could not get duration because: %s", e)
         return False
 
     def _handleErrorMessage(self, error, detail, source):
         self.error("error from %s: %s (%s)" % (source, error, detail))
         self.emit('error', error.message, detail)
 
-    def _getDuration(self, format=Gst.Format.TIME):
+    def _getDuration(self):
         try:
-            res, dur = self._pipeline.query_duration(format)
-        except Exception, e:
+            res, dur = self._pipeline.query_duration(Gst.Format.TIME)
+        except Exception as e:
             self.handleException(e)
             raise PipelineError("Couldn't get duration: %s" % e)
 
@@ -523,30 +509,22 @@ class AssetPipeline(SimplePipeline):
     def setClipUri(self, uri):
         self._pipeline.set_property("uri", uri)
 
+    def connectWithViewer(self, widget):
+        if platform.system() == 'Windows':
+            handle = widget.drawing_area.get_window().get_handle()
+        else:
+            handle = widget.drawing_area.get_window().get_xid()
+
+        self.video_sink.set_window_handle(handle)
+
 
 class Pipeline(GES.Pipeline, SimplePipeline):
     """
     Helper to handle GES.Pipeline through the SimplePipeline API
     and handle the Seeker properly
-
-    Signals:
-     - C{state-changed} : The state of the pipeline changed.
-     - C{position} : The current position of the pipeline changed.
-     - C{eos} : The Pipeline has finished playing.
-     - C{error} : An error happened.
     """
 
-    __gsignals__ = {
-        "state-change": (GObject.SignalFlags.RUN_LAST, None,
-                        (GObject.TYPE_INT,)),
-        "position": (GObject.SignalFlags.RUN_LAST, None,
-                        (GObject.TYPE_UINT64,)),
-        "duration-changed": (GObject.SignalFlags.RUN_LAST, None,
-                        (GObject.TYPE_UINT64,)),
-        "eos": (GObject.SignalFlags.RUN_LAST, None, ()),
-        "error": (GObject.SignalFlags.RUN_LAST, None,
-                (GObject.TYPE_STRING, GObject.TYPE_STRING))
-    }
+    __gsignals__ = PIPELINE_SIGNALS
 
     def __init__(self, pipeline=None):
         GES.Pipeline.__init__(self)
@@ -557,7 +535,7 @@ class Pipeline(GES.Pipeline, SimplePipeline):
         self._seeker.connect("seek", self._seekCb)
         self._seeker.connect("seek-relative", self._seekRelativeCb)
 
-    def _getDuration(self, format=Gst.Format.TIME):
+    def _getDuration(self):
         return self._timeline.get_duration()
 
     def set_timeline(self, timeline):
@@ -579,8 +557,8 @@ class Pipeline(GES.Pipeline, SimplePipeline):
         self._seeker.disconnect_by_func(self._seekCb)
         SimplePipeline.release(self)
 
-    def _seekRelativeCb(self, unused_seeker, time):
-        self.seekRelative(time)
+    def _seekRelativeCb(self, unused_seeker, time_delta):
+        self.seekRelative(time_delta)
 
     def stepFrame(self, framerate, frames_offset):
         """
@@ -595,7 +573,7 @@ class Pipeline(GES.Pipeline, SimplePipeline):
 
         cur_frame = int(round(position * framerate.num / float(Gst.SECOND * framerate.denom), 2))
         new_frame = cur_frame + frames_offset
-        new_pos = long(new_frame * Gst.SECOND * framerate.denom / framerate.num)
+        new_pos = int(new_frame * Gst.SECOND * framerate.denom / framerate.num)
         Loggable.info(self, "From frame %d to %d at %f fps, seek to %s s",
                     cur_frame,
                     new_frame,
@@ -603,7 +581,7 @@ class Pipeline(GES.Pipeline, SimplePipeline):
                     new_pos / float(Gst.SECOND))
         self.simple_seek(new_pos)
 
-    def _seekCb(self, unused_ruler, position, unused_format):
+    def _seekCb(self, unused_seeker, position):
         """
         The app's main seek method used when the user seeks manually.
 
