@@ -21,12 +21,9 @@
 # Boston, MA 02110-1301, USA.
 
 from gi.repository import GES
-from gi.repository import Gdk
+from gi.repository import GObject
 from gi.repository import Gst
 
-from pitivi.undo.undo import UndoableAction
-from pitivi.utils.signal import Signallable
-
 
 # Selection modes
 # Set the selection to the given set.
@@ -39,29 +36,13 @@ SELECT_ADD = 2
 
 #------------------------------------------------------------------------------#
 #                          Timeline Object management helper                   #
+
 class TimelineError(Exception):
     """Base Exception for errors happening in L{Timeline}s or L{Clip}s"""
     pass
 
 
-class ClipEdited(UndoableAction):
-    def __init__(self, focus, old_priority, new_priority, mode, edge, old_position, new_position):
-        self.focus = focus
-        self.old_priority = old_priority
-        self.old_position = old_position
-        self.new_priority = new_priority
-        self.new_position = new_position
-        self.mode = mode
-        self.edge = edge
-
-    def do(self):
-        self.focus.edit([], self.new_priority, self.mode, self.edge, long(self.new_position))
-
-    def undo(self):
-        self.focus.edit([], self.old_priority, self.mode, self.edge, long(self.old_position))
-
-
-class Selected(Signallable):
+class Selected(GObject.Object):
     """
     A simple class that let us emit a selected-changed signal
     when needed, and that can be check directly to know if the
@@ -71,13 +52,15 @@ class Selected(Signallable):
     utils.timeline's "Selection" class.
     """
 
-    __signals__ = {
-        "selected-changed": []}
+    __gsignals__ = {
+        "selected-changed": (GObject.SIGNAL_RUN_LAST, None, (bool,)),
+    }
 
     def __init__(self):
+        GObject.Object.__init__(self)
         self._selected = False
 
-    def __nonzero__(self):
+    def __bool__(self):
         """
         checking a Selected object is the same as checking its _selected
         property
@@ -94,7 +77,7 @@ class Selected(Signallable):
     selected = property(getSelected, setSelected)
 
 
-class Selection(Signallable):
+class Selection(GObject.Object):
     """
     A collection of L{GES.Clip}.
 
@@ -105,10 +88,12 @@ class Selection(Signallable):
     @type selected: C{list}
     """
 
-    __signals__ = {
-        "selection-changed": []}
+    __gsignals__ = {
+        "selection-changed": (GObject.SIGNAL_RUN_LAST, None, ()),
+    }
 
     def __init__(self):
+        GObject.Object.__init__(self)
         self.selected = set()
 
     def setToObj(self, obj, mode):
@@ -160,7 +145,6 @@ class Selection(Signallable):
             for element in obj.get_children(False):
                 if not isinstance(element, GES.BaseEffect) and not isinstance(element, GES.TextOverlay):
                     element.selected.selected = True
-
         self.emit("selection-changed")
 
     def getSelectedTrackElements(self):
@@ -184,6 +168,18 @@ class Selection(Signallable):
                     effects.append(element)
         return effects
 
+    def getSingleClip(self, clip_type):
+        """
+        Returns the single-selected clip, if any.
+
+        @param clip_type: The class the clip must be an instance of.
+        """
+        if len(self.selected) == 1:
+            clip = tuple(self.selected)[0]
+            if isinstance(clip, clip_type):
+                return clip
+        return None
+
     def __len__(self):
         return len(self.selected)
 
@@ -193,16 +189,17 @@ class Selection(Signallable):
 
 #-----------------------------------------------------------------------------#
 #                       Timeline edition modes helper                         #
-class EditingContext(Signallable):
+
+class EditingContext(GObject.Object):
     """
         Encapsulates interactive editing.
 
         This is the main class for interactive edition.
     """
 
-    __signals__ = {
-        "clip-trim": ["uri", "position"],
-        "clip-trim-finished": [],
+    __gsignals__ = {
+        "clip-trim": (GObject.SIGNAL_RUN_LAST, None, (GES.Clip, int)),
+        "clip-trim-finished": (GObject.SIGNAL_RUN_LAST, None, ()),
     }
 
     def __init__(self, focus, timeline, mode, edge, unused_settings, action_log):
@@ -228,8 +225,7 @@ class EditingContext(Signallable):
 
         @returns: An instance of L{pitivi.utils.timeline.EditingContext}
         """
-        Signallable.__init__(self)
-
+        GObject.Object.__init__(self)
         if isinstance(focus, GES.TrackElement):
             self.focus = focus.get_parent()
         else:
@@ -251,14 +247,8 @@ class EditingContext(Signallable):
         self.action_log.begin("move-clip")
 
     def finish(self):
-        """Clean up timeline for normal editing"""
-        if self.new_position is not None and self.new_priority is not None:
-            # The mouse cursor did move.
-            action = ClipEdited(self.focus, self.old_priority, self.new_priority, self.mode, self.edge,
-                                self.old_position, self.new_position)
-            self.action_log.push(action)
-            self.action_log.commit()
-            self.timeline.commit()
+        self.action_log.commit()
+        self.timeline.commit()
         self.emit("clip-trim-finished")
 
     def setMode(self, mode):
@@ -277,7 +267,7 @@ class EditingContext(Signallable):
         self.new_position = position
         self.new_priority = priority
 
-        res = self.focus.edit([], priority, self.mode, self.edge, long(position))
+        res = self.focus.edit([], priority, self.mode, self.edge, int(position))
         if res and self.mode == GES.EditMode.EDIT_TRIM:
             if self.edge == GES.Edge.EDGE_START:
                 self.emit("clip-trim", self.focus, self.focus.props.in_point)
@@ -381,14 +371,14 @@ class Zoomable(object):
         """
         Returns the pixel equivalent in nanoseconds according to the zoomratio
         """
-        return long(pixel * Gst.SECOND / cls.zoomratio)
+        return int(pixel * Gst.SECOND / cls.zoomratio)
 
     @classmethod
     def pixelToNsAt(cls, pixel, ratio):
         """
         Returns the pixel equivalent in nanoseconds according to the zoomratio
         """
-        return long(pixel * Gst.SECOND / ratio)
+        return int(pixel * Gst.SECOND / ratio)
 
     @classmethod
     def nsToPixel(cls, duration):
