@@ -48,8 +48,6 @@ from pitivi.utils.ui import beautify_length, \
 from pitivi.utils.timeline import Zoomable
 
 
-ZOOM_FIT = _("Zoom Fit")
-
 ZOOM_SLIDER_PADDING = SPACING * 4 / 5
 
 
@@ -247,8 +245,8 @@ class NumericWidget(Gtk.HBox, DynamicWidget):
         if self._type is None:
             self._type = type_
 
-        if type_ == int or type_ == long:
-            minimum, maximum = (-sys.maxint, sys.maxint)
+        if type_ == int or type_ == int:
+            minimum, maximum = (-sys.maxsize, sys.maxsize)
             step = 1.0
             page = 10.0
         elif type_ == float:
@@ -488,7 +486,7 @@ class PathWidget(Gtk.FileChooserButton, DynamicWidget):
         self.dialog = Gtk.FileChooserDialog(action=action)
         self.dialog.add_buttons(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)
         self.dialog.set_default_response(Gtk.ResponseType.OK)
-        Gtk.FileChooserButton.__init__(self, self.dialog)
+        Gtk.FileChooserButton.__init__(self, dialog=self.dialog)
         self.dialog.connect("response", self._responseCb)
         self.uri = ""
 
@@ -526,7 +524,7 @@ class ColorWidget(Gtk.ColorButton, DynamicWidget):
 
         if type_ is str:
             color = Gdk.Color(value)
-        elif (type_ is int) or (type_ is long):
+        elif (type_ is int) or (type_ is int):
             red, green, blue, alpha = unpack_color(value)
             color = Gdk.Color(red, green, blue)
         elif type_ is Gdk.Color:
@@ -542,7 +540,7 @@ class ColorWidget(Gtk.ColorButton, DynamicWidget):
         alpha = self.get_alpha()
         if self.value_type is int:
             return pack_color_32(color.red, color.green, color.blue, alpha)
-        if self.value_type is long:
+        if self.value_type is int:
             return pack_color_64(color.red, color.green, color.blue, alpha)
         elif self.value_type is Gdk.Color:
             return color
@@ -589,7 +587,7 @@ class GstElementSettingsWidget(Gtk.VBox, Loggable):
             # Use the dynamic widget (that has been provided as an argument)
             # to find which of the togglebuttons is the related one.
             self.log("Resetting one keyframe button")
-            for togglebutton in self.keyframeToggleButtons.keys():
+            for togglebutton in list(self.keyframeToggleButtons.keys()):
                 if self.keyframeToggleButtons[togglebutton] is widget:
                     # The dynamic widget matches the one
                     # related to the current to the current togglebutton
@@ -598,7 +596,7 @@ class GstElementSettingsWidget(Gtk.VBox, Loggable):
                     break  # Stop searching
         else:
             self.log("Resetting all keyframe buttons")
-            for togglebutton in self.keyframeToggleButtons.keys():
+            for togglebutton in list(self.keyframeToggleButtons.keys()):
                 togglebutton.set_label("◇")
                 self._setKeyframeToggleButtonState(togglebutton, False)
 
@@ -632,9 +630,9 @@ class GstElementSettingsWidget(Gtk.VBox, Loggable):
         is_effect = False
         if isinstance(self.element, GES.Effect):
             is_effect = True
-            props = [prop for prop in self.element.list_children_properties() if not prop.name in self.ignore]
+            props = [prop for prop in self.element.list_children_properties() if prop.name not in self.ignore]
         else:
-            props = [prop for prop in GObject.list_properties(self.element) if not prop.name in self.ignore]
+            props = [prop for prop in GObject.list_properties(self.element) if prop.name not in self.ignore]
         if not props:
             table = Gtk.Table(n_rows=1, n_columns=1)
             widget = Gtk.Label(label=_("No properties."))
@@ -695,7 +693,6 @@ class GstElementSettingsWidget(Gtk.VBox, Loggable):
             # The "reset to default" button associated with this property
             if default_btn:
                 widget.propName = prop.name.split("-")[0]
-                name = prop.name
 
                 if self.isControllable:
                     # If this element is controlled, the value means nothing anymore.
@@ -707,15 +704,15 @@ class GstElementSettingsWidget(Gtk.VBox, Loggable):
                 table.attach(button, 2, 3, y, y + 1, xoptions=Gtk.AttachOptions.FILL, yoptions=Gtk.AttachOptions.FILL)
                 self.buttons[button] = widget
 
-            self.element.connect('notify::' + prop.name, self._propertyChangedCb, widget)
-
             y += 1
 
+        self.element.connect('deep-notify', self._propertyChangedCb)
         self.pack_start(table, expand=True, fill=True, padding=0)
         self.show_all()
 
-    def _propertyChangedCb(self, unused_element, pspec, widget):
-        widget.setWidgetValue(self.element.get_property(pspec.name))
+    def _propertyChangedCb(self, effect, gst_element, pspec):
+        widget = self.properties[pspec]
+        widget.setWidgetValue(self.element.get_child_property(pspec.name)[1])
 
     def _getKeyframeToggleButton(self, prop):
         button = Gtk.ToggleButton()
@@ -752,7 +749,7 @@ class GstElementSettingsWidget(Gtk.VBox, Loggable):
         widget = self.keyframeToggleButtons[button]
         widget.set_sensitive(False)
         # Now change the state of the *other* togglebuttons.
-        for togglebutton in self.keyframeToggleButtons.keys():
+        for togglebutton in list(self.keyframeToggleButtons.keys()):
             if togglebutton != button:
                 # Don't use set_active directly on the buttons; doing so will
                 # fire off signals that will toggle the others/confuse the UI
@@ -793,7 +790,7 @@ class GstElementSettingsWidget(Gtk.VBox, Loggable):
         returns the dictionnary of propertyname/propertyvalue
         """
         d = {}
-        for prop, widget in self.properties.iteritems():
+        for prop, widget in self.properties.items():
             if not prop.flags & GObject.PARAM_WRITABLE:
                 continue
             if isinstance(widget, DefaultWidget):
@@ -819,7 +816,7 @@ class GstElementSettingsWidget(Gtk.VBox, Loggable):
             widget = ToggleWidget(default=prop.default_value)
         elif type_name == "GEnum":
             choices = []
-            for key, val in prop.enum_class.__enum_values__.iteritems():
+            for key, val in prop.enum_class.__enum_values__.items():
                 choices.append([val.value_name, int(val)])
             widget = ChoiceWidget(choices, default=prop.default_value)
         elif type_name == "GstFraction":
@@ -894,7 +891,7 @@ class GstElementSettingsDialog(Loggable):
         self.resetAll()
 
     def resetAll(self):
-        for prop, widget in self.elementsettings.properties.iteritems():
+        for prop, widget in self.elementsettings.properties.items():
             widget.setWidgetToDefault()
 
 
@@ -980,7 +977,7 @@ class BaseTabs(Gtk.Notebook):
                                       resize=True, shrink=False)
 
 
-class ZoomBox(Gtk.HBox, Zoomable):
+class ZoomBox(Gtk.Grid, Zoomable):
     """
     Container holding the widgets for zooming.
 
@@ -988,22 +985,23 @@ class ZoomBox(Gtk.HBox, Zoomable):
     """
 
     def __init__(self, timeline):
-        Gtk.HBox.__init__(self)
+        Gtk.Grid.__init__(self)
         Zoomable.__init__(self)
 
         self.timeline = timeline
 
         zoom_fit_btn = Gtk.Button()
         zoom_fit_btn.set_relief(Gtk.ReliefStyle.NONE)
-        zoom_fit_btn.set_tooltip_text(ZOOM_FIT)
+        zoom_fit_btn.set_tooltip_text(_("Zoom Fit"))
+        zoom_fit_btn_grid = Gtk.Grid()
         zoom_fit_icon = Gtk.Image.new_from_icon_name("zoom-best-fit", Gtk.IconSize.BUTTON)
-        zoom_fit_btn_hbox = Gtk.HBox()
-        zoom_fit_btn_hbox.pack_start(zoom_fit_icon, expand=False, fill=True, padding=0)
-        zoom_fit_btn_hbox.pack_start(Gtk.Label(label=_("Zoom")), expand=False, fill=True, padding=0)
-        zoom_fit_btn.add(zoom_fit_btn_hbox)
+        zoom_fit_btn_grid.add(zoom_fit_icon)
+        zoom_fit_btn_label = Gtk.Label(label=_("Zoom"))
+        zoom_fit_btn_grid.add(zoom_fit_btn_label)
+        zoom_fit_btn_grid.set_column_spacing(SPACING / 2)
+        zoom_fit_btn.add(zoom_fit_btn_grid)
         zoom_fit_btn.connect("clicked", self._zoomFitCb)
-
-        self.pack_start(zoom_fit_btn, expand=False, fill=True, padding=0)
+        self.attach(zoom_fit_btn, 0, 0, 1, 1)
 
         # zooming slider
         self._zoomAdjustment = Gtk.Adjustment()
@@ -1019,13 +1017,20 @@ class ZoomBox(Gtk.HBox, Zoomable):
         zoomslider.connect("query-tooltip", self._sliderTooltipCb)
         zoomslider.set_has_tooltip(True)
         zoomslider.set_size_request(100, 0)  # At least 100px wide for precision
-        self.pack_start(zoomslider, expand=True, fill=True, padding=ZOOM_SLIDER_PADDING)
+        zoomslider.set_hexpand(True)
+        self.attach(zoomslider, 1, 0, 1, 1)
 
+        # Empty label so we have some spacing at the right of the zoomslider
+        self.attach(Gtk.Label(label=""), 2, 0, 1, 1)
+
+        self.set_hexpand(False)
+        self.set_column_spacing(ZOOM_SLIDER_PADDING)
         self.set_size_request(CONTROL_WIDTH, -1)
         self.show_all()
 
     def _zoomAdjustmentChangedCb(self, adjustment):
         Zoomable.setZoomLevel(adjustment.get_value())
+        self.timeline._scrollToPlayhead()
 
     def _zoomFitCb(self, unused_button):
         self.timeline.zoomFit()
