@@ -23,6 +23,11 @@ from gi.repository import Clutter
 from gi.repository import Gtk
 from gi.repository import GtkClutter
 from gi.repository import Gdk
+try:
+    from gi.repository import GdkX11
+except ImportError:
+
+    pass
 from gi.repository import Gst
 from gi.repository import GObject
 from gi.repository import GES
@@ -39,6 +44,8 @@ from pitivi.utils.pipeline import AssetPipeline, Seeker
 from pitivi.utils.ui import SPACING, hex_to_rgb
 from pitivi.utils.widgets import TimeWidget
 
+import platform
+
 GlobalSettings.addConfigSection("viewer")
 GlobalSettings.addConfigOption("viewerDocked", section="viewer",
     key="docked",
@@ -130,6 +137,10 @@ class ViewerContainer(Gtk.VBox, Loggable):
         self.pipeline.connect("position", self._positionCb)
         self.pipeline.connect("duration-changed", self._durationChangedCb)
 
+        self.sink = pipeline.video_sink
+        self.internal.sink = self.sink
+        self.external.sink = self.sink
+
         self._switch_output_window()
         self._setUiActive()
 
@@ -168,7 +179,7 @@ class ViewerContainer(Gtk.VBox, Loggable):
 
     def _videoRealizedCb(self, unused_drawing_area, viewer):
         if viewer == self.target:
-            self.log("Viewer widget realized: %s", viewer)
+            self.log("Widget realized: %s", viewer)
             self._switch_output_window()
 
     def _createUi(self):
@@ -191,9 +202,11 @@ class ViewerContainer(Gtk.VBox, Loggable):
 
         # Buttons/Controls
         bbox = Gtk.HBox()
-        boxalign = Gtk.Alignment(xalign=0.5, yalign=0.5, xscale=0.0, yscale=0.0)
-        boxalign.add(bbox)
-        self.pack_start(boxalign, False, True, SPACING)
+
+        bbox.set_property("valign", Gtk.Align.CENTER)
+        bbox.set_property("halign", Gtk.Align.CENTER)
+
+        self.pack_start(bbox, False, True, SPACING)
 
         self.goToStart_button = Gtk.ToolButton()
         self.goToStart_button.set_icon_name("media-skip-backward")
@@ -266,7 +279,7 @@ class ViewerContainer(Gtk.VBox, Loggable):
             self.internal.set_size_request(width, height)
 
         self.buttons = bbox
-        self.buttons_container = boxalign
+        self.buttons_container = bbox
         self.show_all()
         self.external_vbox.show_all()
 
@@ -282,14 +295,14 @@ class ViewerContainer(Gtk.VBox, Loggable):
         nanoseconds = self.timecode_entry.getWidgetValue()
         self.seeker.seek(nanoseconds)
 
-    ## active Timeline calllbacks
+    # Active Timeline calllbacks
     def _durationChangedCb(self, unused_pipeline, duration):
         if duration == 0:
             self._setUiActive(False)
         else:
             self._setUiActive(True)
 
-    ## Control Gtk.Button callbacks
+    # Control Gtk.Button callbacks
 
     def setZoom(self, zoom):
         """
@@ -309,7 +322,7 @@ class ViewerContainer(Gtk.VBox, Loggable):
             self.target.renderbox()
 
     def _playButtonCb(self, unused_button, unused_playing):
-        self.app.current_project.pipeline.togglePlayback()
+        self.app.project_manager.current_project.pipeline.togglePlayback()
         self.app.gui.focusTimeline()
 
     def _goToStartCb(self, unused_button):
@@ -327,11 +340,11 @@ class ViewerContainer(Gtk.VBox, Loggable):
         self.app.gui.focusTimeline()
 
     def _goToEndCb(self, unused_button):
-        end = self.app.current_project.pipeline.getDuration()
+        end = self.app.project_manager.current_project.pipeline.getDuration()
         self.seeker.seek(end)
         self.app.gui.focusTimeline()
 
-    ## public methods for controlling playback
+    # Public methods for controlling playback
 
     def undock(self, *unused_widget):
         if not self.docked:
@@ -344,7 +357,6 @@ class ViewerContainer(Gtk.VBox, Loggable):
         self.remove(self.buttons_container)
         self.external_vbox.pack_end(self.buttons_container, False, False, 0)
         self.external_window.set_type_hint(Gdk.WindowTypeHint.UTILITY)
-        self.external_window.show()
 
         self.undock_button.hide()
         self.fullscreen_button = Gtk.ToggleToolButton()
@@ -354,9 +366,8 @@ class ViewerContainer(Gtk.VBox, Loggable):
         self.fullscreen_button.show()
         self.fullscreen_button.connect("toggled", self._toggleFullscreen)
 
-        # if we are playing, switch output immediately
-        if self.pipeline:
-            self._switch_output_window()
+        self.external_window.show()
+        self._switch_output_window()
         self.hide()
         self.external_window.move(self.settings.viewerX, self.settings.viewerY)
         self.external_window.resize(self.settings.viewerWidth, self.settings.viewerHeight)
@@ -373,9 +384,7 @@ class ViewerContainer(Gtk.VBox, Loggable):
         self.external_vbox.remove(self.buttons_container)
         self.pack_end(self.buttons_container, False, False, 0)
         self.show()
-        # if we are playing, switch output immediately
-        if self.pipeline:
-            self._switch_output_window()
+        self._switch_output_window()
         self.external_window.hide()
 
     def _toggleFullscreen(self, widget):
@@ -412,7 +421,7 @@ class ViewerContainer(Gtk.VBox, Loggable):
 
         clip_uri = tl_obj.props.uri
         cur_time = time()
-        if self.pipeline == self.app.current_project.pipeline:
+        if self.pipeline == self.app.project_manager.current_project.pipeline:
             self.debug("Creating temporary pipeline for clip %s, position %s",
                 clip_uri, format_ns(position))
             self._oldTimelinePos = self.pipeline.getPosition()
@@ -428,11 +437,11 @@ class ViewerContainer(Gtk.VBox, Loggable):
         """
         After trimming a clip, reset the project pipeline into the viewer.
         """
-        if self.pipeline is not self.app.current_project.pipeline:
+        if self.pipeline is not self.app.project_manager.current_project.pipeline:
             self.pipeline.setState(Gst.State.NULL)
             # Using pipeline.getPosition() here does not work because for some
             # reason it's a bit off, that's why we need self._oldTimelinePos.
-            self.setPipeline(self.app.current_project.pipeline, self._oldTimelinePos)
+            self.setPipeline(self.app.project_manager.current_project.pipeline, self._oldTimelinePos)
             self.debug("Back to the project's pipeline")
 
     def _pipelineStateChangedCb(self, unused_pipeline, state):
@@ -453,13 +462,19 @@ class ViewerContainer(Gtk.VBox, Loggable):
         self.internal._currentStateCb(self.pipeline, state)
 
     def _switch_output_window(self):
-        # Don't do anything if we don't have a pipeline
+        # Bail out if we don't have a playable pipeline (it happens!)
         if self.pipeline is None:
             return
 
         if self.target.get_realized():
             self.debug("Connecting the pipeline to the viewer's texture")
-            self.pipeline.connectWithViewer(self.target)
+            if platform.system() == 'Windows':
+                xid = self.target.drawing_area.get_window().get_handle()
+            else:
+                xid = self.target.drawing_area.get_window().get_xid()
+
+            self.sink.set_window_handle(xid)
+            self.sink.expose()
         else:
             # Show the widget and wait for the realized callback
             self.log("Target is not realized, showing the widget")
@@ -540,7 +555,7 @@ class Point():
  LEFT,
  RIGHT,
  TOP,
- BOTTOM) = range(10)
+ BOTTOM) = list(range(10))
 
 
 class TransformationBox():
@@ -614,12 +629,12 @@ class TransformationBox():
         self.last_y = event.y
 
     def init_points(self):
-        #corner boxes
+        # Corner boxes
         self.points[TOP_LEFT] = Point(self.left, self.top, self.settings)
         self.points[TOP_RIGHT] = Point(self.right, self.top, self.settings)
         self.points[BOTTOM_LEFT] = Point(self.left, self.bottom, self.settings)
         self.points[BOTTOM_RIGHT] = Point(self.right, self.bottom, self.settings)
-        #edge boxes
+        # Edge boxes
         self.points[TOP] = Point(self.center.x, self.top, self.settings)
         self.points[BOTTOM] = Point(self.center.x, self.bottom, self.settings)
         self.points[LEFT] = Point(self.left, self.center.y, self.settings)
@@ -628,12 +643,12 @@ class TransformationBox():
     def update_points(self):
         self._update_measure()
 
-        #corner boxes
+        # Corner boxes
         self.points[TOP_LEFT].set_position(self.left, self.top)
         self.points[TOP_RIGHT].set_position(self.right, self.top)
         self.points[BOTTOM_LEFT].set_position(self.left, self.bottom)
         self.points[BOTTOM_RIGHT].set_position(self.right, self.bottom)
-        #edge boxes
+        # Edge boxes
         self.points[TOP].set_position(self.center.x, self.top)
         self.points[BOTTOM].set_position(self.center.x, self.bottom)
         self.points[LEFT].set_position(self.left, self.center.y)
@@ -651,7 +666,7 @@ class TransformationBox():
         else:
             point_width = self.settings.pointSize
 
-        for point in self.points.values():
+        for point in list(self.points.values()):
             point.set_width(point_width)
 
     def draw(self, cr):
@@ -661,14 +676,14 @@ class TransformationBox():
         cr.rectangle(self.left, self.top, self.right - self.left, self.bottom - self.top)
         cr.stroke()
 
-        for point in self.points.values():
+        for point in list(self.points.values()):
             point.draw(cr)
 
     def select_point(self, event):
         # translate when zoomed out
         event.x -= self.area.x
         event.y -= self.area.y
-        for type, point in self.points.items():
+        for type, point in list(self.points.items()):
             if point.is_clicked(event):
                 self.clicked_point = type
                 return
@@ -722,7 +737,7 @@ class TransformationBox():
         return True
 
     def release_point(self):
-        for point in self.points.values():
+        for point in list(self.points.values()):
             point.clicked = False
         self.clicked_point = NO_POINT
 
@@ -792,26 +807,19 @@ class ViewerWidget(Gtk.AspectFrame, Loggable):
     def __init__(self, settings=None, realizedCb=None):
         # Prevent black frames and flickering while resizing or changing focus:
         # The aspect ratio gets overridden by setDisplayAspectRatio.
-        Gtk.AspectFrame.__init__(self, xalign=0.5, yalign=1.0,
+        Gtk.AspectFrame.__init__(self, xalign=0.5, yalign=0.5,
                                  ratio=4.0 / 3.0, obey_child=False)
         Loggable.__init__(self)
 
-        self.drawing_area = GtkClutter.Embed()
+        self.drawing_area = Gtk.DrawingArea()
         self.drawing_area.set_double_buffered(False)
+        self.drawing_area.connect("draw", self._drawCb, None)
         # We keep the ViewerWidget hidden initially, or the desktop wallpaper
         # would show through the non-double-buffered widget!
         if realizedCb:
             self.drawing_area.connect("realize", realizedCb, self)
         self.add(self.drawing_area)
 
-        layout_manager = Clutter.BinLayout(x_align=Clutter.BinAlignment.FILL, y_align=Clutter.BinAlignment.FILL)
-        self.drawing_area.get_stage().set_layout_manager(layout_manager)
-        self.texture = Clutter.Texture()
-        # This is a trick to make the viewer appear darker at the start.
-        self.texture.set_from_rgb_data(data=[0] * 3, has_alpha=False,
-                width=1, height=1, rowstride=3, bpp=3,
-                flags=Clutter.TextureFlags.NONE)
-        self.drawing_area.get_stage().add_child(self.texture)
         self.drawing_area.show()
 
         self.seeker = Seeker()
@@ -824,11 +832,25 @@ class ViewerWidget(Gtk.AspectFrame, Loggable):
         self.pixbuf = None
         self.pipeline = None
         self.transformation_properties = None
+        self._setting_ratio = False
+
         # FIXME PyGi Styling with Gtk3
-        #for state in range(Gtk.StateType.INSENSITIVE + 1):
-            #self.modify_bg(state, self.style.black)
+        # for state in range(Gtk.StateType.INSENSITIVE + 1):
+        # self.modify_bg(state, self.style.black)
+
+    def _drawCb(self, unused, unused1, unused2):
+        if self._setting_ratio:
+            # During caps renogotiation resulting from
+            # the change of the rendering setting/aspect ratio
+            # changes, we could end up with the viewer displaying
+            # broken frames, avoid calling the videosink.expose()
+            # in that case (https://bugzilla.gnome.org/show_bug.cgi?id=739145)
+            self._setting_ratio = False
+        elif self.sink:
+            self.sink.expose()
 
     def setDisplayAspectRatio(self, ratio):
+        self._setting_ratio = True
         self.set_property("ratio", float(ratio))
 
     def init_transformation_events(self):
