@@ -45,11 +45,11 @@ class TestCase(unittest.TestCase):
         self.gccollect()
 
         for elt in leaked:
-            print elt
+            print(elt)
             for i in gc.get_referrers(elt):
-                print "   ", i
+                print("   ", i)
 
-        self.failIf(leaked, leaked)
+        self.assertFalse(leaked, leaked)
         del self._tracked
 
     def setUp(self):
@@ -75,6 +75,11 @@ class TestCase(unittest.TestCase):
         self._result = result
         unittest.TestCase.run(self, result)
 
+    @staticmethod
+    def getSampleUri(sample):
+        dir = os.path.dirname(os.path.abspath(__file__))
+        return "file://%s/samples/%s" % (dir, sample)
+
 
 class SignalMonitor(object):
     def __init__(self, obj, *signals):
