@@ -58,10 +58,14 @@ def setup():
     from pitivi.check import initialize_modules
     initialize_modules()
 
+    from pitivi.utils import loggable as log
+    log.init('PITIVI_DEBUG')
+
     try:
         import mock
-    except ImportError, e:
-        raise Exception("Python mock library missing! www.voidspace.org.uk/python/mock", e)
+    except ImportError:
+        print("\n\nPython mock library missing! www.voidspace.org.uk/python/mock\n\n", file=sys.stderr)
+        raise
 
 
 if __name__ == "__main__":
@@ -73,8 +77,6 @@ if __name__ == "__main__":
     if 'VERBOSE' in os.environ:
         descriptions = 2
         verbosity = 2
-    from pitivi.utils import loggable as log
-    log.init('PITIVI_DEBUG')
 
     suite = _tests_suite()
     if not list(suite):
