@@ -20,7 +20,7 @@
 # Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 # Boston, MA 02110-1301, USA.
 
-from common import TestCase
+from tests import common
 
 from pitivi import application
 from pitivi import configure
@@ -31,36 +31,50 @@ class MockGioFile(object):
         return (True, result)
 
 
-class TestPitivi(TestCase):
-
-    def testBasic(self):
-        app = application.Pitivi()
-        self.assertTrue(app.shutdown())
+class TestPitivi(common.TestCase):
 
     def testVersionInfo(self):
         app = application.Pitivi()
+        app._checkVersion()
         self.assertTrue(app.isLatest())
 
         app = application.Pitivi()
+        app._checkVersion()
         app._versionInfoReceivedCb(MockGioFile(), "invalid", None)
         self.assertTrue(app.isLatest())
 
         app = application.Pitivi()
+        app._checkVersion()
         app._versionInfoReceivedCb(MockGioFile(), "%s=CURRENT" % configure.VERSION, None)
         self.assertTrue(app.isLatest())
         self.assertEqual(configure.VERSION, app.getLatest())
 
         app = application.Pitivi()
+        app._checkVersion()
         app._versionInfoReceivedCb(MockGioFile(), "%s=current\n0=supported" % configure.VERSION, None)
         self.assertTrue(app.isLatest())
         self.assertEqual(configure.VERSION, app.getLatest())
 
         app = application.Pitivi()
+        app._checkVersion()
         app._versionInfoReceivedCb(MockGioFile(), "999.0=CURRENT", None)
         self.assertFalse(app.isLatest())
         self.assertEqual("999.0", app.getLatest())
 
         app = application.Pitivi()
+        app._checkVersion()
         app._versionInfoReceivedCb(MockGioFile(), "999.0=CURRENT\n%s=SUPPORTED" % configure.VERSION, None)
         self.assertFalse(app.isLatest())
         self.assertEqual("999.0", app.getLatest())
+
+        app = application.Pitivi()
+        app._checkVersion()
+        app._versionInfoReceivedCb(MockGioFile(), "0.91=current", None)
+        self.assertTrue(app.isLatest())
+        self.assertEqual("0.91", app.getLatest())
+
+        app = application.Pitivi()
+        app._checkVersion()
+        app._versionInfoReceivedCb(MockGioFile(), "0.100000000=current", None)
+        self.assertFalse(app.isLatest())
+        self.assertEqual("0.100000000", app.getLatest())
