@@ -28,6 +28,9 @@ from pitivi.undo.undo import UndoError, UndoWrongStateError, UndoableAction, \
 class DummyUndoableAction(UndoableAction):
     done_ = True
 
+    def __init__(self):
+        UndoableAction.__init__(self)
+
     def do(self):
         self.done_ = True
         self._done()
@@ -52,10 +55,10 @@ class TestUndoableAction(TestCase):
         action.connect("undone", doneCb, False)
 
         action.undo()
-        self.failIf(state["done"])
+        self.assertFalse(state["done"])
 
         action.do()
-        self.failUnless(state["done"])
+        self.assertTrue(state["done"])
 
 
 class TestUndoableActionStack(TestCase):
@@ -73,10 +76,10 @@ class TestUndoableActionStack(TestCase):
         stack.connect("undone", doneCb, False)
 
         stack.undo()
-        self.failIf(state["done"])
+        self.assertFalse(state["done"])
 
         stack.do()
-        self.failUnless(state["done"])
+        self.assertTrue(state["done"])
 
     def testUndoDo(self):
         """
@@ -107,12 +110,12 @@ class TestUndoableActionStack(TestCase):
         stack.push(action2)
 
         stack.undo()
-        self.failUnlessEqual(state["actions"], 0)
-        self.failIf(state["done"])
+        self.assertEqual(state["actions"], 0)
+        self.assertFalse(state["done"])
 
         stack.do()
-        self.failUnlessEqual(state["actions"], 2)
-        self.failUnless(state["done"])
+        self.assertEqual(state["actions"], 2)
+        self.assertTrue(state["done"])
 
     def testUndoError(self):
         """
@@ -143,9 +146,9 @@ class TestUndoableActionStack(TestCase):
         stack.push(action1)
         stack.push(action2)
 
-        self.failUnlessRaises(UndoError, stack.undo)
-        self.failUnlessEqual(state["actions"], 1)
-        self.failUnless(state["done"])
+        self.assertRaises(UndoError, stack.undo)
+        self.assertEqual(state["actions"], 1)
+        self.assertTrue(state["done"])
 
 
 class TestUndoableActionLog(TestCase):
@@ -171,156 +174,156 @@ class TestUndoableActionLog(TestCase):
         self.log.disconnect_by_func(self._undoActionLogSignalCb)
 
     def testRollbackWrongState(self):
-        self.failUnlessRaises(UndoWrongStateError, self.log.rollback)
+        self.assertRaises(UndoWrongStateError, self.log.rollback)
 
     def testCommitWrongState(self):
-        self.failUnlessRaises(UndoWrongStateError, self.log.commit)
+        self.assertRaises(UndoWrongStateError, self.log.commit)
 
     def testPushWrongState(self):
         # no error in this case
         self.log.push(None)
 
     def testUndoWrongState(self):
-        self.failUnlessRaises(UndoWrongStateError, self.log.undo)
+        self.assertRaises(UndoWrongStateError, self.log.undo)
 
     def testRedoWrongState(self):
-        self.failUnlessRaises(UndoWrongStateError, self.log.redo)
+        self.assertRaises(UndoWrongStateError, self.log.redo)
 
     def testCheckpoint(self):
         self.log.begin("meh")
         self.log.push(DummyUndoableAction())
-        self.failUnlessRaises(UndoWrongStateError, self.log.checkpoint)
+        self.assertRaises(UndoWrongStateError, self.log.checkpoint)
         self.log.rollback()
         self.log.checkpoint()
-        self.failIfEqual(self.log._checkpoint, None)
+        self.assertNotEqual(self.log._checkpoint, None)
 
     def testDirty(self):
-        self.failIf(self.log.dirty())
+        self.assertFalse(self.log.dirty())
         self.log.begin("meh")
         self.log.push(DummyUndoableAction())
         self.log.commit()
-        self.failUnless(self.log.dirty())
+        self.assertTrue(self.log.dirty())
         self.log.checkpoint()
-        self.failIf(self.log.dirty())
+        self.assertFalse(self.log.dirty())
         self.log.undo()
-        self.failUnless(self.log.dirty())
+        self.assertTrue(self.log.dirty())
         self.log.redo()
-        self.failIf(self.log.dirty())
+        self.assertFalse(self.log.dirty())
 
     def testCommit(self):
         """
         Commit a stack.
         """
-        self.failUnlessEqual(len(self.log.undo_stacks), 0)
-        self.failUnlessEqual(len(self.log.redo_stacks), 0)
+        self.assertEqual(len(self.log.undo_stacks), 0)
+        self.assertEqual(len(self.log.redo_stacks), 0)
         self.log.begin("meh")
-        self.failUnlessEqual(len(self.signals), 1)
+        self.assertEqual(len(self.signals), 1)
         name, (stack, nested) = self.signals[0]
-        self.failUnlessEqual(name, "begin")
-        self.failIf(nested)
+        self.assertEqual(name, "begin")
+        self.assertFalse(nested)
 
-        self.failUnlessEqual(self.log.undo_stacks, [])
+        self.assertEqual(self.log.undo_stacks, [])
         self.log.commit()
-        self.failUnlessEqual(len(self.signals), 2)
+        self.assertEqual(len(self.signals), 2)
         name, (stack, nested) = self.signals[1]
-        self.failUnlessEqual(name, "commit")
-        self.failIf(nested)
-        self.failUnlessEqual(len(self.log.undo_stacks), 1)
-        self.failUnlessEqual(len(self.log.redo_stacks), 0)
+        self.assertEqual(name, "commit")
+        self.assertFalse(nested)
+        self.assertEqual(len(self.log.undo_stacks), 1)
+        self.assertEqual(len(self.log.redo_stacks), 0)
 
     def testNestedCommit(self):
         """
         Do two nested commits.
         """
-        self.failUnlessEqual(len(self.log.undo_stacks), 0)
-        self.failUnlessEqual(len(self.log.redo_stacks), 0)
+        self.assertEqual(len(self.log.undo_stacks), 0)
+        self.assertEqual(len(self.log.redo_stacks), 0)
         self.log.begin("meh")
-        self.failUnlessEqual(len(self.signals), 1)
+        self.assertEqual(len(self.signals), 1)
         name, (stack, nested) = self.signals[0]
-        self.failUnlessEqual(name, "begin")
-        self.failIf(nested)
+        self.assertEqual(name, "begin")
+        self.assertFalse(nested)
 
-        self.failUnlessEqual(len(self.log.undo_stacks), 0)
-        self.failUnlessEqual(len(self.log.redo_stacks), 0)
+        self.assertEqual(len(self.log.undo_stacks), 0)
+        self.assertEqual(len(self.log.redo_stacks), 0)
         self.log.begin("nested")
-        self.failUnlessEqual(len(self.signals), 2)
+        self.assertEqual(len(self.signals), 2)
         name, (stack, nested) = self.signals[1]
-        self.failUnlessEqual(name, "begin")
-        self.failUnless(nested)
+        self.assertEqual(name, "begin")
+        self.assertTrue(nested)
 
-        self.failUnlessEqual(self.log.undo_stacks, [])
+        self.assertEqual(self.log.undo_stacks, [])
         self.log.commit()
-        self.failUnlessEqual(len(self.signals), 3)
+        self.assertEqual(len(self.signals), 3)
         name, (stack, nested) = self.signals[2]
-        self.failUnlessEqual(name, "commit")
-        self.failUnless(nested)
-        self.failUnlessEqual(len(self.log.undo_stacks), 0)
-        self.failUnlessEqual(len(self.log.redo_stacks), 0)
+        self.assertEqual(name, "commit")
+        self.assertTrue(nested)
+        self.assertEqual(len(self.log.undo_stacks), 0)
+        self.assertEqual(len(self.log.redo_stacks), 0)
 
-        self.failUnlessEqual(self.log.undo_stacks, [])
+        self.assertEqual(self.log.undo_stacks, [])
         self.log.commit()
-        self.failUnlessEqual(len(self.signals), 4)
+        self.assertEqual(len(self.signals), 4)
         name, (stack, nested) = self.signals[3]
-        self.failUnlessEqual(name, "commit")
-        self.failIf(nested)
-        self.failUnlessEqual(len(self.log.undo_stacks), 1)
-        self.failUnlessEqual(len(self.log.redo_stacks), 0)
+        self.assertEqual(name, "commit")
+        self.assertFalse(nested)
+        self.assertEqual(len(self.log.undo_stacks), 1)
+        self.assertEqual(len(self.log.redo_stacks), 0)
 
     def testRollback(self):
         """
         Test a rollback.
         """
-        self.failUnlessEqual(len(self.log.undo_stacks), 0)
-        self.failUnlessEqual(len(self.log.redo_stacks), 0)
+        self.assertEqual(len(self.log.undo_stacks), 0)
+        self.assertEqual(len(self.log.redo_stacks), 0)
         self.log.begin("meh")
-        self.failUnlessEqual(len(self.signals), 1)
+        self.assertEqual(len(self.signals), 1)
         name, (stack, nested) = self.signals[0]
-        self.failUnlessEqual(name, "begin")
-        self.failIf(nested)
+        self.assertEqual(name, "begin")
+        self.assertFalse(nested)
 
         self.log.rollback()
-        self.failUnlessEqual(len(self.signals), 2)
+        self.assertEqual(len(self.signals), 2)
         name, (stack, nested) = self.signals[1]
-        self.failUnlessEqual(name, "rollback")
-        self.failIf(nested)
-        self.failUnlessEqual(len(self.log.undo_stacks), 0)
-        self.failUnlessEqual(len(self.log.redo_stacks), 0)
+        self.assertEqual(name, "rollback")
+        self.assertFalse(nested)
+        self.assertEqual(len(self.log.undo_stacks), 0)
+        self.assertEqual(len(self.log.redo_stacks), 0)
 
     def testNestedRollback(self):
         """
         Test two nested rollbacks.
         """
-        self.failUnlessEqual(len(self.log.undo_stacks), 0)
-        self.failUnlessEqual(len(self.log.redo_stacks), 0)
+        self.assertEqual(len(self.log.undo_stacks), 0)
+        self.assertEqual(len(self.log.redo_stacks), 0)
         self.log.begin("meh")
-        self.failUnlessEqual(len(self.signals), 1)
+        self.assertEqual(len(self.signals), 1)
         name, (stack, nested) = self.signals[0]
-        self.failUnlessEqual(name, "begin")
-        self.failIf(nested)
+        self.assertEqual(name, "begin")
+        self.assertFalse(nested)
 
-        self.failUnlessEqual(len(self.log.undo_stacks), 0)
-        self.failUnlessEqual(len(self.log.redo_stacks), 0)
+        self.assertEqual(len(self.log.undo_stacks), 0)
+        self.assertEqual(len(self.log.redo_stacks), 0)
         self.log.begin("nested")
-        self.failUnlessEqual(len(self.signals), 2)
+        self.assertEqual(len(self.signals), 2)
         name, (stack, nested) = self.signals[1]
-        self.failUnlessEqual(name, "begin")
-        self.failUnless(nested)
+        self.assertEqual(name, "begin")
+        self.assertTrue(nested)
 
         self.log.rollback()
-        self.failUnlessEqual(len(self.signals), 3)
+        self.assertEqual(len(self.signals), 3)
         name, (stack, nested) = self.signals[2]
-        self.failUnlessEqual(name, "rollback")
-        self.failUnless(nested)
-        self.failUnlessEqual(len(self.log.undo_stacks), 0)
-        self.failUnlessEqual(len(self.log.redo_stacks), 0)
+        self.assertEqual(name, "rollback")
+        self.assertTrue(nested)
+        self.assertEqual(len(self.log.undo_stacks), 0)
+        self.assertEqual(len(self.log.redo_stacks), 0)
 
         self.log.rollback()
-        self.failUnlessEqual(len(self.signals), 4)
+        self.assertEqual(len(self.signals), 4)
         name, (stack, nested) = self.signals[3]
-        self.failUnlessEqual(name, "rollback")
-        self.failIf(nested)
-        self.failUnlessEqual(len(self.log.undo_stacks), 0)
-        self.failUnlessEqual(len(self.log.redo_stacks), 0)
+        self.assertEqual(name, "rollback")
+        self.assertFalse(nested)
+        self.assertEqual(len(self.log.undo_stacks), 0)
+        self.assertEqual(len(self.log.redo_stacks), 0)
 
     def testUndoRedo(self):
         """
@@ -328,61 +331,61 @@ class TestUndoableActionLog(TestCase):
         """
         # begin
         self.log.begin("meh")
-        self.failUnlessEqual(len(self.signals), 1)
+        self.assertEqual(len(self.signals), 1)
         name, (stack, nested) = self.signals[0]
-        self.failUnlessEqual(name, "begin")
-        self.failIf(nested)
+        self.assertEqual(name, "begin")
+        self.assertFalse(nested)
 
         # push two actions
         action1 = DummyUndoableAction()
         self.log.push(action1)
-        self.failUnlessEqual(len(self.signals), 2)
+        self.assertEqual(len(self.signals), 2)
         name, (stack, signalAction) = self.signals[1]
-        self.failUnlessEqual(name, "push")
-        self.failUnless(action1 is signalAction)
+        self.assertEqual(name, "push")
+        self.assertTrue(action1 is signalAction)
 
         action2 = DummyUndoableAction()
         self.log.push(action2)
-        self.failUnlessEqual(len(self.signals), 3)
+        self.assertEqual(len(self.signals), 3)
         name, (stack, signalAction) = self.signals[2]
-        self.failUnlessEqual(name, "push")
-        self.failUnless(action2 is signalAction)
+        self.assertEqual(name, "push")
+        self.assertTrue(action2 is signalAction)
 
         # commit
-        self.failUnlessEqual(len(self.log.undo_stacks), 0)
-        self.failUnlessEqual(len(self.log.redo_stacks), 0)
+        self.assertEqual(len(self.log.undo_stacks), 0)
+        self.assertEqual(len(self.log.redo_stacks), 0)
         self.log.commit()
-        self.failUnlessEqual(len(self.signals), 4)
+        self.assertEqual(len(self.signals), 4)
         name, (stack, nested) = self.signals[3]
-        self.failUnlessEqual(name, "commit")
-        self.failIf(nested)
-        self.failUnlessEqual(len(self.log.undo_stacks), 1)
-        self.failUnlessEqual(len(self.log.redo_stacks), 0)
+        self.assertEqual(name, "commit")
+        self.assertFalse(nested)
+        self.assertEqual(len(self.log.undo_stacks), 1)
+        self.assertEqual(len(self.log.redo_stacks), 0)
 
-        self.failUnless(action1.done_)
-        self.failUnless(action2.done_)
+        self.assertTrue(action1.done_)
+        self.assertTrue(action2.done_)
 
         # undo what we just committed
         self.log.undo()
-        self.failUnlessEqual(len(self.signals), 5)
+        self.assertEqual(len(self.signals), 5)
         name, stack = self.signals[4]
-        self.failUnlessEqual(name, "undo")
-        self.failUnlessEqual(len(self.log.undo_stacks), 0)
-        self.failUnlessEqual(len(self.log.redo_stacks), 1)
+        self.assertEqual(name, "undo")
+        self.assertEqual(len(self.log.undo_stacks), 0)
+        self.assertEqual(len(self.log.redo_stacks), 1)
 
-        self.failIf(action1.done_)
-        self.failIf(action2.done_)
+        self.assertFalse(action1.done_)
+        self.assertFalse(action2.done_)
 
         # redo
         self.log.redo()
-        self.failUnlessEqual(len(self.signals), 6)
+        self.assertEqual(len(self.signals), 6)
         name, stack = self.signals[5]
-        self.failUnlessEqual(name, "redo")
-        self.failUnlessEqual(len(self.log.undo_stacks), 1)
-        self.failUnlessEqual(len(self.log.redo_stacks), 0)
+        self.assertEqual(name, "redo")
+        self.assertEqual(len(self.log.undo_stacks), 1)
+        self.assertEqual(len(self.log.redo_stacks), 0)
 
-        self.failUnless(action1.done_)
-        self.failUnless(action2.done_)
+        self.assertTrue(action1.done_)
+        self.assertTrue(action2.done_)
 
     def testOrder(self):
         """
@@ -392,6 +395,7 @@ class TestUndoableActionLog(TestCase):
 
         class Action(UndoableAction):
             def __init__(self, n):
+                UndoableAction.__init__(self)
                 self.n = n
 
             def do(self):
@@ -415,12 +419,12 @@ class TestUndoableActionLog(TestCase):
         self.log.commit()
 
         self.log.undo()
-        self.failUnlessEqual(call_sequence, ["undo3", "undo2", "undo1"])
+        self.assertEqual(call_sequence, ["undo3", "undo2", "undo1"])
 
         call_sequence[:] = []
         self.log.redo()
-        self.failUnlessEqual(call_sequence, ["do1", "do2", "do3"])
+        self.assertEqual(call_sequence, ["do1", "do2", "do3"])
 
         call_sequence[:] = []
         self.log.undo()
-        self.failUnlessEqual(call_sequence, ["undo3", "undo2", "undo1"])
+        self.assertEqual(call_sequence, ["undo3", "undo2", "undo1"])
