@@ -34,23 +34,23 @@ hour = minute * 60
 
 class TestBeautifyLength(TestCase):
     def testBeautifySeconds(self):
-        self.failUnlessEqual(beautify_length(second), "1 second")
-        self.failUnlessEqual(beautify_length(second * 2), "2 seconds")
+        self.assertEqual(beautify_length(second), "1 second")
+        self.assertEqual(beautify_length(second * 2), "2 seconds")
 
     def testBeautifyMinutes(self):
-        self.failUnlessEqual(beautify_length(minute), "1 minute")
-        self.failUnlessEqual(beautify_length(minute * 2), "2 minutes")
+        self.assertEqual(beautify_length(minute), "1 minute")
+        self.assertEqual(beautify_length(minute * 2), "2 minutes")
 
     def testBeautifyHours(self):
-        self.failUnlessEqual(beautify_length(hour), "1 hour")
-        self.failUnlessEqual(beautify_length(hour * 2), "2 hours")
+        self.assertEqual(beautify_length(hour), "1 hour")
+        self.assertEqual(beautify_length(hour * 2), "2 hours")
 
     def testBeautifyMinutesAndSeconds(self):
-        self.failUnlessEqual(beautify_length(minute + second),
+        self.assertEqual(beautify_length(minute + second),
                 "1 minute, 1 second")
 
     def testBeautifyHoursAndMinutes(self):
-        self.failUnlessEqual(beautify_length(hour + minute + second),
+        self.assertEqual(beautify_length(hour + minute + second),
                 "1 hour, 1 minute")
 
 
@@ -58,40 +58,40 @@ class TestDependencyChecks(TestCase):
     def testDependencies(self):
         gi_dep = GstDependency("Gst", "1.0.0")
         gi_dep.check()
-        self.failUnless(gi_dep.satisfied)
+        self.assertTrue(gi_dep.satisfied)
 
         gi_dep = GstDependency("Gst", "9.9.9")
         gi_dep.check()
-        self.failIf(gi_dep.satisfied)
+        self.assertFalse(gi_dep.satisfied)
 
         gi_dep = GstDependency("ThisShouldNotExist", None)
         gi_dep.check()
-        self.failIf(gi_dep.satisfied)
+        self.assertFalse(gi_dep.satisfied)
 
         gi_dep = GtkOrClutterDependency("Gtk", "3.0.0")
         gi_dep.check()
-        self.failUnless(gi_dep.satisfied)
+        self.assertTrue(gi_dep.satisfied)
 
         gi_dep = GtkOrClutterDependency("Gtk", "9.9.9")
         gi_dep.check()
-        self.failIf(gi_dep.satisfied)
+        self.assertFalse(gi_dep.satisfied)
 
         cairo_dep = CairoDependency("1.0.0")
         cairo_dep.check()
-        self.failUnless(cairo_dep.satisfied)
+        self.assertTrue(cairo_dep.satisfied)
 
         cairo_dep = CairoDependency("9.9.9")
         cairo_dep.check()
-        self.failIf(cairo_dep.satisfied)
+        self.assertFalse(cairo_dep.satisfied)
 
         classic_dep = ClassicDependency("numpy", None)
         classic_dep.check()
-        self.failUnless(classic_dep.satisfied)
+        self.assertTrue(classic_dep.satisfied)
 
         gst_plugin_dep = GstPluginDependency("gnonlin", "1.1.90")
         gst_plugin_dep.check()
-        self.failUnless(gst_plugin_dep.satisfied)
+        self.assertTrue(gst_plugin_dep.satisfied)
 
         gst_plugin_dep = GstPluginDependency("gnonlin", "9.9.9")
         gst_plugin_dep.check()
-        self.failIf(gst_plugin_dep.satisfied)
+        self.assertFalse(gst_plugin_dep.satisfied)
